% Focused Coding subproject: Semiologic Factors
% Wesley Kerr, December 2016, wesleytk@g.ucla.edu with MATLAB2016b
%
% To do coding
% 0. Memory management with permutations
%
% 1. Retrospective data analysis for prediction
% 1b. Multiple imputation
% 1c. Model Summarization
%
% 2. Prospective data analysis & prediction
% 2a. Load Data
% 2b. Performance
%
% 3. Kappa Analysis
%
% 4. Descriptive models - 5 class
% 4a. Models - need fix age and table output
% 4b. Pairwise comparisons
% 4c. Descriptive Figures
%
% 5. Raw data display
% 5a. Continuous
% 5b. Binary
% 5c. Limit to just significant factors
% 
% Generic Things
% 0. Table 1
% 1. Supplemental Table 1: R vs P on all studied factors
%
% Note: fitctree does not have proper options in MATLAB2014b

% Set up environment and file sources
dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.analysis =[dirs.base 'Dropbox/ES_Semiology/'];
dirs.data     =[dirs.base 'Documents/EMU/CI/Semiology/'];
dirs.retroDx  =[dirs.data 'Retro5_ForDx.csv'];
dirs.retrodata=[dirs.data 'Retro6_Semiology.csv'];
dirs.retroarff=[dirs.data 'Retro6_Semiology'];
dirs.retrosum =[dirs.analysis 'Retro6_ModelSummary.csv'];
dirs.retrotreesum =[dirs.analysis 'Retro6_ModelSummaryTree.csv'];
dirs.sigmodel =[dirs.analysis 'Retro6_SigModel.csv'];
dirs.prospDx  =[dirs.data 'Prosp_Diagnosis161122b.csv'];
dirs.prospdata=[dirs.data 'Prosp_Semiology161121.csv'];
dirs.prosparff=[dirs.analysis 'Prosp5_Semiology'];
dirs.pro2ret  =[dirs.analysis 'Semiology_Pro2Ret.csv'];
dirs.descrip  =[dirs.analysis 'Semiology_Descrip_Class.csv'];
dirs.pairwise =[dirs.analysis 'Semiology_DescripPairwise.csv'];
dirs.table1   =[dirs.analysis 'Semiology_Table1.csv'];
dirs.Stable1  =[dirs.analysis 'Semiology_STable1.csv'];
dirs.process  =[dirs.data 'Semiology_Processed'];
dirs.treeout  =[dirs.analysis 'Semiology_TreeOutput.txt'];
dirs.perftable=[dirs.analysis 'Semiology_Perf.csv'];

%% Numerical Choices
do.fiveclass      =0; % do the 5-class model: it turns out to be the same as the binary
do.age            =1;
n.imputations     =20; % need to change to 20 for final analysis, but 5 is also acceptable
do.permutations   =1;
n.permutations    =50; % note MI not done in permutations because class info wasn't used for MI
% 100 is a reasonable choice for debugging
ideal.imputations =20;
ideal.permutations=10000;
 if n.permutations<10000
     fprintf('Need more permutations to trust significance\n');
 end
 % 10,000 is for p<0.05
 % 50,000 is for p<0.01
cutoff.prevalence =10;
cutoff.age        =150; % maximum allowed age
cutoff.year       =1900;% AoO above this are treated as years
cutoff.rawsubmin  =5; % for raw data display figures
do.mi.classinfo   =0;   % to use diagnosis information for imputation
n.iterations      =400; % converges by 100-ish, so doing 400 is probably best
mi.scale=log(0.01)/100; % set so it's 1% at 100 iterations

% Color choices for figures
Colors5=[78 195 199;
137 88 129;
243 108 54;
199 178 158;
130 71 55]/256;

if do.permutations
    s = RandStream('mt19937ar','Seed',sum(clock));
    RandStream.setGlobalStream(s);
end

if do.age
    dirs.retrosum =[dirs.analysis 'Retro6_ModelSummary_age.csv'];
    dirs.retrotreesum =[dirs.analysis 'Retro6_ModelSummaryTree_age.csv'];
    dirs.sigmodel =[dirs.analysis 'Retro6_SigModel_age.csv'];
    dirs.table1   =[dirs.analysis 'Semiology_Table1_age.csv'];
    dirs.Stable1  =[dirs.analysis 'Semiology_STable1_age.csv'];
    dirs.process  =[dirs.data 'Semiology_Processed_age'];
    dirs.treeout  =[dirs.analysis 'Semiology_TreeOutput_age.txt'];
    dirs.perftable=[dirs.analysis 'Semiology_Perf_age.csv'];
end

%% Load Retrospective Diagnoses
fid=fopen(dirs.retroDx,'r');
d=textscan(fid,'%f %f %f %s %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',3);
fclose(fid);

ix.MRN=2;
ix.Dx =3;
iy.notnan=find(~isnan(d{ix.MRN}));
n.retro.sub=length(iy.notnan);
data.MRNDx=d{ix.MRN}(iy.notnan);
data.Dx   =zeros(n.retro.sub,2);
% 1: Calc where each subdx has a unique code
% 2: NES vs ES, with mixed & inconclusive as 0
data.Dx(:,1)=d{ix.Dx}(iy.notnan);
ix.tmp=find(data.Dx(:,1)==-3);
data.Dx(ix.tmp,1)=-2;
data.Dx(:,2)=((data.Dx(:,1)>0)+(data.Dx(:,1)<0)*-1).*(data.Dx(:,1)~=-5);

%% Load Retrospective Data
fid=fopen(dirs.retrodata,'r');
h=textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Delimiter',',','Headerlines',2);
fclose(fid);

fid=fopen(dirs.retrodata,'r');
d=textscan(fid,'%s %f %f %s %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',3);
fclose(fid);

ix.data.MRN=3;
ix.data.Age=5;
ix.data.Gender=6;
ix.data.Onset=7:8;
ix.data.Semi=9:43;
ix.data.SecG=43-5;
ix.data.Inju=43-4;
ix.data.Use=[ix.data.Age ix.data.Gender setdiff(ix.data.Semi,[ix.data.SecG,ix.data.Inju])];
ix.retro.Age=1;
ix.retro.Gender=2;
% ix.retro.Dur=3;
% ix.retro.Ons=4;
ix.retro.transform=3:4;
ix.retro.types=5;
ix.retro.limbs=18;
ix.retro.secgen=32;
n.retro.vars=length(ix.data.Use);
ix.data.cont =[1 3 4 5 18];%[1 3 4 5 6 7 20];
ix.data.indicators=setdiff(1:n.retro.vars,ix.data.cont);
ix.data.toimpute=3:4;
ix.data.noimpute=setdiff(1:n.retro.vars,ix.data.toimpute);

% Headers
heads.retro=cell(length(ix.data.Use),1);
cnt=1;
for ind=ix.data.Use
    heads.retro{cnt}=h{ind}{1};
    cnt=cnt+1;
end

% Data
data.MRNdata=zeros(n.retro.sub,1);
data.retro=zeros(n.retro.sub,length(ix.data.Use));
data.retro(:,:)=NaN;
for ind=1:length(d{1})
    iy.DxID=find(data.MRNDx==d{ix.data.MRN}(ind));
    if isempty(iy.DxID)
        if ~isnan(d{ix.data.MRN}(ind))
            fprintf(['Missing Dx MRN:' num2str(d{ix.data.MRN}(ind)) '\n']);
        end
    elseif length(iy.DxID)==1
        data.MRNdata(iy.DxID)=d{ix.data.MRN}(ind); % to check that everyone matched and no one got missed
        cnt=1;
        for jnd=ix.data.Use
            if jnd==ix.data.Gender
                data.retro(iy.DxID,cnt)=strcmp(d{ix.data.Gender}(ind),'F');
            else
                if jnd==max(ix.data.Use) && ind==n.retro.sub
                    data.retro(iy.DxID,cnt)=0;
                    fprintf('Check the bottom right entry of retrospective data \n');
                else
                    data.retro(iy.DxID,cnt)=d{jnd}(ind);
                end
            end
            cnt=cnt+1;
        end
    else
        error 'Doubles';
    end
end
clear cnt
if sum(data.MRNdata==data.MRNDx)==n.retro.sub 
    fprintf('All Retrospective Data Loaded\n');
    
    % Put zeros for non-imputed variables
    for jnd=ix.data.noimpute
        iz=find(isnan(data.retro(:,jnd)));
        if intersect(jnd,ix.retro.types) % everyone has at least one type of sz
            data.retro(iz,jnd)=1;
        elseif intersect(jnd,ix.retro.limbs) % number of limbs moving
            for znd=1:length(iz)
                % use sec gen and tonic clonic
                if isnan(data.retro(iz(znd),ix.retro.limbs+1)) 
                    if isnan(data.retro(iz(znd),ix.retro.secgen)) % both nan
                        data.retro(iz(znd),jnd)=0;
                    elseif data.retro(iz(znd),ix.retro.secgen) % secgen +
                        data.retro(iz(znd),jnd)=4;
                    end
                else
                    if data.retro(iz(znd),ix.retro.limbs+1) % tonic +
                        data.retro(iz(znd),jnd)=4;
                    elseif isnan(data.retro(iz(znd),ix.retro.secgen)) % limbs 0, tonic nan
                        data.retro(iz(znd),jnd)=0;
                    else
                        if data.retro(iz(znd),ix.retro.secgen) % limbs 0, tonic +
                            data.retro(iz(znd),jnd)=4;
                        else % limbs 0, tonic 0
                            data.retro(iz(znd),jnd)=0;
                        end
                    end
                end
            end
        else
            data.retro(iz,jnd)=0;
        end
    end
    for ind=ix.data.indicators
        tmp=find(data.retro(:,ind)>1); % These are supposed to be indicators
        if ~isempty(tmp)
            if length(tmp)>1
                fprintf(['Non-indicators present' heads.retro{ind} ',']);
                for jnd=1:length(tmp)
                    fprintf([num2str(tmp(jnd)) ';']);
                end
                fprintf('\n');
            else
                fprintf(['Non-indicators present' heads.retro{ind} ',' num2str(tmp) '\n']);
            end
            data.retro(tmp,ind)=1;
        end
    end
    n.class=5;
    ix.retro.classid=cell(n.class,1);
    ix.DxES=1;
    ix.DxPNES=5;
    ix.retro.classid{1}=find(data.Dx(:,1)>=1); % ES
    ix.retro.classid{2}=find(data.Dx(:,1)==-1); % PSLE
    ix.retro.classid{3}=find(data.Dx(:,1)==0); % Inconclusive
    ix.retro.classid{4}=find(data.Dx(:,1)==-5); % Mixed
    ix.retro.classid{5}=find(data.Dx(:,1)==-2); % PNES
    ix.retro.hazDx=find(data.Dx(:,2));
    if do.permutations
        fprintf(['Permuting with ' num2str(n.permutations) ' permutations\n']);
        data.perm.Dx=zeros(size(data.Dx,1),size(data.Dx,2),n.permutations);
        ix.perm.hazDx=zeros(length(ix.retro.hazDx),n.permutations);
        for rnd=1:n.permutations
            data.perm.Dx(:,:,rnd)=data.Dx(randperm(size(data.Dx,1)),:);
            ix.perm.hazDx(:,rnd)=find(data.perm.Dx(:,2,rnd));
            ix.perm.classid{1,rnd}=find(data.perm.Dx(:,1,rnd)>1);
            ix.perm.classid{2,rnd}=find(data.perm.Dx(:,1,rnd)==-1);
            ix.perm.classid{3,rnd}=find(data.perm.Dx(:,1,rnd)==0);
            ix.perm.classid{4,rnd}=find(data.perm.Dx(:,1,rnd)==-5);
            ix.perm.classid{5,rnd}=find(data.perm.Dx(:,1,rnd)==-2);
        end
    end
    data.class=zeros(n.retro.sub,n.class);
    n.retro.classes=zeros(n.class,1);
    for cnd=1:n.class
        data.class(ix.retro.classid{cnd},cnd)=1;
        n.retro.classes(cnd)=length(ix.retro.classid{cnd});
    end
    n.Dx=length(ix.retro.hazDx);
    data.prevalence=nansum(data.retro);
    ix.prev        =find(data.prevalence>cutoff.prevalence);
    if length(ix.prev)==size(data.retro,2)
        fprintf('No need to limit variables by prevalance\n');
    else
        error 'Need to limit variables by prevalence: modify later code';
    end
%     if ~laptop
        % Output data for Weka
        create_arff(dirs.retroarff,data.retro(ix.retro.hazDx,ix.prev),1*(data.Dx(ix.retro.hazDx,2)>0),2);
%         fprintf('Get full path\n');
%     end
end

% Calculate Onset based on Duration & Vice-verse
% iz1=find(isnan(data.retro(:,ix.retro.Dur)));
% iz2=find(isnan(data.retro(:,ix.retro.Ons)));
% if ~isempty(setdiff(iz1,iz2))
%     for ind=setdiff(iz1,iz2)
%         if data.retro(ind,ix.retro.Age)-data.retro(ind,ix.retro.Ons)<=0
%             data.retro(ind,ix.retro.Dur)=0.5; % assume 6 months
%             fprintf('Delays of zero are now 6 months \n');
%         else
%             data.retro(ind,ix.retro.Dur)=data.retro(ind,ix.retro.Age)-data.retro(ind,ix.retro.Ons);
%         end
%     end
%     for ind=setdiff(iz2,iz1)
%         if data.retro(ind,ix.retro.Age)-data.retro(ind,ix.retro.Dur)<=0
%             data.retro(ind,ix.retro.Ons)=1/365;
%         else
%             data.retro(ind,ix.retro.Ons)=data.retro(ind,ix.retro.Age)-data.retro(ind,ix.retro.Dur);
%         end
%     end
% end
% iz1=find(data.retro(:,ix.retro.Dur)==0);
% data.retro(iz1,ix.retro.Dur)=1/365;
% iz1=find(data.retro(:,ix.retro.Ons)==0);
% data.retro(iz1,ix.retro.Ons)=1/365;

% Transform the Data that Needs to be Transformed (SzF, SzDur)
data.retro(:,ix.retro.transform)=log(data.retro(:,ix.retro.transform));
% imagesc(data.retro(:,ix.retro.transform)./repmat(nanmean(data.retro(:,ix.retro.transform)),[size(data.retro,1) 1]));

ix.retro.missing=cell(length(ix.data.toimpute),1);
ix.retro.filled =ix.retro.missing;
n.retro.filled  =zeros(length(ix.data.toimpute),1);
cnt=0;
for jnd=ix.data.toimpute
    cnt=cnt+1;
    ix.retro.missing{cnt}=find(isnan(data.retro(:,jnd)));
    ix.retro.filled{cnt}=setdiff(1:n.retro.sub,ix.retro.missing{cnt});
    n.retro.filled(cnt)=length(ix.retro.filled{cnt});
end

%% Load the Prospective Data
fid=fopen(dirs.prospdata,'r');
h=textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Delimiter',',','Headerlines',1);
fclose(fid);
heads.prosp=cell(length(h),1);
for hnd=1:length(h)
    heads.prosp{hnd}=h{hnd}{1};
end

fid=fopen(dirs.prospdata,'r');
d=textscan(fid,'%f %s %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',2);
fclose(fid);
ix.prosp.MRNdata=1;
ix.prosp.date   =2;
ix.prosp.Age    =3;
ix.prosp.Gender =4;
ix.prosp.AoO    =5;
ix.prosp.toimpute=6:7;
ix.prosp.limbs  =33;
n.prosp.feats   =length(d)-2; % for MRN and date
ix.prosp.indicators=setdiff(9:n.prosp.feats,ix.prosp.limbs);
n.prosp.loaded  =length(d{1});

%% Check for Doubles, Patients in Retrospective, and align to Retrospective by MRN
data.prosp.MRN=zeros(n.prosp.loaded,2); %MRN,ix.prosp
n.prosp.sub=1;
for ind=1:n.prosp.loaded
    if isempty(intersect(data.MRNdata,d{ix.prosp.MRNdata}(ind))) % MRN not in retrospective
        if ind==1
            data.prosp.MRN(n.prosp.sub,1)=d{ix.prosp.MRNdata}(ind);
            data.prosp.MRN(n.prosp.sub,2)=ind;
        else
            if isempty(intersect(data.prosp.MRN,d{ix.prosp.MRNdata}(ind))) % checking for doubles
                n.prosp.sub=n.prosp.sub+1;
                data.prosp.MRN(n.prosp.sub,1)=d{ix.prosp.MRNdata}(ind);
                data.prosp.MRN(n.prosp.sub,2)=ind;
            else
                fprintf(['Removing doubles: MRN ' num2str(d{ix.prosp.MRNdata}(ind)) '\n'])
                % If there's a double, choose the earlier form
                iy.double=find(data.prosp.MRN==d{ix.prosp.MRNdata}(ind));
                olddate=datetonum(d{ix.prosp.date}{data.prosp.MRN(iy.double,2)});
                curdate=datetonum(d{ix.prosp.date}{ind});
                if curdate<olddate
                    data.prosp.MRN(iy.double,2)=ind;
                end
            end
        end
    end
end

%% import the data
data.prosp.full =zeros(n.prosp.sub,n.prosp.feats);
clear cnt
cnt.feat=0;
for ind=3:length(d)
    cnt.feat=cnt.feat+1;
    if isempty(intersect(ix.prosp.Gender,ind)) % numerical data
        if intersect(ix.prosp.AoO,ind) % double checking that AoO are within range
            for snd=1:n.prosp.sub
                if d{ix.prosp.AoO}(data.prosp.MRN(snd,2))>d{ix.prosp.Age}(data.prosp.MRN(snd,2))
                    if d{ix.prosp.AoO}(data.prosp.MRN(snd,2))>cutoff.year % its a year
                        dateinterview=str2num(d{ix.prosp.date}{data.prosp.MRN(snd,2)}(end-1:end))+2000;
                        data.prosp.full(snd,cnt.feat)=d{ix.prosp.Age}(data.prosp.MRN(snd,2))-(dateinterview-d{ix.prosp.AoO}(data.prosp.MRN(snd,2)));
                        fprintf(['Fixing an AoO-year problem: MRN ' num2str(d{ix.prosp.MRNdata}(data.prosp.MRN(snd,2))) '\n']);
                    else
                        error 'Age of onset higher than age but is not a year'
                    end
                else
                    data.prosp.full(snd,cnt.feat)=d{ind}(data.prosp.MRN(snd,2));
                end
            end
        elseif intersect(ix.prosp.Age,ind) % double checking that ages are within range
            for snd=1:n.prosp.sub
                if d{ind}(data.prosp.MRN(snd,2))>cutoff.age
                    error 'Age>150';
                else
                    data.prosp.full(snd,cnt.feat)=d{ind}(data.prosp.MRN(snd,2));
                end
            end
        elseif ind==length(d)
            if length(d{ind})-1==length(d{ind-1}) % bottom right corner mistake
                fprintf('Making the bottom right corner zero\n');
                data.prosp.full(1:end-1,cnt.feat)=d{ind}(setdiff(data.prosp.MRN(1:n.prosp.sub,2),length(d{ind-1})));
            end
        else
            data.prosp.full(:,cnt.feat)=d{ind}(data.prosp.MRN(1:n.prosp.sub,2));
        end
    else % strings
        if intersect(ix.prosp.Gender,ind)
            data.prosp.full(:,cnt.feat)=strcmp(d{ind}(data.prosp.MRN(1:n.prosp.sub,2)),'F')+strcmp(d{ind}(data.prosp.MRN(1:n.prosp.sub,2)),'f');
        else
            error 'what other strings are there?'
        end
    end
end
% filling in zero for the values that we're not treating as missing
% check for non-indicators while we are here
for fnd=1:length(ix.prosp.indicators)
    ix.tmp=find(data.prosp.full(:,ix.prosp.indicators(fnd)-ix.prosp.date)>1);
    if ~isempty(ix.tmp)
        fprintf(['Non-indicators present' heads.prosp{ix.prosp.indicators(fnd)} ',' num2str(ix.tmp(1)) '\n']);
%         fprintf(['Nonindicators present ' heads.prosp{ix.prosp.ind(fnd)} ]);
        for snd=1:length(ix.tmp)
            fprintf([num2str(ix.tmp(snd)) ',']);
        end
        fprintf('\n');
    end
    ix.tmp=find(isnan(data.prosp.full(:,ix.prosp.indicators(fnd)-ix.prosp.date)));
    data.prosp.full(ix.tmp,ix.prosp.indicators(fnd)-ix.prosp.date)=0;
end

%% Load Prospective Diagnoses
fid=fopen(dirs.prospDx,'r'); % has the f/u column
d=textscan(fid,'%f %s %s %f %f %f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',2);
fclose(fid);
ix.prosp.MRNDx=1;
ix.prosp.Dx=5;
ix.prosp.Dxdate=2;
data.prosp.Dx=ones(n.prosp.sub,2)*-7;
n.misDx=0;
for snd=1:n.prosp.sub
    iy.Dx=find(d{1}==data.prosp.MRN(snd,1));
    if isempty(iy.Dx)
        n.misDx=n.misDx+1;
        fprintf(['Missing Prosp Dx ' num2str(n.misDx) ':' num2str(data.prosp.MRN(snd,1)) '\n']);
        data.prosp.Dx(snd,:)=NaN;
    else
        if length(iy.Dx)==1
            data.prosp.Dx(snd,1)=d{ix.prosp.Dx}(iy.Dx);
        else
            % If multiple matches, find the most recent Dx
            dates=zeros(length(iy.Dx),1);
            for dnd=1:length(iy.Dx)
                dates(dnd)=datetonum(d{ix.prosp.Dxdate}{iy.Dx(dnd)});
            end
            [newdate, iy.new]=max(dates);
            data.prosp.Dx(snd,1)=d{ix.prosp.Dx}(iy.Dx(iy.new));
        end
    end
end
data.prosp.Dx(:,2)=((data.prosp.Dx(:,1)>0)+(data.prosp.Dx(:,1)<0)*-1).*(data.prosp.Dx(:,1)~=-5);

ix.prosp.classid{1}=find(data.prosp.Dx(:,1)>1); % ES
ix.prosp.classid{2}=find(data.prosp.Dx(:,1)==-1); % PSLE
ix.prosp.classid{3}=find(data.prosp.Dx(:,1)==0); % Inconclusive
ix.prosp.classid{4}=find(data.prosp.Dx(:,1)==-5); % Mixed
ix.prosp.classid{5}=find(data.prosp.Dx(:,1)==-2); % PNES
heads.class={'ES','PSLE','Inc','Mixed','PNES'};
ix.prosp.hazDx=find(data.prosp.Dx(:,2));
data.prosp.class=zeros(n.prosp.sub,n.class);
n.prosp.classes=zeros(n.class,1);
for cnd=1:n.class
    data.prosp.class(ix.prosp.classid{cnd},cnd)=1;
    n.prosp.classes(cnd)=length(ix.prosp.classid{cnd});
end
n.prosp.Dx=length(ix.prosp.hazDx);

ix.prosp.hazDx=find(data.prosp.Dx(:,2));
ix.prosp.incDx=find(data.prosp.Dx(:,1)==0);
ix.prosp.mixDx=find(data.prosp.Dx(:,1)==-5);
n.prosp.Dx=length(ix.prosp.hazDx);
n.prosp.inc=length(ix.prosp.incDx);
n.prosp.mix=length(ix.prosp.mixDx);
    
%% Match Prospective Columns to Retrospective Columns
if ~exist(dirs.pro2ret,'file')
    fid=fopen(dirs.pro2ret,'w');
    fprintf(fid,'ix.retro,Retrospective Column,ix.ret2pro\n');
    for jnd=1:length(heads.retro)
        fprintf(fid,[num2str(jnd) ',' heads.retro{jnd} '\n']);
    end
    fprintf(fid,'\n');
    fprintf(fid,'ix.prosp,Prospective Column\n');
    for jnd=1:length(heads.prosp)
        fprintf(fid,[num2str(jnd) ',' heads.prosp{jnd} '\n']);
    end
    fclose(fid);
    error 'Create the column map for prosp to retro'
end
data.prosp.testp=zeros(n.prosp.sub,size(data.retro,2));
fid=fopen(dirs.pro2ret,'r');
d=textscan(fid,'%f %s %f %f %f %f %s','Headerlines',1,'Delimiter',',');
fclose(fid);
ix.ret2pro=3;
ix.ret2pro2=4;
ix.retro.head=17;
ix.retro.gaze=24;
ix.retro.nopro=[];
for fnd=1:size(data.retro,2)
    if ~isnan(d{ix.ret2pro2}(fnd)) % This is a special variable
%         if intersect(ix.retro.Dur,fnd) % Duration
            % Age minus AoO
%             data.prosp.testp(:,fnd)=data.prosp.full(:,d{ix.ret2pro2+1}(fnd)-2)-data.prosp.full(:,d{ix.ret2pro2}(fnd)-2);
%     else
        if intersect([ix.retro.head,ix.retro.gaze],fnd) % Head movements, gaze deviation
            data.prosp.testp(:,fnd)=1*(sum(data.prosp.full(:,(d{ix.ret2pro}(fnd)-2):(d{ix.ret2pro2}(fnd)-2)),2)>0);
        else % we shouldnt get here
            error 'Misread variable'
        end
    else
        if isnan(d{ix.ret2pro}(fnd))
            ix.retro.nopro=[ix.retro.nopro,fnd];
        else
            data.prosp.testp(:,fnd)=data.prosp.full(:,d{ix.ret2pro}(fnd)-2);
        end
    end
end
data.prosp.testp(:,ix.retro.transform)=log(data.prosp.testp(:,ix.retro.transform));
% Fill in zeros for data we're not imputing
for jnd=ix.data.noimpute
    iz=find(isnan(data.prosp.testp(:,jnd)));
    if intersect(jnd,ix.retro.types) % everyone has at least one type of sz
        data.prosp.testp(iz,jnd)=1;
    elseif intersect(jnd,ix.retro.limbs) % number of limbs moving
        for znd=1:length(iz)
            % use sec gen and tonic clonic
            if isnan(data.prosp.testp(iz(znd),ix.retro.limbs+1))
                if isnan(data.prosp.testp(iz(znd),ix.retro.secgen)) % both nan
                    data.prosp.testp(iz(znd),jnd)=0;
                elseif data.prosp.testp(iz(znd),ix.retro.secgen) % secgen +
                    data.prosp.testp(iz(znd),jnd)=4;
                end
            else
                if data.prosp.testp(iz(znd),ix.retro.limbs+1) % tonic +
                    data.prosp.testp(iz(znd),jnd)=4;
                elseif isnan(data.prosp.testp(iz(znd),ix.retro.secgen)) % limbs 0, tonic nan
                    data.prosp.testp(iz(znd),jnd)=0;
                else
                    if data.prosp.testp(iz(znd),ix.retro.secgen) % limbs 0, tonic +
                        data.prosp.testp(iz(znd),jnd)=4;
                    else % limbs 0, tonic 0
                        data.prosp.testp(iz(znd),jnd)=0;
                    end
                end
            end
        end
    else
        data.prosp.testp(iz,jnd)=0;
    end
end

%% Population-Level Descriptive Statistics
data.all.testp=[data.retro;data.prosp.testp];
data.all.Dx   =[data.Dx;data.prosp.Dx];
data.all.class=[data.class;data.prosp.class];

out.descrip.mo=zeros(3+size(data.all.class,2)-1,n.retro.vars+1);
out.descrip.dev=zeros(n.retro.vars+1,1);
out.descrip.se=out.descrip.mo;
out.descrip.p =out.descrip.mo;
ix.descrip.class=[1,4:size(out.descrip.mo,1)];
clear tmp;
fprintf('Removing Age from all descriptive models\n');
for fnd=1:n.retro.vars
    tmp.excluded=0;
    ix.Y=fnd;
    ix.X=setdiff([ix.retro.Age,ix.retro.Gender],fnd);
    if intersect([ix.retro.Age,ix.retro.Gender],fnd)
        tmp.excluded=1;
    end
    modeldata.Xd=[data.all.testp(:,ix.X),data.all.class(:,2:end)];
    modeldata.Yd=data.all.testp(:,ix.Y);
    warning off
    if intersect(ix.data.indicators,fnd)
        if tmp.excluded
            [out.descrip.mo([1,3:end],fnd),out.descrip.dev(fnd),tmp.filler]=glmfit(modeldata.Xd,modeldata.Yd,'binomial','link','logit');
        else
            [out.descrip.mo(:,fnd),out.descrip.dev(fnd),tmp.filler]=glmfit(modeldata.Xd,modeldata.Yd,'binomial','link','logit');
        end
    else
        if tmp.excluded
            [out.descrip.mo([1,3:end],fnd),out.descrip.dev(fnd),tmp.filler]=glmfit(modeldata.Xd,modeldata.Yd);
        else
            [out.descrip.mo(:,fnd),out.descrip.dev(fnd),tmp.filler]=glmfit(modeldata.Xd,modeldata.Yd);
        end
    end
    warning on
    if tmp.excluded
        out.descrip.se([1,3:end],fnd)=tmp.filler.se;
        out.descrip.p([1,3:end],fnd)=tmp.filler.p;
    else
        out.descrip.se(:,fnd)=tmp.filler.se;
        out.descrip.p(:,fnd)=tmp.filler.p;
    end

end

fprintf('Make descriptive output of predicted means and CIs for each group\n');
dirs.descrip  =[dirs.analysis 'Semiology_Descrip_Class.csv'];
fid=fopen(dirs.descrip,'w');
fprintf(fid,',');
for cnd=1:n.class
    fprintf(fid,[heads.class{cnd} ',,,']);
end
fprintf(fid,'\nVariable,');
for cnd=1:n.class
    fprintf(fid,'Mean,SE,p,');
end
fprintf(fid,'\n');
for fnd=1:n.retro.vars
    fprintf(fid,[heads.retro{fnd} ',']);
    for cnd=1:n.class
        fprintf(fid,[num2str(out.descrip.mo(ix.descrip.class(cnd),fnd)) ',']);
        fprintf(fid,[num2str(out.descrip.se(ix.descrip.class(cnd),fnd)) ',']);
        fprintf(fid,[num2str(out.descrip.p (ix.descrip.class(cnd),fnd)) ',']);
    end
    fprintf(fid,'\n');
end
fclose(fid);

summary.pairwise=zeros(n.class,n.class,n.retro.vars,3);
for znd=1:n.retro.vars
    for cnd=1:n.class
        for vnd=cnd+1:n.class
            if cnd==1
                summary.pairwise(cnd,vnd,znd,1)=-out.descrip.mo(ix.descrip.class(vnd),znd); % ES was coded as an intercept
            else
                summary.pairwise(cnd,vnd,znd,1)=out.descrip.mo(ix.descrip.class(cnd),znd)-out.descrip.mo(ix.descrip.class(vnd),znd); % mean dif
            end
            summary.pairwise(cnd,vnd,znd,2)=sqrt(out.descrip.se(ix.descrip.class(cnd),znd)^2+out.descrip.se(ix.descrip.class(vnd),znd)^2); % SE
            summary.pairwise(cnd,vnd,znd,3)=2*normcdf(-abs(summary.pairwise(cnd,vnd,znd,1)),0,summary.pairwise(cnd,vnd,znd,2));
        end
    end
end

fid=fopen(dirs.pairwise,'w');
fprintf(fid,'Variable/Class,P-value of difference,,,,,Z-difference\n');
for znd=1:n.retro.vars
    fprintf(fid,heads.retro{znd});
    for cnd=2:n.class
        fprintf(fid,[',' heads.class{cnd}]);
    end
    for cnd=2:n.class
        fprintf(fid,[',' heads.class{cnd}]);
    end
    fprintf(fid,'\n');
    for cnd=1:n.class-1
        fprintf(fid,[heads.class{cnd}]);
        for vnd=2:n.class
            fprintf(fid,[',' num2str(summary.pairwise(cnd,vnd,znd,3))]);
        end
        for vnd=2:n.class
            fprintf(fid,[',' num2str(summary.pairwise(cnd,vnd,znd,1))]);
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

%% Individual-Level Predictive Statistics

%% Multiple Imputation
ix.retro.misvar=ix.retro.transform;
n.retro.misvar=length(ix.retro.misvar);
trees.binary=cell(n.imputations,1);
trees.fullcl=cell(n.imputations,1);
% feature to use for each type of imputation
ix.retro.usetoimpute=cell(n.retro.misvar,1);
for jnd=1:n.retro.misvar
%     if jnd<3
%         ix.retro.usetoimpute{jnd}=setdiff(1:n.retro.vars,[ix.retro.Dur ix.retro.Ons]);
%         % duration & onset variables
%     else
        ix.retro.usetoimpute{jnd}=setdiff(2:n.retro.vars,jnd+2); % excluding age
%     end
end
% Set up output variables
data.retrofilled=repmat(data.retro,[1 1 n.imputations]);
if do.mi.classinfo
    mi.mo=zeros(length(ix.retro.usetoimpute{1})+1+n.class-1,n.retro.misvar,n.imputations); % Fix this size for the class data
else
    mi.mo=zeros(length(ix.retro.usetoimpute{1})+1,n.retro.misvar,n.imputations); % Fix this size for the class data
end
mi.dev=zeros(n.iterations,n.retro.misvar,n.imputations);
if do.age
    out.mi.mo=zeros(size(data.retro,2)+1,n.imputations); % age is the intercept
else
    out.mi.mo=zeros(size(data.retro,2),n.imputations); % age is the intercept
end
out.mi.se=out.mi.mo;
out.mi.dev=zeros(n.imputations,1);
out.mi.pred=zeros(n.prosp.Dx,n.imputations,3);
out.mi.tree.pred=zeros(n.prosp.Dx,n.imputations);
out.mi.tree.mo=zeros(size(out.mi.mo));
out.mi.oth.pred=zeros(max(n.retro.classes(2:4)+n.prosp.classes(2:4)),n.imputations,3,3);
out.mi.oth.tree.pred=zeros(max(n.retro.classes(2:4)+n.prosp.classes(2:4)),n.imputations,3);
if do.permutations
    fprintf('Right now we do this the time-intensive way of optimizing the tree of each perm\n');
    fprintf('For debugging, consider speeding this up by passing the optimal value\n');
    out.perm.mi.mo       =zeros(size(out.mi.mo,1),size(out.mi.mo,2),n.permutations);
    out.perm.mi.se       =out.perm.mi.mo;
    out.perm.mi.dev      =zeros(size(out.mi.dev,1),n.permutations);
    out.perm.mi.pred     =zeros(size(out.mi.pred,1),size(out.mi.pred,2),n.permutations);
    out.perm.mi.tree.pred=zeros(size(out.mi.pred,1),size(out.mi.pred,2),n.permutations);
    out.perm.mi.tree.mo  =zeros(size(out.perm.mi.mo));
    trees.perm.binary    =cell(n.imputations,n.permutations);
    if do.fiveclass
        trees.perm.fullcl    =cell(n.imputations,n.permutations);
    end
end
mi.misvar=cell(4,1);
fprintf('Imputing\n');
for mnd=1:n.imputations
    % Fill in initial values with cold deck imputation
    for jnd=2:n.retro.misvar % doing duration and onset together
        for snd=1:(n.retro.sub-n.retro.filled(jnd))
            r=ceil(rand()*n.retro.filled(jnd));
            data.retrofilled(ix.retro.missing{jnd}(snd),ix.retro.misvar(jnd),mnd)=data.retro(ix.retro.filled{jnd}(r),ix.retro.misvar(jnd));
            if jnd==2
                data.retrofilled(ix.retro.missing{jnd}(snd),ix.retro.misvar(jnd-1),mnd)=data.retro(ix.retro.filled{jnd}(r),ix.retro.misvar(jnd-1));
            end
        end
    end    
    % Impute
    for iind=1:n.iterations
        mi.disperse=exp(mi.scale*iind)+1; % to scale the SE in the regressions
        cnt.retro.misvar=0;
        for fnd=ix.retro.misvar
            cnt.retro.misvar=cnt.retro.misvar+1;
            ix.retro.ToImpute=fnd;
            modeldata.Ym=data.retrofilled(:,fnd,mnd);
            if do.mi.classinfo
                modeldata.Xm=[data.retrofilled(:,ix.retro.usetoimpute{cnt.retro.misvar},mnd) data.class(:,2:n.class)]; % class data is part of MI, treat ES as baseline
            else
                modeldata.Xm=data.retrofilled(:,ix.retro.usetoimpute{cnt.retro.misvar},mnd); % class data is NOT part of MI
            end
%             if fnd<=ix.retro.Ons % Duration or Onset
%                 if intersect(fnd,ix.retro.Dur)
%                     mi.misvar{cnt.retro.misvar}='Duration';
%                 elseif intersect(fnd,ix.retro.Ons)
%                     mi.misvar{cnt.retro.misvar}='Onset';
%                 else
%                     error 'more missingness?'
%                 end
%                 % model the log!
%                 [mi.mo(:,cnt.retro.misvar,mnd),mi.dev(iind,cnt.retro.misvar,mnd),mi.stats]=glmfit(modeldata.Xm,modeldata.Ym,'normal','link','log');
%                 [proposed.M,proposed.LB,proposed.UB]=glmval(mi.mo(:,cnt.retro.misvar,mnd),modeldata.Xm(ix.retro.missing{cnt.retro.misvar},:),'log',mi.stats);
%                 proposed.raw=[proposed.M proposed.M-proposed.LB proposed.M+proposed.UB];
%                 proposed.trans=log(proposed.raw);
%                 proposed.SE=(proposed.trans(:,1)-proposed.trans(:,2))*mi.disperse;
%                 for ssnd=1:length(ix.retro.missing{cnt.retro.misvar})
%                     tmp.log=randn()*proposed.SE(ssnd)+proposed.trans(ssnd,1); 
%                     % Check to see if 1/365<=Duration<=Age, if not, round
%                     if exp(tmp.log)>=data.retro(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Age)
%                         data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),fnd,mnd)=ix.retro.Age-1/365;
%                     elseif exp(tmp.log)<1/365
%                         data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),fnd,mnd)=1/365;
%                     else
%                         data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),fnd,mnd)=exp(tmp.log);
%                     end
%                     if fnd==ix.retro.Ons % check to see that duration + onset = Age
%                         % if it doesn't, then shink each equally to make it
%                         % so
%                         tmp.Age=data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Dur,mnd)+data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Ons,mnd);
%                         if tmp.Age~=data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Age,mnd)
%                             tmp.AgeDif=tmp.Age-data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Age,mnd);
%                             data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Ons,mnd)=data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Ons,mnd)-tmp.AgeDif/2;
%                             data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Dur,mnd)=data.retrofilled(ix.retro.missing{cnt.retro.misvar}(ssnd),ix.retro.Dur,mnd)-tmp.AgeDif/2;
%                         end
%                     end
%                 end
%             else
                mi.misvar{cnt.retro.misvar}=heads.retro{fnd};
                if fnd>max(ix.retro.transform)
                    error 'Confused'
                end
                [mi.mo(:,cnt.retro.misvar,mnd),mi.dev(iind,cnt.retro.misvar,mnd),mi.stats]=glmfit(modeldata.Xm,modeldata.Ym,'normal');
                [proposed.M,proposed.LB,proposed.UB]=glmval(mi.mo(:,cnt.retro.misvar,mnd),modeldata.Xm(ix.retro.missing{cnt.retro.misvar},:),'identity',mi.stats);
                %                 proposed.raw=[proposed.M proposed.M-proposed.LB proposed.M+proposed.UB];
                proposed.trans=[proposed.M proposed.M-proposed.LB proposed.M+proposed.UB];
                proposed.SE=(proposed.trans(:,1)-proposed.trans(:,2))*mi.disperse;
                % vector fill in
                data.retrofilled(ix.retro.missing{cnt.retro.misvar},fnd,mnd)=randn([n.retro.sub-n.retro.filled(cnt.retro.misvar),1]).*proposed.SE+proposed.trans(:,1);
%             end % fill in loop
        end % feature loop
    end % iteration loop
    
    fprintf(['   Imputation ' num2str(mnd) ' done\n']);
    
    %% Fit the predictive model and predict the prospective data
    %     ix.classuse=setdiff(1:size(data.retro,2),[ix.retro.Age,ix.retro.Dur,ix.retro.Ons]);
    if ~do.age
        ix.classuse=setdiff(1:size(data.retro,2),ix.retro.Age);
    else
        ix.classuse=1:size(data.retro,2);
    end
    modeldata.Xr=data.retrofilled(ix.retro.hazDx,ix.classuse,mnd);
%     fprintf('Fix collinearity of Age/AoO/Dur: currently excluding Age\n');
%     fprintf('Think about log transforming the AoO/Dur');
    modeldata.Yr=(data.Dx(ix.retro.hazDx,2)==1)*1;
    create_arff([dirs.retroarff '_' num2str(mnd) ],modeldata.Xr,modeldata.Yr,2);

    [out.mi.mo(:,mnd),out.mi.dev(mnd),tmp.out.mi.stats]=glmfit(modeldata.Xr,modeldata.Yr,'binomial','link','logit');
    out.mi.se(:,mnd)=tmp.out.mi.stats.se;
    trees.binary{mnd}=fitctree(modeldata.Xr,modeldata.Yr,'OptimizeHyperparameters','auto','AlgorithmForCategorical','Exact','PredictorNames',{heads.retro{ix.classuse}});
    close all;pause(0.00001);
    out.mi.tree.mo(2:end,mnd)=predictorImportance(trees.binary{mnd});
    if do.fiveclass
        modeldata.X5=data.retrofilled(:,ix.classuse,mnd);
        tmp.Dx=data.Dx(:,1);
        iz=find(tmp.Dx>0);
        tmp.Dx(iz)=1; % Simplifying all ES to one class, because we're already bad at things
        modeldata.Y5=tmp.Dx;
        trees.fullcl{mnd}=fitctree(modeldata.X5,modeldata.Y5,'OptimizeHyperparameters','auto','AlgorithmForCategorical','Exact','PredictorNames',{heads.retro{ix.classuse}});
        close all;pause(0.00001);
    end
    % fix the output of stats to save the important parts
    if do.permutations
        for rnd=1:n.permutations
            modeldata.Yperm=squeeze((data.perm.Dx(ix.perm.hazDx(:,rnd),2)==1)*1);
            warning off
            [out.perm.mi.mo(:,mnd,rnd),out.perm.mi.dev(mnd,rnd),tmp.out.perm.mi.stats]=glmfit(modeldata.Xr,modeldata.Yperm,'binomial','link','logit');
            out.perm.mi.se(:,mnd,rnd)=tmp.out.perm.mi.stats.se;
            trees.perm.binary{mnd,rnd}=fitctree(modeldata.Xr,modeldata.Yperm,'OptimizeHyperparameters','auto','AlgorithmForCategorical','Exact','PredictorNames',{heads.retro{ix.classuse}});
            close all;pause(0.00001);
            out.perm.mi.tree.mo(2:end,mnd,rnd)=predictorImportance(trees.perm.binary{mnd,rnd});
            if do.fiveclass
                tmp.Dx=data.perm.Dx(:,1);
                iz=find(tmp.Dx>0);
                tmp.Dx(iz)=1;
                modeldata.Yperm5=tmp.Dx;
                trees.perm.fullcl{mnd,rnd}=fitctree(modeldata.X5,modeldata.Yperm5,'OptimizeHyperparameters','auto','AlgorithmForCategorical','Exact','PredictorNames',{heads.retro{ix.classuse}});
                close all;pause(0.00001);
            end
            warning on
            if round(rnd/10)==rnd/10
                fprintf(['.\n .\n .\n .\n .\n .\nImputation ' num2str(mnd) ' Perm ' num2str(rnd) '/' num2str(n.permutations) '\n .\n .\n .\n .\n .\n .\n']);
            end
        end
    end
    
    %% predict the prospective, inconclusives, mixed, and PSLE
    fprintf(['   Predicting the prospective with model ' num2str(mnd) '\n']);
    modeldata.Xp=data.prosp.testp(ix.prosp.hazDx,ix.classuse);
    for fnd=1:size(modeldata.Xp,2)
        tmp.mis=find(isnan(modeldata.Xp(:,fnd)));
        if ~isempty(tmp.mis)
            if mnd==1
                fprintf(['Fill in ' num2str(length(tmp.mis)) ' missing ' heads.retro{fnd+1} ' data for the prospective\n']);
            end
            %             if intersect(ix.retro.Dur-1,fnd) % note age was removed from ix.classuse
            %                 proposed.M=glmval(mi.mo(:,1,mnd),data.prosp.testp(tmp.mis,ix.retro.usetoimpute{1}),'log');
            %                 for snd=1:length(tmp.mis)
            %                     % Check to see if 1/365<=Duration<=Age, if not, round
            %                     if proposed.M(snd)>=data.prosp.testp(tmp.mis(snd),ix.retro.Age)
            %                         modeldata.Xp(tmp.mis(snd),fnd)=data.prosp.testp(tmp.mis(snd),ix.retro.Age)-1/365;
            %                     elseif proposed.M(snd)<1/365
            %                         modeldata.Xp(tmp.mis(snd),fnd)=1/365;
            %                     else
            %                         modeldata.Xp(tmp.mis(snd),fnd)=proposed.M(snd);
            %                     end
            %                 end
            %             elseif intersect(ix.retro.Ons-1,fnd)
            %                 proposed.M=glmval(mi.mo(:,2,mnd),data.prosp.testp(tmp.mis,ix.retro.usetoimpute{2}),'log');
            %                 for snd=1:length(tmp.mis)
            %                     % Check to see if 1/365<=Duration<=Age, if not, round
            %                     if proposed.M(snd)>=data.prosp.testp(tmp.mis(snd),ix.retro.Age)
            %                         modeldata.Xp(tmp.mis(snd),fnd)=data.prosp.testp(tmp.mis(snd),ix.retro.Age)-1/365;
            %                     elseif proposed.M(snd)<1/365
            %                         modeldata.Xp(tmp.mis(snd),fnd)=1/365;
            %                     else
            %                         modeldata.Xp(tmp.mis(snd),fnd)=proposed.M(snd);
            %                     end
            %                 end
            %             else
            if do.age
                if intersect(ix.retro.transform,fnd)
                    % fnd-2 to make a 3-2->1, and 4-2->2 (working with
                    % modeldata.Xp indices, not raw
                    modeldata.Xp(tmp.mis,fnd)=glmval(mi.mo(:,fnd-2,mnd),data.prosp.testp(tmp.mis,ix.retro.usetoimpute{fnd-2}),'identity');
                else
                    error 'missing prospective data that we do not have a model for or SzDur/SzF';
                end
            else
                if intersect(ix.retro.transform-1,fnd)
                    % fnd+1-2 to make a 5-1->3, and 6-1->4 (working with
                    % modeldata.Xp indices, not raw
                    modeldata.Xp(tmp.mis,fnd)=glmval(mi.mo(:,fnd+1-2,mnd),data.prosp.testp(tmp.mis,ix.retro.usetoimpute{fnd+1-2}),'identity');
                else
                    error 'missing prospective data that we do not have a model for or SzDur/SzF';
                end
            end
        end
    end
    % fixing to make sure Dur+Ons==Age
%     tmp.checkAge=modeldata.Xp(:,ix.retro.Ons-1)+modeldata.Xp(:,ix.retro.Dur-1);
%     tmp.Agemis  =find(tmp.checkAge~=data.prosp.testp(ix.prosp.hazDx,ix.retro.Age));
%     if ~isempty(tmp.Agemis)
%         for ssnd=1:length(tmp.Agemis)
%             tmp.AgeDif=tmp.checkAge(tmp.Agemis(ssnd))-data.prosp.testp(ix.prosp.hazDx(tmp.Agemis(ssnd)),ix.retro.Age);
%             if isnan(tmp.AgeDif)
%                 fprintf('Missing a prospective age\n');
%             else
%                 modeldata.Xp(tmp.Agemis(ssnd),ix.retro.Ons-1)=modeldata.Xp(tmp.Agemis(ssnd),ix.retro.Ons-1)-tmp.AgeDif/2;
%                 modeldata.Xp(tmp.Agemis(ssnd),ix.retro.Dur-1)=modeldata.Xp(tmp.Agemis(ssnd),ix.retro.Dur-1)-tmp.AgeDif/2;
%             end
%         end
%     end    
    % predicting the prospectives
    [out.mi.pred(:,mnd,1),out.mi.pred(:,mnd,2),out.mi.pred(:,mnd,3)]=glmval(out.mi.mo(:,mnd),modeldata.Xp,'logit',tmp.out.mi.stats);
    out.mi.tree.pred(:,mnd)=predict(trees.binary{mnd},modeldata.Xp);
    if do.permutations
        for rnd=1:n.permutations
            out.perm.mi.pred(:,mnd,rnd)=glmval(out.perm.mi.mo(:,mnd,rnd),modeldata.Xp,'logit');
            out.perm.mi.tree.pred(:,mnd,rnd)=predict(trees.perm.binary{mnd,rnd},modeldata.Xp);
        end
    end
    % Predict PSLE, Inconclusive, Mixed from both retro & prosp
    cnt.dx=0;
    for dnd=2:4 
        cnt.dx=cnt.dx+1;
        modeldata.Xp=[data.retrofilled(ix.retro.classid{dnd},ix.classuse,mnd);data.prosp.testp(ix.prosp.classid{dnd},ix.classuse)];
        [out.mi.oth.pred(1:size(modeldata.Xp,1),mnd,1,cnt.dx),mi.out.oth.pred(1:size(modeldata.Xp,1),mnd,2,cnt.dx),out.mi.oth.pred(1:size(modeldata.Xp,1),mnd,3,cnt.dx)]=glmval(out.mi.mo(:,mnd),modeldata.Xp,'logit',tmp.out.mi.stats);
        out.mi.oth.tree.pred(1:size(modeldata.Xp,1),mnd,cnt.dx)=predict(trees.binary{mnd},modeldata.Xp);
    end
    close all;
end % imputation loop

%% Determine significance of the model, both using distributional assumptions and permutations

% Distributional Assumptions First
% Rubin 1987 
% Barnard & Rubin 1999 - for updated degrees of freedom does not apply bc
% we have lots of degrees of freedom in the complete-data
out.mo.est =mean(out.mi.mo,2);
out.mi.win =mean(out.mi.se.^2,2);
out.mi.btwn=var(out.mi.mo')';
out.mi.com =out.mi.win+(1+1/n.imputations)*out.mi.btwn;
out.mo.tsta=out.mo.est./(out.mi.com).^(1/2);
out.mo.df  =(n.imputations-1)*(1+out.mi.win./out.mi.btwn/(1+1/n.imputations)).^2;
% out.mi.gamma=(1+1/n.imputatons)*out.mi.btwn./out.mi.com;
out.mo.p=zeros(size(out.mo.est));
for fnd=1:length(out.mo.est)
    out.mo.p(fnd)=tcdf(-abs(out.mo.tsta(fnd)),out.mo.df(fnd))*2;
end

% Permutations
if do.permutations
    out.perm.mo.est =squeeze(mean(out.perm.mi.mo,2));
    out.perm.mi.win =squeeze(mean(out.perm.mi.se.^2,2));
    out.perm.mi.btwn=squeeze(var(permute(out.perm.mi.mo,[2,1,3])));
    out.perm.mi.com =out.perm.mi.win+(1+1/n.imputations)*out.perm.mi.btwn;
    out.perm.mo.tsta=out.perm.mo.est./(out.perm.mi.com).^(1/2);
    out.mo.phat=zeros(size(out.mo.est));
    out.mo.CI  =zeros(size(out.mo.est,1),2);
    for fnd=1:length(out.mo.est)
        out.mo.phat(fnd)=sum(abs(out.mo.tsta(fnd))<=abs(out.perm.mo.tsta(fnd,:)))/n.permutations;
        tmp.filler=sort(squeeze(out.perm.mo.est(fnd,:)));
        out.mo.CI(fnd,1)=tmp.filler(max(1,floor(0.025*n.permutations)));
        out.mo.CI(fnd,2)=tmp.filler(ceil( 0.975*n.permutations));
    end
end

fid=fopen(dirs.retrosum,'w');
fprintf(fid,'Variable,Weight,SEWeight,phat\n');
for ind=1:length(out.mo.est)
    if do.age 
        if ind==1
            fprintf(fid,'Intercept,');
        else
            fprintf(fid,[heads.retro{ind-1} ',']);
        end
    elseif ind==1 
        fprintf(fid,'Intercept,');
%         fprintf('Assuming you excluded Age\n'); ***
    else
        fprintf(fid,[heads.retro{ind} ',']);
    end
    if do.permutations
        fprintf(fid,[num2str(out.mo.est(ind)) ',' num2str(sqrt(out.mi.com(ind))) ',' num2str(out.mo.phat(ind)) '\n']);
    else
        fprintf(fid,[num2str(out.mo.est(ind)) ',' num2str(sqrt(out.mi.com(ind))) ',' num2str(out.mo.p(ind)) '\n']);
    end
end
fclose(fid);

figure;
% rescaling AoO/Dur to decades
if exist('ix.retro.Dur','var')
    out.rescale=(ones(1,length(ix.classuse))+9*(ix.classuse(end:-1:1)==ix.retro.Dur)+9*(ix.classuse(end:-1:1)==ix.retro.Ons))';
else
    out.rescale=ones(1,length(out.mo.est)-1);
end
barmod=barh(out.mo.est(end:-1:2).*out.rescale','BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
set(gca,'fontsize',18);
set(gca,'ytick',1:length(ix.classuse),'yticklabel',{heads.retro{ix.classuse(end:-1:1)}});
set(gca,'ylim',[0.5 length(ix.classuse)+0.5]);
set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
set(gca,'xlim',log([1/5 5]));
xlabel('PNES <- Odds Ratio -> ES');
hold on
if do.permutations
    barerrLB=barh(out.mo.CI(end:-1:2,1).*out.rescale,'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    barerrUB=barh(out.mo.CI(end:-1:2,2).*out.rescale,'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
else
    ebs=errbar(out.mo.est(end:-1:2).*out.rescale',1:length(out.rescale)',1.96*sqrt(out.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
end
hold off

%% Limiting to just significant predictors to get accurate intercept
if n.imputations>=10000
    ix.sigpred=find(out.mo.phat<0.05);
else
    ix.sigpred=find(out.mo.p<0.05);
end
if ~isempty(intersect(1,ix.sigpred)) % Remove the Intercept
    ix.sigpred=ix.sigpred(2:end);
end
out.sig.mi.mo=zeros(length(ix.sigpred)+1,n.imputations);
out.sig.mi.se=out.sig.mi.mo;
out.perm.sig.mi.mo=zeros(length(ix.sigpred)+1,n.imputations,n.permutations);
out.perm.sig.mi.se=out.perm.sig.mi.mo;
for mnd=1:n.imputations
    if do.age
        modeldata.Xr=data.retrofilled(ix.retro.hazDx,ix.sigpred-1,mnd);
    else
        modeldata.Xr=data.retrofilled(ix.retro.hazDx,ix.sigpred,mnd);
    end
    if mnd==1 && ~do.age
        fprintf('Currently excluding Age\n');
    end
    modeldata.Yr=(data.Dx(ix.retro.hazDx,2)==1)*1;
    [out.sig.mi.mo(:,mnd),tmp.filler,tmp.out.mi.stats]=glmfit(modeldata.Xr,modeldata.Yr,'binomial','link','logit');
    out.sig.mi.se(:,mnd)=tmp.out.mi.stats.se;
    if do.permutations
        for rnd=1:n.permutations
            modeldata.Yperm=squeeze((data.perm.Dx(ix.perm.hazDx(:,rnd),2)==1)*1);
            warning off
            [out.perm.sig.mi.mo(:,mnd,rnd),tmp.filler,tmp.out.perm.mi.stats]=glmfit(modeldata.Xr,modeldata.Yperm,'binomial','link','logit');
            out.perm.sig.mi.se(:,mnd,rnd)=tmp.out.perm.mi.stats.se;
            warning on
        end
    end
    fprintf(['Refit significant model ' num2str(mnd) '\n']);
end

out.sig.mo.est =mean(out.sig.mi.mo,2);
out.sig.mi.win =mean(out.sig.mi.se.^2,2);
out.sig.mi.btwn=var(out.sig.mi.mo')';
out.sig.mi.com =out.sig.mi.win+(1+1/n.imputations)*out.sig.mi.btwn;
out.sig.mo.tsta=out.sig.mo.est./(out.sig.mi.com).^(1/2);
out.sig.mo.df  =(n.imputations-1)*(1+out.sig.mi.win./out.sig.mi.btwn/(1+1/n.imputations)).^2;
% out.mi.gamma=(1+1/n.imputatons)*out.mi.btwn./out.mi.com;
out.sig.mo.p=zeros(size(out.sig.mo.est));
for fnd=1:length(out.sig.mo.est)
    out.sig.mo.p(fnd)=tcdf(-abs(out.sig.mo.tsta(fnd)),out.sig.mo.df(fnd))*2;
end

% Permutations
if do.permutations
    out.perm.sig.mo.est =squeeze(mean(out.perm.sig.mi.mo,2));
    out.perm.sig.mi.win =squeeze(mean(out.perm.sig.mi.se.^2,2));
    out.perm.sig.mi.btwn=squeeze(var(permute(out.perm.sig.mi.mo,[2,1,3])));
    out.perm.sig.mi.com =out.perm.sig.mi.win+(1+1/n.imputations)*out.perm.sig.mi.btwn;
    out.perm.sig.mo.tsta=out.perm.sig.mo.est./(out.perm.sig.mi.com).^(1/2);
    out.sig.mo.phat=zeros(size(out.sig.mo.est));
    out.sig.mo.CI  =zeros(size(out.sig.mo.est,1),2);
    for fnd=1:length(out.sig.mo.est)
        out.sig.mo.phat(fnd)=sum(abs(out.sig.mo.tsta(fnd))<=abs(out.perm.sig.mo.tsta(fnd,:)))/n.permutations;
        tmp.filler=sort(squeeze(out.perm.sig.mo.est(fnd,:)));
        out.sig.mo.CI(fnd,1)=tmp.filler(max(1,floor(0.025*n.permutations)));
        out.sig.mo.CI(fnd,2)=tmp.filler(ceil( 0.975*n.permutations));
    end
end

fid=fopen(dirs.sigmodel,'w');
fprintf(fid,'Variable,Weight,SEWeight,phat\n');
for ind=1:length(out.sig.mo.est)
    if do.age 
        if ind==1
            fprintf(fid,'Intercept,');
        else
            fprintf(fid,[heads.retro{ix.sigpred(ind-1)-1} ',']);
        end
    elseif ind==1
        fprintf(fid,'Intercept,');
        fprintf('Assuming you excluded Age\n');
    else
        fprintf(fid,[heads.retro{ix.sigpred(ind-1)} ',']);
    end
    if do.permutations && n.permutations>=10000 
        fprintf(fid,[num2str(out.sig.mo.est(ind)) ',' num2str(sqrt(out.sig.mi.com(ind))) ',' num2str(out.sig.mo.phat(ind)) '\n']);
    else
        fprintf(fid,[num2str(out.sig.mo.est(ind)) ',' num2str(sqrt(out.sig.mi.com(ind))) ',' num2str(out.sig.mo.p(ind)) '\n']);
    end
end
fclose(fid);

figure;
if exist('ix.retro.Dur','var')
    % rescaling AoO/Dur to decades
    out.rescale=(ones(length(ix.sigpred),1)+9*(ix.sigpred(end:-1:1)==ix.retro.Dur)+9*(ix.sigpred(end:-1:1)==ix.retro.Ons));
else
    out.rescale=ones(1,length(out.sig.mo.est)-1);
end
barmod=barh(out.sig.mo.est(end:-1:2).*out.rescale','BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
set(gca,'fontsize',18);
if do.age
    set(gca,'ytick',1:length(ix.sigpred),'yticklabel',{heads.retro{ix.sigpred(end:-1:1)-1}});
else
    set(gca,'ytick',1:length(ix.sigpred),'yticklabel',{heads.retro{ix.sigpred(end:-1:1)}});
end
set(gca,'ylim',[0.5 length(ix.sigpred)+0.5]);
set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
set(gca,'xlim',log([1/10 10]));
xlabel('PNES <- Odds Ratio -> ES');
hold on
if do.permutations
    barerrLB=barh(out.sig.mo.CI(end:-1:2,1).*out.rescale,'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    barerrUB=barh(out.sig.mo.CI(end:-1:2,2).*out.rescale,'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
else
    ebs=errbar(out.sig.mo.est(end:-1:2).*out.rescale',1:length(ix.sigpred),1.96*sqrt(out.sig.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
end
hold off

%% Process the Models for trees

out.mo.tree.est =mean(out.mi.tree.mo,2);
% Permutations
if do.permutations
    out.perm.mo.tree.est =squeeze(mean(out.perm.mi.tree.mo,2));
    out.mo.tree.phat=zeros(size(out.mo.tree.est));
    out.mo.tree.CI  =zeros(size(out.mo.tree.est,1),2);
    for fnd=1:length(out.mo.est)
        out.mo.tree.phat(fnd)=sum(abs(out.mo.tree.est(fnd))<=abs(out.perm.mo.tree.est(fnd,:)))/n.permutations;
        tmp.filler=sort(squeeze(out.perm.mo.tree.est(fnd,:)));
        out.mo.tree.CI(fnd,1)=tmp.filler(max(1,floor(0.025*n.permutations)));
        out.mo.tree.CI(fnd,2)=tmp.filler(ceil( 0.975*n.permutations));
    end
end

fid=fopen(dirs.retrotreesum,'w');
if do.permutations
    fprintf(fid,'Variable,Weight,CI,phat\n');
else
    fprintf(fid,'Variable,Weight\n');
end
for ind=1:length(out.mo.tree.est)
    if do.age 
        if ind==1
            fprintf(fid,'Intercept,');
        else
            fprintf(fid,[heads.retro{ind-1} ',']);
        end
    elseif ind==1
        fprintf(fid,'Intercept,');
        fprintf('Assuming you excluded Age\n');
    else
        fprintf(fid,[heads.retro{ind} ',']);
    end
    if do.permutations
        fprintf(fid,[num2str(out.mo.tree.est(ind)) ',' num2str(sqrt(out.mo.tree.CI(ind,1))) '--' num2str(sqrt(out.mo.tree.CI(ind,2))) ',' num2str(out.mo.tree.phat(ind)) '\n']);
    else
        fprintf(fid,[num2str(out.mo.est(ind)) ',' num2str(sqrt(out.mi.com(ind))) ',' num2str(out.mo.p(ind)) '\n']);
    end
end
fclose(fid);

figure;
barmod=barh(out.mo.tree.est(end:-1:2),'BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
set(gca,'fontsize',18);
set(gca,'ytick',1:length(ix.classuse),'yticklabel',{heads.retro{ix.classuse(end:-1:1)}});
set(gca,'ylim',[0.5 length(ix.classuse)+0.5]);
% set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
% set(gca,'xlim',log([1/5 5]));
xlabel('Gini Importance');
hold on
if do.permutations
    barerrLB=barh(out.mo.tree.CI(end:-1:2,1),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    barerrUB=barh(out.mo.tree.CI(end:-1:2,2),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
else
    % there is no estimate of error for importance
%     ebs=errbar(out.mo.est(end:-1:2).*out.rescale',1:length(out.rescale)',1.96*sqrt(out.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
end
hold off

ix.tree.sigpred=find(out.mo.tree.est>0);
figure;
barmod=barh(out.mo.tree.est(ix.tree.sigpred),'BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
set(gca,'fontsize',18);
set(gca,'ytick',1:length(ix.tree.sigpred),'yticklabel',{heads.retro{ix.tree.sigpred-1}});
set(gca,'ylim',[0.5 length(ix.tree.sigpred)+0.5]);
% set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
% set(gca,'xlim',log([1/5 5]));
xlabel('Gini Importance');
hold on
if do.permutations
    barerrLB=barh(out.mo.tree.CI(ix.tree.sigpred,1),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    barerrUB=barh(out.mo.tree.CI(ix.tree.sigpred,2),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
else
    % there is no estimate of error for importance
%     ebs=errbar(out.mo.est(end:-1:2).*out.rescale',1:length(out.rescale)',1.96*sqrt(out.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
end
hold off

%% Process the Predictions
fprintf('Assess the performance\n');
ix.testp.classid{1}=find(data.prosp.Dx(ix.prosp.hazDx,2)==1);
ix.testp.classid{5}=find(data.prosp.Dx(ix.prosp.hazDx,2)==-1);

if do.permutations
    out.perm.pred        =zeros(size(out.mi.pred,1),3,n.permutations);
    out.perm.ROC         =zeros(n.prosp.Dx,2,n.permutations);
    summary.perm.AUC     =zeros(n.permutations,1);
    out.perm.mi.preds    =zeros(size(out.mi.pred,1),n.imputations,2,n.permutations);
    out.perm.mi.ROC      =zeros(n.prosp.Dx,n.imputations,2,n.permutations);
    summary.perm.mi.AUC  =zeros(n.imputations,n.permutations);
    summary.perm.sens    =zeros(n.permutations,1);
    summary.perm.spec    =zeros(n.permutations,1);
    summary.perm.ESPV    =zeros(n.permutations,1);
    summary.perm.PSPV    =zeros(n.permutations,1);
    summary.perm.ovacc   =zeros(n.permutations,1);
    summary.perm.mi.sens =zeros(n.imputations,n.permutations);
    summary.perm.mi.spec =zeros(n.imputations,n.permutations);
    summary.perm.mi.ESPV =zeros(n.imputations,n.permutations);
    summary.perm.mi.PSPV =zeros(n.imputations,n.permutations);
    summary.perm.mi.ovacc=zeros(n.imputations,n.permutations);
    
    out.perm.tree.pred     =zeros(size(out.mi.pred,1),3,n.permutations);
    out.perm.tree.ROC      =zeros(length(0:0.05:1)+1,2,n.permutations);
%     out.perm.tree.ROC      =zeros(n.prosp.Dx,2,n.permutations);
    summary.perm.tree.AUC  =summary.perm.AUC;
    summary.perm.tree.sens =summary.perm.sens;
    summary.perm.tree.spec =zeros(n.permutations,1);
    summary.perm.tree.ESPV =zeros(n.permutations,1);
    summary.perm.tree.PSPV =zeros(n.permutations,1);
    summary.perm.tree.ovacc=zeros(n.permutations,1);
    
    out.perm.tree.pred(:,1,:)=squeeze(sum(out.perm.mi.tree.pred,2))/size(out.perm.mi.tree.pred,2);
    out.perm.tree.pred(:,2,:)=round(out.perm.tree.pred(:,1,:))*2-1;
    
    for rnd=1:n.permutations
        % 1: continuous prediction: average in logit space
        % 2: binary prediction
        % 3: yhat
        % proposed.trans=log(proposed.raw./(1-proposed.raw));
        tmp.preds.logit=log(out.perm.mi.pred(:,:,rnd)./(1-out.perm.mi.pred(:,:,rnd)));
        tmp.preds.probs=mean(tmp.preds.logit,2);
        out.perm.pred(:,1,rnd)=exp(tmp.preds.probs)./(1+exp(tmp.preds.probs));
        out.perm.pred(:,2,rnd)=round(out.perm.pred(:,1,rnd))*2-1;
        out.perm.pred(:,3,rnd)=1*(out.perm.pred(:,2,rnd)==data.prosp.Dx(ix.prosp.hazDx,2));
        tmp.thresh=sort(out.perm.pred(:,1,rnd));
        for snd=1:n.prosp.Dx
            out.perm.ROC(snd,1,rnd)=sum(out.perm.pred(ix.testp.classid{1},1,rnd)>=tmp.thresh(snd),1)/length(ix.testp.classid{1});
            out.perm.ROC(snd,2,rnd)=1-sum(out.perm.pred(ix.testp.classid{5},1,rnd)<tmp.thresh(snd),1)/length(ix.testp.classid{5});
            if snd>1
                summary.perm.AUC(rnd)=summary.perm.AUC(rnd)+(1-out.perm.ROC(snd,2,rnd))*(out.perm.ROC(snd-1,1,rnd)-out.perm.ROC(snd,1,rnd));
            end
        end
        
        % 1: binary prediction
        % 2: yhat
        out.perm.mi.preds(:,:,1,rnd)=round(out.perm.mi.pred(:,:,1))*2-1;
        out.perm.mi.preds(:,:,2,rnd)=1*(out.perm.mi.preds(:,:,1,rnd)==repmat(data.prosp.Dx(ix.prosp.hazDx,2),[1 n.imputations]));
        for mnd=1:n.imputations
            tmp.thresh=sort(out.perm.mi.pred(:,mnd,1));
            for snd=1:n.prosp.Dx
                out.perm.mi.ROC(snd,mnd,1,rnd)=sum(out.perm.mi.pred(ix.testp.classid{1},mnd,rnd)>=tmp.thresh(snd))/length(ix.testp.classid{1});
                out.perm.mi.ROC(snd,mnd,2,rnd)=1-sum(out.perm.mi.pred(ix.testp.classid{5},mnd,rnd) <tmp.thresh(snd))/length(ix.testp.classid{5});
                if snd>1
                    summary.perm.mi.AUC(mnd,rnd)=summary.perm.mi.AUC(mnd,rnd)+(1-out.perm.mi.ROC(snd,mnd,2,rnd))*(out.perm.mi.ROC(snd-1,mnd,1,rnd)-out.perm.mi.ROC(snd,mnd,1,rnd));
                end
            end
        end
        
        % Tree predictions
        out.perm.tree.pred(:,3,rnd)=1*(out.perm.tree.pred(:,2,rnd)==data.prosp.Dx(ix.prosp.hazDx,2));
        tmp.thresh=0:0.05:1;
%         tmp.thresh=sort(out.perm.tree.pred(:,rnd),'ascend');
        summary.perm.tree.AUC(rnd)=0; 
        for snd=1:21
            out.perm.tree.ROC(snd,1,rnd)=sum(out.perm.tree.pred(ix.testp.classid{1},1,rnd)>=tmp.thresh(snd),1)/length(ix.testp.classid{1});
            out.perm.tree.ROC(snd,2,rnd)=1-sum(out.perm.tree.pred(ix.testp.classid{5},1,rnd)<tmp.thresh(snd),1)/length(ix.testp.classid{5});
            if snd>1
                summary.perm.tree.AUC(rnd)=summary.perm.tree.AUC(rnd)+(1-out.perm.tree.ROC(snd,2,rnd))*(out.perm.tree.ROC(snd-1,1,rnd)-out.perm.tree.ROC(snd,1,rnd));
            end
        end
        out.perm.tree.ROC(end,:)=0;
        summary.perm.tree.AUC(rnd)=summary.perm.tree.AUC(rnd)+(1-out.perm.tree.ROC(end,2,rnd))*(out.perm.tree.ROC(snd,1,rnd)-out.perm.tree.ROC(end,1,rnd));
        
        % %% Performance Summary Figures
        
        % combining the imputations        
        summary.perm.sens(rnd) =mean(out.perm.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3,rnd),1);
        summary.perm.spec(rnd) =mean(out.perm.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3,rnd),1);
        summary.perm.ESPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.pred(:,2,rnd)==1)),2)==1);
        summary.perm.PSPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.pred(:,2,rnd)==-1)),2)==-1);
        summary.perm.ovacc(rnd)=mean(out.perm.pred(:,3,rnd),1);
        
        % by each imputation separately
        summary.perm.mi.sens(:,rnd)=mean(out.perm.mi.preds(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),:,2,rnd),1);
        summary.perm.mi.spec(:,rnd)=mean(out.perm.mi.preds(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),:,2,rnd),1);
        for mnd=1:n.imputations
            summary.perm.mi.ESPV(mnd,rnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.mi.preds(:,mnd,1,rnd)==1)),2)==1);
            summary.perm.mi.PSPV(mnd,rnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.mi.preds(:,mnd,1,rnd)==-1)),2)==-1);
        end
        summary.perm.mi.ovacc(:,rnd)=mean(out.perm.mi.preds(:,:,2,rnd),1);
        
        % Trees
        summary.perm.tree.sens(rnd) =mean(out.perm.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3,rnd),1);
        summary.perm.tree.spec(rnd) =mean(out.perm.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3,rnd),1);
        summary.perm.tree.ESPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.tree.pred(:,2,rnd)==1)),2)==1);
        summary.perm.tree.PSPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.tree.pred(:,2,rnd)==-1)),2)==-1);
        summary.perm.tree.ovacc(rnd)=mean(out.perm.tree.pred(:,3,rnd),1);
        
        clear tmp;
    end
end

% Logistic Regression First
out.prosp.pred     =zeros(size(out.mi.pred,1),3);
% 1: continuous prediction: average in logit space
% 2: binary prediction
% 3: yhat
% proposed.trans=log(proposed.raw./(1-proposed.raw));
tmp.preds.logit=log(out.mi.pred./(1-out.mi.pred));
tmp.preds.probs=mean(tmp.preds.logit(:,:,1),2);
out.prosp.pred(:,1)=exp(tmp.preds.probs)./(1+exp(tmp.preds.probs));
out.prosp.pred(:,2)=round(out.prosp.pred(:,1))*2-1;
out.prosp.pred(:,3)=1*(out.prosp.pred(:,2)==data.prosp.Dx(ix.prosp.hazDx,2));

out.prosp.ROC=zeros(n.prosp.Dx,2);
summary.AUC=0;
tmp.thresh=sort(out.prosp.pred(:,1));
for snd=1:n.prosp.Dx
    out.prosp.ROC(snd,1)=sum(out.prosp.pred(ix.testp.classid{1},1)>=tmp.thresh(snd))/length(ix.testp.classid{1});
    out.prosp.ROC(snd,2)=1-sum(out.prosp.pred(ix.testp.classid{5},1)<tmp.thresh(snd))/length(ix.testp.classid{5});
    if snd>1
        summary.AUC=summary.AUC+(1-out.prosp.ROC(snd,2))*(out.prosp.ROC(snd-1,1)-out.prosp.ROC(snd,1));
    end
end

figure;
p2=plot(out.prosp.ROC(:,2),out.prosp.ROC(:,1),'LineWidth',2,'color','black');
hold on
if do.permutations
    for rnd=1:n.permutations
        p3=plot(out.perm.ROC(:,2,rnd),out.perm.ROC(:,1,rnd),'LineWidth',2,'color',[0.8 0.8 0.8]);
    end
end
hold off
set(gca,'fontsize',14);
axis square
title('Combined Prediction');
xlabel('Percent ES above threshold (false positive rate)');
ylabel('Percent PNES above threshold (true positive rate)');
set(gca,'xlim',[0 1],'ylim',[0 1]);
set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});

% Now trees
out.prosp.tree.pred=zeros(size(out.mi.pred,1),2);
% 1: Continuous prediction: average across imputations
% 2: binary prediction
% 3: yhat
out.prosp.tree.pred(:,1)=mean(out.mi.tree.pred,2);
out.prosp.tree.pred(:,2)=round(out.prosp.tree.pred(:,1))*2-1;
out.prosp.tree.pred(:,3)=1*(out.prosp.tree.pred(:,2)==data.prosp.Dx(ix.prosp.hazDx,2));

out.prosp.tree.ROC=zeros(length(0:0.05:1)+1,2);
summary.tree.AUC=0;
tmp.thresh=0:0.05:1;
% tmp.thresh=sort(out.prosp.tree.pred(:,1),'ascend');
for snd=1:21
    out.prosp.tree.ROC(snd,1)=sum(out.prosp.tree.pred(ix.testp.classid{1},1)>=tmp.thresh(snd))/length(ix.testp.classid{1});
    out.prosp.tree.ROC(snd,2)=1-sum(out.prosp.tree.pred(ix.testp.classid{5},1)<tmp.thresh(snd))/length(ix.testp.classid{5});
    if snd>1
        summary.tree.AUC=summary.tree.AUC+(1-out.prosp.tree.ROC(snd,2))*(out.prosp.tree.ROC(snd-1,1)-out.prosp.tree.ROC(snd,1));    
    end
end
out.prosp.tree.ROC(end,:)=0;
summary.tree.AUC=summary.tree.AUC+(1-out.prosp.tree.ROC(end,2))*(out.prosp.tree.ROC(snd,1)-out.prosp.tree.ROC(end,1));

figure;
p2=plot(out.prosp.tree.ROC(:,2),out.prosp.tree.ROC(:,1),'LineWidth',2,'color','black');
hold on
if do.permutations
    for rnd=1:n.permutations
        p3=plot(out.perm.tree.ROC(:,2,rnd),out.perm.tree.ROC(:,1,rnd),'LineWidth',2,'color',[0.8 0.8 0.8]);
    end
end
% fprintf(['Need ROC for perms\n']);
hold off
set(gca,'fontsize',14);
axis square
title('Combined Prediction - Tree');
xlabel('Percent ES above threshold (false positive rate)');
ylabel('Percent PNES above threshold (true positive rate)');
set(gca,'xlim',[0 1],'ylim',[0 1]);
set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});

% Back to Logistic Regression by Imputation 
% (this doesn't make sense in trees)
out.prosp.mi.pred=zeros(size(out.mi.pred,1),n.imputations,2);
% 1: binary prediction
% 2: yhat
out.prosp.mi.pred(:,:,1)=round(out.mi.pred(:,:,1))*2-1;
out.prosp.mi.pred(:,:,2)=1*(out.prosp.mi.pred(:,:,1)==repmat(data.prosp.Dx(ix.prosp.hazDx,2),[1 n.imputations]));
out.prosp.oth.pred=round(out.mi.oth.pred)*2-1;
out.prosp.mi.ROC=zeros(n.prosp.Dx,n.imputations,2);
summary.mi.AUC=zeros(n.imputations,1);
for mnd=1:n.imputations
    tmp.thresh=sort(out.mi.pred(:,mnd,1));
    for snd=1:n.prosp.Dx
        out.prosp.mi.ROC(snd,mnd,1)=sum(out.mi.pred(ix.testp.classid{1},mnd,1)>=tmp.thresh(snd))/length(ix.testp.classid{1});
        out.prosp.mi.ROC(snd,mnd,2)=1-sum(out.mi.pred(ix.testp.classid{5},mnd,1) <tmp.thresh(snd))/length(ix.testp.classid{5});
        if snd>1
            summary.mi.AUC(mnd)=summary.mi.AUC(mnd)+(1-out.prosp.mi.ROC(snd,mnd,2))*(out.prosp.mi.ROC(snd-1,mnd,1)-out.prosp.mi.ROC(snd,mnd,1));
        end
    end
end

figure;
p2=plot(out.prosp.mi.ROC(:,:,2),out.prosp.mi.ROC(:,:,1),'LineWidth',2);
hold on
if do.permutations
    for rnd=1:n.permutations
        p3=plot(out.perm.mi.ROC(:,:,2,rnd),out.perm.mi.ROC(:,:,1,rnd),'LineWidth',2,'color',[0.8 0.8 0.8]);
    end
end
hold off
set(gca,'fontsize',14);
axis square
title('Prediction by imputation');
xlabel('Percent ES above threshold (false positive rate)');
ylabel('Percent PNES above threshold (true positive rate)');
set(gca,'xlim',[0 1],'ylim',[0 1]);
set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});

%% Performance Summary Figures

% combining the imputations
clear tmp
summary.sens =mean(out.prosp.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3),1);
summary.sensCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(1),summary.sens)/n.prosp.classes(1),binoinv(normcdf(1,0,1),n.prosp.classes(1),summary.sens)/n.prosp.classes(1)];
summary.spec =mean(out.prosp.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3),1);
summary.specCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(5),summary.spec)/n.prosp.classes(5),binoinv(normcdf(1,0,1),n.prosp.classes(5),summary.sens)/n.prosp.classes(5)];
tmp.n=sum(out.prosp.pred(:,2)==1);
summary.ESPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.pred(:,2)==1)),2)==1);
summary.ESPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.ESPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.ESPV)/tmp.n];
tmp.n=sum(out.prosp.pred(:,2)==-1);
summary.PSPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.pred(:,2)==-1)),2)==-1);
summary.PSPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.PSPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.PSPV)/tmp.n];
summary.ovacc=mean(out.prosp.pred(:,3),1);
summary.ovaccCI=[binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.ovacc)/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.ovacc)/n.prosp.Dx];

if do.permutations
    summary.p.sens =permtest(summary.sens ,summary.perm.sens ,0);
    summary.p.spec =permtest(summary.spec ,summary.perm.spec ,0);
    summary.p.ESPV =permtest(summary.ESPV ,summary.perm.ESPV ,0);
    summary.p.PSPV =permtest(summary.PSPV ,summary.perm.PSPV ,0);
    summary.p.ovacc=permtest(summary.ovacc,summary.perm.ovacc,0);
end

% now trees
clear tmp
summary.tree.sens =mean(out.prosp.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3),1);
summary.tree.sensCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(1),summary.tree.sens)/n.prosp.classes(1),binoinv(normcdf(1,0,1),n.prosp.classes(1),summary.tree.sens)/n.prosp.classes(1)];
summary.tree.spec =mean(out.prosp.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3),1);
summary.tree.specCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(5),summary.tree.spec)/n.prosp.classes(5),binoinv(normcdf(1,0,1),n.prosp.classes(5),summary.tree.sens)/n.prosp.classes(5)];
tmp.n=sum(out.prosp.tree.pred(:,2)==1);
summary.tree.ESPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.tree.pred(:,2)==1)),2)==1);
summary.tree.ESPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.tree.ESPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.tree.ESPV)/tmp.n];
tmp.n=sum(out.prosp.tree.pred(:,2)==-1);
summary.tree.PSPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.tree.pred(:,2)==-1)),2)==-1);
summary.tree.PSPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.tree.PSPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.tree.PSPV)/tmp.n];
summary.tree.ovacc=mean(out.prosp.tree.pred(:,3),1);
summary.tree.ovaccCI=[binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.tree.ovacc)/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.tree.ovacc)/n.prosp.Dx];

if do.permutations
    summary.tree.p.sens =permtest(summary.tree.sens ,summary.perm.tree.sens ,0);
    summary.tree.p.spec =permtest(summary.tree.spec ,summary.perm.tree.spec ,0);
    summary.tree.p.ESPV =permtest(summary.tree.ESPV ,summary.perm.tree.ESPV ,0);
    summary.tree.p.PSPV =permtest(summary.tree.PSPV ,summary.perm.tree.PSPV ,0);
    summary.tree.p.ovacc=permtest(summary.tree.ovacc,summary.perm.tree.ovacc,0);
end

% Logistic Regression by each imputation separately
summary.mi.sens =mean(out.prosp.mi.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),:,2),1);
summary.mi.spec =mean(out.prosp.mi.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),:,2),1);
summary.mi.ESPV =zeros(n.imputations,1);
summary.mi.PSPV =summary.mi.ESPV;
for mnd=1:n.imputations
    summary.mi.ESPV(mnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.mi.pred(:,mnd,1)==1)),2)==1);
    summary.mi.PSPV(mnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.mi.pred(:,mnd,1)==-1)),2)==-1);
end
summary.mi.ovacc=mean(out.prosp.mi.pred(:,:,2),1);

summary.mi.p.sens =zeros(n.imputations,1);
summary.mi.p.spec =zeros(n.imputations,1);
summary.mi.p.ESPV =zeros(n.imputations,1);
summary.mi.p.PSPV =zeros(n.imputations,1);
summary.mi.p.ovacc=zeros(n.imputations,1);
clear tmp;
if do.permutations
    for mnd=1:n.imputations
        tmp                    =permtest(summary.mi.sens(mnd) ,squeeze(summary.perm.mi.sens(mnd,:)) ,0);
        summary.mi.p.sens(mnd) =tmp.quantiles;
        tmp                    =permtest(summary.mi.spec(mnd) ,squeeze(summary.perm.mi.spec(mnd,:)) ,0);
        summary.mi.p.spec(mnd) =tmp.quantiles;
        tmp                    =permtest(summary.mi.ESPV(mnd) ,squeeze(summary.perm.mi.ESPV(mnd,:)) ,0);
        summary.mi.p.ESPV(mnd) =tmp.quantiles;
        tmp                    =permtest(summary.mi.PSPV(mnd) ,squeeze(summary.perm.mi.PSPV(mnd,:)) ,0);
        summary.mi.p.PSPV(mnd) =tmp.quantiles;
        tmp                    =permtest(summary.mi.ovacc(mnd),squeeze(summary.perm.mi.ovacc(mnd,:)),0);
        summary.mi.p.ovacc(mnd)=tmp.quantiles;
    end
end

summary.chance.ovacc  =max(n.prosp.classes([1 5]))/sum(n.prosp.classes([1 5]));
summary.chance.ovacc95(1)=binoinv(0.025,sum(n.prosp.classes([1 5])),summary.chance.ovacc)/sum(n.prosp.classes([1 5]));
summary.chance.ovacc95(2)=binoinv(0.975,sum(n.prosp.classes([1 5])),summary.chance.ovacc)/sum(n.prosp.classes([1 5]));

%% Performance Figure
summary.perf=[summary.ovacc,summary.sens,summary.spec,summary.ESPV,summary.PSPV];
summary.perfCI=[summary.ovaccCI;summary.sensCI;summary.specCI;summary.ESPVCI;summary.PSPVCI];
summary.tree.perf=[summary.tree.ovacc,summary.tree.sens,summary.tree.spec,summary.tree.ESPV,summary.tree.PSPV];
summary.tree.perfCI=[summary.tree.ovaccCI;summary.tree.sensCI;summary.tree.specCI;summary.tree.ESPVCI;summary.tree.PSPVCI];
summary.naive=[max(n.prosp.classes(ix.DxES),n.prosp.classes(ix.DxPNES))/n.prosp.Dx,1,0,max(n.prosp.classes(ix.DxES),n.prosp.classes(ix.DxPNES))/n.prosp.Dx,0];
summary.naiveCI=[binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx;
    binoinv(normcdf(-1,0,1),n.prosp.classes(ix.DxES),1-1/n.prosp.classes(ix.DxES)/2)/n.prosp.classes(ix.DxES),binoinv(normcdf(1,0,1),n.prosp.classes(ix.DxES),1-1/n.prosp.classes(ix.DxES)/2)/n.prosp.classes(ix.DxES);
    binoinv(normcdf(-1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES),binoinv(normcdf(1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES);
    binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx;
    binoinv(normcdf(-1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES),binoinv(normcdf(1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES)];

summary.chan=zeros(5,4); % -1 SD, Median, +1 SD, 97.5%
cutoff.quantiles=[normcdf(-1,0,1),0.5,normcdf(1,0,1),0.975];
if do.permutations
    tmp=sort(summary.perm.ovacc);
    for ind=1:4
        summary.chan(1,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.sens);
    for ind=1:4
        summary.chan(2,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.spec);
    for ind=1:4
        summary.chan(3,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.ESPV);
    for ind=1:4
        summary.chan(4,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.PSPV);
    for ind=1:4
        summary.chan(5,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
end

summary.tree.chan=zeros(5,4); % -1 SD, Median, +1 SD, 97.5%
cutoff.quantiles=[normcdf(-1,0,1),0.5,normcdf(1,0,1),0.975];
if do.permutations
    tmp=sort(summary.perm.tree.ovacc);
    for ind=1:4
        summary.tree.chan(1,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.tree.sens);
    for ind=1:4
        summary.tree.chan(2,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.tree.spec);
    for ind=1:4
        summary.tree.chan(3,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.tree.ESPV);
    for ind=1:4
        summary.tree.chan(4,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.tree.PSPV);
    for ind=1:4
        summary.tree.chan(5,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
end


figure
bar3=barh(summary.perf(5:-1:1),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
set(gca,'fontsize',16);
set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
set(gca,'ylim',[0.5 5.5]);
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
cha3=barh(summary.chan(5:-1:1,4),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
cnt=1;
for jnd=5:-1:1
    ebs3=errbar(summary.perf(jnd),cnt,abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    cnt=cnt+1;
end
hold off

figure
bar3=barh(summary.tree.perf(5:-1:1),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
set(gca,'fontsize',16);
title('Tree');
set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
set(gca,'ylim',[0.5 5.5]);
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
cha3=barh(summary.tree.chan(5:-1:1,4),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
cnt=1;
for jnd=5:-1:1
    ebs3=errbar(summary.tree.perf(jnd),cnt,abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    cnt=cnt+1;
end
hold off

figure;
if do.permutations
    bar4=barh([summary.naive(5:-1:1)',summary.chan(5:-1:1,2),summary.tree.chan(5:-1:1,2),summary.perf(5:-1:1)'],'BarWidth',1);
else
    bar4=barh([summary.naive(5:-1:1)',summary.perf(5:-1:1)'],'BarWidth',1);
end
set(gca,'fontsize',16);
set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(bar4(1),'FaceColor',[0.70 0.3 1],...
    'DisplayName','Naive Assumption');
if do.permutations
    set(bar4(3),'FaceColor',[0.3 1 0.7],...
        'DisplayName','Permuted Data-LR');
    set(bar4(2),'FaceColor',[0.3 1 0.7],...
        'DisplayName','Permuted Data-Tree');
    set(bar4(4),'FaceColor',[1 0.3 0.7],...
        'DisplayName','Our Model');
else
    set(bar4(2),'FaceColor',[1 0.3 0.7],...
        'DisplayName','Our Model');
end
legend1 = legend(gca,'show');
hold on
cnt=1;
if do.permutations
    offset=[-0.23,0,0.23];
else
    offset=[-0.14,0.14];
end
for jnd=5:-1:1
    ebs4=errbar(summary.naive(jnd),cnt+offset(1),abs(summary.naive(jnd)-summary.naiveCI(jnd,1)),abs(summary.naive(jnd)-summary.naiveCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    if do.permutations
        ebs4=errbar(summary.chan(jnd,2),cnt+offset(2),abs(summary.chan(jnd,2)-summary.chan(jnd,1)),abs(summary.chan(jnd,2)-summary.chan(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
        ebs4=errbar(summary.perf(jnd),cnt+offset(3),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    else
        ebs4=errbar(summary.perf(jnd),cnt+offset(2),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    end
    cnt=cnt+1;
end
hold off

figure;
if do.permutations
    bar4=barh([summary.naive(5:-1:1)',summary.chan(5:-1:1,2),summary.tree.perf(5:-1:1)'],'BarWidth',1);
else
    bar4=barh([summary.naive(5:-1:1)',summary.tree.perf(5:-1:1)'],'BarWidth',1);
end
set(gca,'fontsize',16);
set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(bar4(1),'FaceColor',[0.70 0.3 1],...
    'DisplayName','Naive Assumption');
if do.permutations
    set(bar4(2),'FaceColor',[0.3 1 0.7],...
        'DisplayName','Permuted Data');
    set(bar4(3),'FaceColor',[1 0.3 0.7],...
        'DisplayName','Our Tree Model');
else
    set(bar4(2),'FaceColor',[1 0.3 0.7],...
        'DisplayName','Our Tree Model');
end
legend1 = legend(gca,'show');
hold on
cnt=1;
if do.permutations
    offset=[-0.23,0,0.23];
else
    offset=[-0.14,0.14];
end
for jnd=5:-1:1
    ebs4=errbar(summary.naive(jnd),cnt+offset(1),abs(summary.naive(jnd)-summary.naiveCI(jnd,1)),abs(summary.naive(jnd)-summary.naiveCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    if do.permutations
        ebs4=errbar(summary.chan(jnd,2),cnt+offset(2),abs(summary.chan(jnd,2)-summary.chan(jnd,1)),abs(summary.chan(jnd,2)-summary.chan(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
        ebs4=errbar(summary.tree.perf(jnd),cnt+offset(3),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    else
        ebs4=errbar(summary.tree.perf(jnd),cnt+offset(2),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    end
    cnt=cnt+1;
end
hold off

figure;
if do.permutations
    bar4=barh([summary.naive(5:-1:1)',summary.chan(5:-1:1,2),summary.perf(5:-1:1)',summary.tree.perf(5:-1:1)'],'BarWidth',1);
else
    bar4=barh([summary.naive(5:-1:1)',summary.perf(5:-1:1)',summary.tree.perf(5:-1:1)'],'BarWidth',1);
end
set(gca,'fontsize',16);
set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(bar4(1),'FaceColor',[0.70 0.3 1],...
    'DisplayName','Naive Assumption');
if do.permutations
    set(bar4(2),'FaceColor',[0.3 1 0.7],...
        'DisplayName','Permuted Data');
    set(bar4(3),'FaceColor',[1 0.3 0.7],...
        'DisplayName','Our Model');
    set(bar4(4),'FaceColor',[0.5 0.3 0.7],...
        'DisplayName','Our Tree Model');
else
    set(bar4(2),'FaceColor',[1 0.3 0.7],...
        'DisplayName','Our Model');
    set(bar4(3),'FaceColor',[0.5 0.3 0.7],...
        'DisplayName','Our Tree Model');
end
legend1 = legend(gca,'show');
hold on
cnt=1;
if do.permutations
    offset=[-0.23,-0.14,0.14,0.23];
else
    offset=[-0.23,0,0.23];
end
for jnd=5:-1:1
    ebs4=errbar(summary.naive(jnd),cnt+offset(1),abs(summary.naive(jnd)-summary.naiveCI(jnd,1)),abs(summary.naive(jnd)-summary.naiveCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    if do.permutations
        ebs4=errbar(summary.chan(jnd,2),cnt+offset(2),abs(summary.chan(jnd,2)-summary.chan(jnd,1)),abs(summary.chan(jnd,2)-summary.chan(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
        ebs4=errbar(summary.perf(jnd),cnt+offset(3),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        ebs4=errbar(summary.tree.perf(jnd),cnt+offset(4),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    else
        ebs4=errbar(summary.perf(jnd),cnt+offset(2),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        ebs4=errbar(summary.tree.perf(jnd),cnt+offset(3),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
    end
    cnt=cnt+1;
end
hold off

%% Performance Table

fid=fopen(dirs.perftable,'w');
if do.permutations
    fprintf(fid,',Tree,,Logistic,,Permutations Tree,,Permutations Logistic,,Naive\n');
else
    fprintf(fid,',Tree,,Logistic,,Naive\n');
end
for mnd=1:(3+do.permutations)
    fprintf(fid,',Mean,95 CI');
end
fprintf(fid,'\n');
fprintf(fid,'Accuracy,');
fprintf(fid,[num2str(round(summary.tree.ovacc*100,0)) ',' num2str(floor(summary.tree.ovaccCI(1)*100)) '--' num2str(ceil(summary.tree.ovaccCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.ovacc*100,0)) ',' num2str(floor(summary.ovaccCI(1)*100)) '--' num2str(ceil(summary.ovaccCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.tree.chan(1,2)*100,0)) ',' num2str(floor(summary.tree.chan(1,1)*100)) '--' num2str(ceil(summary.tree.chan(1,4)*100)) ',']);
    fprintf(fid,[num2str(round(summary.chan(1,2)*100,0)) ',' num2str(floor(summary.chan(1,1)*100)) '--' num2str(ceil(summary.chan(1,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(1)*100,0)) ',' num2str(floor(summary.naiveCI(1,1)*100)) '--' num2str(ceil(summary.naiveCI(1,2)*100)) '\n']);
fprintf(fid,'Sensitivity,');
fprintf(fid,[num2str(round(summary.tree.sens*100,0)) ',' num2str(floor(summary.tree.sensCI(1)*100)) '--' num2str(ceil(summary.tree.sensCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.sens*100,0)) ',' num2str(floor(summary.sensCI(1)*100)) '--' num2str(ceil(summary.sensCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.tree.chan(2,2)*100,0)) ',' num2str(floor(summary.tree.chan(2,1)*100)) '--' num2str(ceil(summary.tree.chan(2,4)*100)) ',']);
    fprintf(fid,[num2str(round(summary.chan(2,2)*100,0)) ',' num2str(floor(summary.chan(2,1)*100)) '--' num2str(ceil(summary.chan(2,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(2)*100,0)) ',' num2str(floor(summary.naiveCI(2,1)*100)) '--' num2str(ceil(summary.naiveCI(2,2)*100)) '\n']);
fprintf(fid,'Specificity,');
fprintf(fid,[num2str(round(summary.tree.spec*100,0)) ',' num2str(floor(summary.tree.specCI(1)*100)) '--' num2str(ceil(summary.tree.specCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.spec*100,0)) ',' num2str(floor(summary.specCI(1)*100)) '--' num2str(ceil(summary.specCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.tree.chan(3,2)*100,0)) ',' num2str(floor(summary.tree.chan(3,1)*100)) '--' num2str(ceil(summary.tree.chan(3,4)*100)) ',']);
    fprintf(fid,[num2str(round(summary.chan(3,2)*100,0)) ',' num2str(floor(summary.chan(3,1)*100)) '--' num2str(ceil(summary.chan(3,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(3)*100,0)) ',' num2str(floor(summary.naiveCI(3,1)*100)) '--' num2str(ceil(summary.naiveCI(3,2)*100)) '\n']);
fprintf(fid,'ES-PV,');
fprintf(fid,[num2str(round(summary.tree.ESPV*100,0)) ',' num2str(floor(summary.tree.ESPVCI(1)*100)) '--' num2str(ceil(summary.tree.ESPVCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.ESPV*100,0)) ',' num2str(floor(summary.ESPVCI(1)*100)) '--' num2str(ceil(summary.ESPVCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.tree.chan(4,2)*100,0)) ',' num2str(floor(summary.tree.chan(4,1)*100)) '--' num2str(ceil(summary.tree.chan(4,4)*100)) ',']);
    fprintf(fid,[num2str(round(summary.chan(4,2)*100,0)) ',' num2str(floor(summary.chan(4,1)*100)) '--' num2str(ceil(summary.chan(4,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(4)*100,0)) ',' num2str(floor(summary.naiveCI(4,1)*100)) '--' num2str(ceil(summary.naiveCI(4,2)*100)) '\n']);
fprintf(fid,'PNES-PV,');
fprintf(fid,[num2str(round(summary.tree.PSPV*100,0)) ',' num2str(floor(summary.tree.PSPVCI(1)*100)) '--' num2str(ceil(summary.tree.PSPVCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.PSPV*100,0)) ',' num2str(floor(summary.PSPVCI(1)*100)) '--' num2str(ceil(summary.PSPVCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.tree.chan(5,2)*100,0)) ',' num2str(floor(summary.tree.chan(5,1)*100)) '--' num2str(ceil(summary.tree.chan(5,4)*100)) ',']);
    fprintf(fid,[num2str(round(summary.chan(5,2)*100,0)) ',' num2str(floor(summary.chan(5,1)*100)) '--' num2str(ceil(summary.chan(5,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(5)*100,0)) ',' num2str(floor(summary.naiveCI(5,1)*100)) '--' num2str(ceil(summary.naiveCI(5,2)*100)) '\n']);
fclose(fid);

%% Descriptive Trend Figure - PNES vs ES
for znd=ix.data.cont
    figure;
    
    if exist('ix.retro.Dur','var')
        if znd==4
            ssigma=2;
        elseif intersect(znd,[1,3])
            ssigma=2; % Gaussian window
        elseif intersect(znd,[5,6])
            ssigma=0.3;
        else
            ssigma=0.001;
        end
    else
        if intersect(znd,ix.retro.Age)
            ssigma=2;
        elseif intersect(znd,ix.retro.transform)
            ssigma=0.3;
        else
            ssigma=0.001;
        end
    end
    
    % make exact figure
    tmps.percvals=unique(data.retro(find(~isnan(data.retro(:,znd))),znd));
    tmps.perchist=zeros(length(tmps.percvals),2);
    for ind=1:length(tmps.percvals)
        tmps.perchist(ind,1)=sum(data.retro(ix.retro.classid{ix.DxPNES},znd)==tmps.percvals(ind));
        tmps.perchist(ind,2)=sum(data.retro(ix.retro.classid{ix.DxES},znd)==tmps.percvals(ind));
    end
    % add smoothing
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,7)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    else
        if intersect(znd,[3,4])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,5)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    end
    n.percvals=length(perc.val);
    perc.loess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
    % Gaussian smoothing kernel applied onto tmps.perchist
    for ind=1:n.percvals
        for jnd=1:length(tmps.percvals)
            perc.loess(ind,1)=perc.loess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
            perc.loess(ind,2)=perc.loess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
            perc.loess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
        end
    end
    perc.loess=perc.loess./repmat(perc.loess(:,3),[1 3]);
    perc.rfreqbars=zeros(n.percvals,3);
    perc.rfreqbars(:,2)=perc.loess(:,1)./perc.loess(:,2);
    for ind=1:n.percvals
        if perc.rfreqbars(ind,2)==1
            perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),1-1/2/floor(perc.loess(ind,2)))/floor(perc.loess(ind,2)));
        else
            perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),perc.rfreqbars(ind,2))/floor(perc.loess(ind,2)));
        end
        if perc.loess(ind,2)<2
            perc.rfreqbars(ind,:)=NaN;
        end
    end
    hold on
    pl4=plot(perc.val,perc.loess(:,1)./perc.loess(:,2),'Color',[0 0 0],'LineWidth',2);
    ebs=errbar(perc.val,perc.rfreqbars(:,2),perc.rfreqbars(:,1),perc.rfreqbars(:,3),'LineWidth',3,'Color',[0 0 0]);
    hold off
    
    title('Retrospective Data');
    ylabel('Percent Patients with PNES vs ES');
    xlabel(heads.retro{znd});
    set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    if exist('ix.retro.Dur','var')
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==4
            iy.min=1;
            iy.max=75;
        elseif znd==3
            iy.min=0;
            iy.max=40;
        elseif znd==5
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==6
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    else
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==3
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==4
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    end
    set(gca,'xlim',[iy.min iy.max]);
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            if znd==5 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==6 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
        end
    else
        if intersect(znd,[3,4])
            if znd==3 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==4 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
        end
    end
      
    %% Descriptive Trend Figure - 5 classes
    figure;
%     ssigma=0.015; % Gaussian window
    
    % make exact figure
    ix.retro.notmissing=find(~isnan(data.retro(:,znd)));
    tmps5.percvals=unique(data.retro(ix.retro.notmissing,znd));
    tmps5.perchist=zeros(length(tmps.percvals),n.class);
    for ind=1:length(tmps5.percvals)
        for cnd=1:n.class
            tmps5.perchist(ind,cnd)=sum(data.retro(intersect(ix.retro.classid{cnd},ix.retro.notmissing),znd)==tmps5.percvals(ind));
        end
    end
    % add smoothing
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,7)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    else
        if intersect(znd,[3,4])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,5)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    end
    n.percvals=length(perc.val);
    perc.r5loess=zeros(n.percvals,2,n.class); %1: freq, 2:n
    % Gaussian smoothing kernel applied onto tmps5.perchist
    for ind=1:n.percvals
        for jnd=1:length(tmps5.percvals)
            for cnd=1:n.class
                perc.r5loess(ind,1,cnd)=perc.r5loess(ind,1,cnd)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*tmps5.perchist(jnd,cnd);
            end
            perc.r5loess(ind,2,1)=perc.r5loess(ind,2,1)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*sum(tmps5.perchist(jnd,:),2);
        end
    end
    perc.r5loess=perc.r5loess./normpdf(0,0,ssigma); % norming to make the weight of a patient at this specific value 1
    perc.r5freqbars=zeros(n.percvals,n.class); % Note that we don't have error bars because that would be too messy
    perc.r5freqbars=squeeze(perc.r5loess(:,1,:))./repmat(perc.r5loess(:,2,1),[1 n.class]);
    for ind=1:n.percvals
        if perc.r5loess(ind,2,1)<2
            perc.r5freqbars(ind,:)=NaN;
        end
    end
    ordcl=5:-1:1;
    bar5=bar(perc.val,perc.r5freqbars(:,ordcl),'stacked','BarWidth',1);
    title('Retrospective Data');
    set(gca,'fontsize',16);
    ylabel('Percent of All Patients');
    xlabel(heads.retro{znd});
    set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    %     set(gca,'xlim',[-0.01 0.4],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});
    if exist('ix.retro.Dur','var')
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==4
            iy.min=1;
            iy.max=75;
        elseif znd==3
            iy.min=0;
            iy.max=40;
        elseif znd==5
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==6
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    else
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==3
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==4
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    end
    set(gca,'xlim',[iy.min iy.max]);
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            if znd==5 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==6 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
        end
    else
        if intersect(znd,[3,4])
            if znd==3 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==4 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
        end
    end
    
    set(bar5(ordcl(1)),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
        'DisplayName','ES');
    set(bar5(ordcl(2)),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(2),:),...
        'DisplayName','PSLE');
    set(bar5(ordcl(3)),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(3),:),...
        'DisplayName','Inconclusive');
    set(bar5(ordcl(4)),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(4),:),...
        'DisplayName','Mixed');
    set(bar5(ordcl(5)),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
        'DisplayName','PNES');
    legend1 = legend(gca,'show');
end

% Splitting By Sex
ix.retro.Female=find(data.retro(:,ix.retro.Gender)==1);
ix.retro.Male  =setdiff(1:size(data.retro,1),ix.retro.Female);
for znd=ix.data.cont
    figure;
    for sexnd=1:2
        if sexnd==1
            ix.tmp=ix.retro.Female;
        else
            ix.tmp=ix.retro.Male;
        end
        % make exact figure
        tmps.percvals=unique(data.retro(intersect(ix.tmp,find(~isnan(data.retro(:,znd)))),znd));
        tmps.perchist=zeros(length(tmps.percvals),2);
        for ind=1:length(tmps.percvals)
            tmps.perchist(ind,1)=sum(data.retro(intersect(ix.tmp,ix.retro.classid{ix.DxPNES}),znd)==tmps.percvals(ind));
            tmps.perchist(ind,2)=sum(data.retro(intersect(ix.tmp,ix.retro.classid{ix.DxES}),znd)==tmps.percvals(ind));
        end
        % add smoothing
        perc.val=0:max(data.retro(ix.tmp,znd));
        n.percvals=length(perc.val);
        perc.loess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
        % Gaussian smoothing kernel applied onto tmps.perchist
        for ind=1:n.percvals
            for jnd=1:length(tmps.percvals)
                perc.loess(ind,1)=perc.loess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
                perc.loess(ind,2)=perc.loess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
                perc.loess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
            end
        end
        perc.loess=perc.loess./repmat(perc.loess(:,3),[1 3]);
        perc.rfreqbars=zeros(n.percvals,3);
        perc.rfreqbars(:,2)=perc.loess(:,1)./perc.loess(:,2);
        for ind=1:n.percvals
            if perc.rfreqbars(ind,2)==1
                perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),1-1/2/floor(perc.loess(ind,2)))/floor(perc.loess(ind,2)));
            else
                perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),perc.rfreqbars(ind,2))/floor(perc.loess(ind,2)));
            end
            if perc.loess(ind,2)<2
                perc.rfreqbars(ind,:)=NaN;
            end
        end
        hold on
        if sexnd==1
            Colr=[0 0 0];
            pl4=plot(perc.val,perc.loess(:,1)./perc.loess(:,2),'Color',Colr,'LineWidth',2);
            ebs=errbar(perc.val,perc.rfreqbars(:,2),perc.rfreqbars(:,1),perc.rfreqbars(:,3),'LineWidth',3,'Color',Colr);
        else
            Colr=[0 0 1];
            pl4=plot(perc.val+0.25,perc.loess(:,1)./perc.loess(:,2),'Color',Colr,'LineWidth',2);
            ebs=errbar(perc.val+0.25,perc.rfreqbars(:,2),perc.rfreqbars(:,1),perc.rfreqbars(:,3),'LineWidth',3,'Color',Colr);
        end
        if sexnd==2
            hold off
        end
        
        if sexnd==1
            title('Retrospective Data by Sex');
        else
            %         title('Retrospective Data by Sex: Males Only');
        end
        ylabel('Percent Patients with PNES vs ES');
        xlabel(heads.retro{znd});
        
        set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
        if exist('ix.retro.Dur','var')
            if znd==1
                iy.min=13;
                iy.max=83;
                %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
                %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
            elseif znd==4
                iy.min=1;
                iy.max=75;
            elseif znd==3
                iy.min=0;
                iy.max=40;
            elseif znd==5
                iy.min=log(2);
                iy.max=log(5.2*60*60);
            elseif znd==6
                iy.min=min(perc.val);
                iy.max=log(30*30.5+1);
            else
                iy.min=min(perc.val);
                iy.max=max(perc.val);
            end
        else
            if znd==1
                iy.min=13;
                iy.max=83;
                %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
                %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
            elseif znd==3
                iy.min=log(2);
                iy.max=log(5.2*60*60);
            elseif znd==4
                iy.min=min(perc.val);
                iy.max=log(30*30.5+1);
            else
                iy.min=min(perc.val);
                iy.max=max(perc.val);
            end
        end
        set(gca,'xlim',[iy.min iy.max]);
        if exist('ix.retro.Dur','var')
            if intersect(znd,[5,6])
                if znd==5 % Duration
                    iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
                elseif znd==6 % SzF
                    iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
                end
                set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
            end
        else
            if intersect(znd,[3,4])
                if znd==3 % Duration
                    iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
                elseif znd==4 % SzF
                    iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
                end
                set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
            end
        end
    end
end


%% Binary 5 class figures
n.bin=length(ix.data.indicators);
datafigs.bin5class=zeros(5,n.bin);
cnt=0;
for fnd=1:n.bin
    cnt=cnt+1;
    for jnd=1:5
        datafigs.bin5class(jnd,cnt)=sum(data.retro(ix.retro.classid{jnd},ix.data.indicators(fnd)));
    end
end
datafigs.binbin=datafigs.bin5class([ix.DxES,ix.DxPNES],:);
datafigs.binbinsum=sum(datafigs.binbin,1);
datafigs.binbin=datafigs.binbin./repmat(sum(datafigs.binbin,1),[2 1]);
datafigs.binbinCI=zeros(2,n.bin);
for fnd=1:n.bin
    datafigs.binbinCI(1,fnd)=binoinv(0.025,datafigs.binbinsum(fnd),datafigs.binbin(1,fnd))/datafigs.binbinsum(fnd);
    datafigs.binbinCI(2,fnd)=binoinv(0.975,datafigs.binbinsum(fnd),datafigs.binbin(1,fnd))/datafigs.binbinsum(fnd);
end
datafigs.bin5sum=sum(datafigs.bin5class,1);
datafigs.bin5class=datafigs.bin5class./repmat(sum(datafigs.bin5class,1),[n.class 1]);
    
figure;
bar5=barh(1:n.bin,datafigs.bin5class(:,end:-1:1)','stacked','BarWidth',1);
set(gca,'fontsize',18);
title('Retrospective Data');
set(bar5(ordcl(5)),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','ES');
set(bar5(ordcl(4)),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(4),:),...
    'DisplayName','PSLE');
set(bar5(ordcl(3)),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(3),:),...
    'DisplayName','Inconclusive');
set(bar5(ordcl(2)),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(2),:),...
    'DisplayName','Mixed');
set(bar5(ordcl(1)),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','PNES');
legend1 = legend(gca,'show');
set(gca,'ylim',[1.5 n.bin+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(end:-1:1)}}); %,'XTickLabelRotation',90);
xlabel('Percent of Patients with Each Factor');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
pl=plot([n.retro.classes(1)/sum(n.retro.classes) n.retro.classes(1)/sum(n.retro.classes)],[0 n.bin+1],':','LineWidth',3,'Color',[1 1 1]);
hold off;

figure;
bar5=barh(1:n.bin,datafigs.binbin(:,end:-1:1)','stacked','BarWidth',1);
set(gca,'fontsize',18);
title('Retrospective Data');
set(bar5(1),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','ES');
set(bar5(2),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','PNES');
legend1 = legend(gca,'show');
set(gca,'ylim',[1.5 n.bin+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(end:-1:1)}}); %,'XTickLabelRotation',90);
xlabel('ES-PV');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
pl=plot([summary.naive(1) summary.naive(1)],[0 n.bin+1],':','LineWidth',3,'Color',[0 0 0]);
cnt=1;
for fnd=n.bin:-1:1
    ebs=errbar(datafigs.binbin(1,fnd),cnt,abs(datafigs.binbin(1,fnd)-datafigs.binbinCI(1,fnd)),abs(datafigs.binbin(1,fnd)-datafigs.binbinCI(2,fnd)),'LineWidth',3,'Color',[0 0 0],'horiz');
    cnt=cnt+1;
end
hold off;

clear tmp;
tmp.filler=zeros(length(ix.data.indicators),1);
for fnd=1:length(ix.data.indicators)
    if ~isempty(intersect(ix.sigpred,ix.data.indicators(fnd)));
        tmp.filler(fnd)=1;
    end
end
ix.signdicators=find(tmp.filler);
n.signdicators =sum(tmp.filler);
figure;
bar5=barh(1:n.signdicators,datafigs.bin5class(:,ix.signdicators(n.signdicators:-1:1))','stacked','BarWidth',1);
set(gca,'fontsize',18);
title('Retrospective Data');
set(bar5(ordcl(5)),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','ES');
set(bar5(ordcl(4)),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(4),:),...
    'DisplayName','PSLE');
set(bar5(ordcl(3)),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(3),:),...
    'DisplayName','Inconclusive');
set(bar5(ordcl(2)),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(2),:),...
    'DisplayName','Mixed');
set(bar5(ordcl(1)),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','PNES');
legend1 = legend(gca,'show');
set(gca,'ylim',[0.5 n.signdicators+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(ix.signdicators(end:-1:1))}}); %,'XTickLabelRotation',90);
xlabel('Percent of Patients with Each Factor');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
pl=plot([n.retro.classes(1)/sum(n.retro.classes) n.retro.classes(1)/sum(n.retro.classes)],[0 n.signdicators+1],':','LineWidth',3,'Color',[1 1 1]);
hold off;

figure;
bar5=barh(1:n.signdicators,datafigs.binbin(:,ix.signdicators(n.signdicators:-1:1))','stacked','BarWidth',1);
set(gca,'fontsize',18);
title('Retrospective Data');
set(bar5(1),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','ES');
set(bar5(2),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','PNES');
legend1 = legend(gca,'show');
set(gca,'ylim',[0.5 n.signdicators+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(ix.signdicators(end:-1:1))}}); %,'XTickLabelRotation',90);
xlabel('ES-PV');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
pl=plot([summary.naive(1) summary.naive(1)],[0 n.bin+1],':','LineWidth',3,'Color',[0 0 0]);
cnt=1;
for fnd=n.signdicators:-1:1
    ebs=errbar(datafigs.binbin(1,ix.signdicators(fnd)),cnt,abs(datafigs.binbin(1,ix.signdicators(fnd))-datafigs.binbinCI(1,ix.signdicators(fnd))),abs(datafigs.binbin(1,ix.signdicators(fnd))-datafigs.binbinCI(2,ix.signdicators(fnd))),'LineWidth',3,'Color',[0 0 0],'horiz');
    cnt=cnt+1;
end
hold off;

%% Table 1
ix.all.classid=cell(n.class,1);
ix.all.classid{1}=find(data.all.Dx(:,1)>1); % ES
ix.all.classid{2}=find(data.all.Dx(:,1)==-1); % PSLE
ix.all.classid{3}=find(data.all.Dx(:,1)==0); % Inconclusive
ix.all.classid{4}=find(data.all.Dx(:,1)==-5); % Mixed
ix.all.classid{5}=find(data.all.Dx(:,1)==-2); % PNES
ix.retvpro.classid=cell(n.class,2);
ix.retvpro.classid{1,1}=find(data.Dx(:,1)>1); % ES
ix.retvpro.classid{2,1}=find(data.Dx(:,1)==-1); % PSLE
ix.retvpro.classid{3,1}=find(data.Dx(:,1)==0); % Inconclusive
ix.retvpro.classid{4,1}=find(data.Dx(:,1)==-5); % Mixed
ix.retvpro.classid{5,1}=find(data.Dx(:,1)==-2); % PNES
ix.retvpro.classid{1,2}=find(data.prosp.Dx(:,1)>1); % ES
ix.retvpro.classid{2,2}=find(data.prosp.Dx(:,1)==-1); % PSLE
ix.retvpro.classid{3,2}=find(data.prosp.Dx(:,1)==0); % Inconclusive
ix.retvpro.classid{4,2}=find(data.prosp.Dx(:,1)==-5); % Mixed
ix.retvpro.classid{5,2}=find(data.prosp.Dx(:,1)==-2); % PNES

summary.all.class=zeros(n.class,4,6);
% Index 2
% 1: Class value
% 2: n
% 3: Age
% 4: Sex
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
ix.Demo=[ix.retro.Age,ix.retro.Gender];
for cnd=1:n.class
    summary.all.class(cnd,1,:)=data.all.Dx(ix.all.classid{cnd}(1),1);
    summary.all.class(cnd,2,:)=length(ix.all.classid{cnd});
    cnt=2;
    for jnd=ix.Demo
        cnt=cnt+1;
        summary.all.class(cnd,cnt,1)=nanmean(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,2)=min(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,3)=max(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,4)=nanstd(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,5)=summary.all.class(cnd,cnt,1)-1.96*summary.all.class(cnd,cnt,4)/sqrt(summary.all.class(cnd,2,1));
        summary.all.class(cnd,cnt,6)=summary.all.class(cnd,cnt,1)+1.96*summary.all.class(cnd,cnt,4)/sqrt(summary.all.class(cnd,2,1));
    end
end

% Write it!
fid=fopen(dirs.table1,'w');
fprintf(fid,', ,Age,Sex\n');
fprintf(fid,'Class,Count,Min (95CI) Max,F\n');
for ind=1:n.class
    fprintf(fid,[num2str(summary.all.class(ind,1,1)) ',' num2str(summary.all.class(ind,2,1)) ',']);
    for jnd=3:4
        if jnd==4
            fprintf(fid,[num2str(round(100*summary.all.class(ind,jnd,1))) ',']);
        else
            fprintf(fid,[num2str(summary.all.class(ind,jnd,2)) ' (' num2str(floor(summary.all.class(ind,jnd,5))) '-' num2str(ceil(summary.all.class(ind,jnd,6))) ') ' num2str(summary.all.class(ind,jnd,3)) ',']);
        end
    end
    fprintf(fid,'\n');
end
fclose(fid);

%% Supplemental Table 1
summary.retvpro.classes=zeros(n.class+2,4,6,2);
% Index 2
% 1: Class value
% 2: n
% 3: Age
% 4: Sex
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
% Index 4
% 1: Retrospective
% 2: Prospective
for rnd=1:2
    for cnd=1:n.class
        summary.retvpro.classes(cnd,1,:,:)=data.all.Dx(ix.all.classid{cnd}(1),1);
        summary.retvpro.classes(cnd,2,:,rnd)=length(ix.retvpro.classid{cnd,rnd});
        cnt=2;
        for jnd=ix.Demo
            cnt=cnt+1;
            if ~isempty(ix.retvpro.classid{cnd,rnd})
                if rnd==1
                    tmp.source=data.retro(ix.retvpro.classid{cnd,rnd},jnd);
                else
                    tmp.source=data.prosp.testp(ix.retvpro.classid{cnd,rnd},jnd);
                end
                summary.retvpro.classes(cnd,cnt,1,rnd)=nanmean(tmp.source);
                summary.retvpro.classes(cnd,cnt,2,rnd)=min(tmp.source);
                summary.retvpro.classes(cnd,cnt,3,rnd)=max(tmp.source);
                summary.retvpro.classes(cnd,cnt,4,rnd)=nanstd(tmp.source);
                summary.retvpro.classes(cnd,cnt,5,rnd)=summary.retvpro.classes(cnd,cnt,1,rnd)-1.96*summary.retvpro.classes(cnd,cnt,4,rnd)/sqrt(summary.retvpro.classes(ind,2,1,rnd));
                summary.retvpro.classes(cnd,cnt,6,rnd)=summary.retvpro.classes(cnd,cnt,1,rnd)+1.96*summary.retvpro.classes(cnd,cnt,4,rnd)/sqrt(summary.retvpro.classes(ind,2,1,rnd));
            end
        end
    end
end

% Write it!
fid=fopen(dirs.Stable1,'w');
fprintf(fid,',,,Age,Sex,Delay\n');
fprintf(fid,'Class,Dataset,Count,Min (95CI) Max,Mean,Min (95CI) Max\n');
for ind=[1:n.class n.class+2 n.class+1]
    fprintf(fid,[num2str(summary.retvpro.classes(ind,1,1,rnd)) ',']);
    for rnd=1:2
        if rnd==1
            fprintf(fid,'Retro,');
        else
            fprintf(fid,',Prosp,');
        end
        fprintf(fid,[num2str(summary.retvpro.classes(ind,2,1,rnd)) ',']);
        for jnd=3:4
            if jnd==4
                fprintf(fid,[num2str(round(100*summary.retvpro.classes(ind,jnd,1,rnd))) ',']);
            else
                fprintf(fid,[num2str(summary.retvpro.classes(ind,jnd,2,rnd)) ' (' num2str(floor(summary.retvpro.classes(ind,jnd,5,rnd))) '-' num2str(ceil(summary.retvpro.classes(ind,jnd,6,rnd))) ') ' num2str(summary.retvpro.classes(ind,jnd,3,rnd)) ',']);
            end
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

%% Write Out the Trees
if exist(dirs.treeout,'file')
    system(['rm ' dirs.treeout]);
end
diary(dirs.treeout);
for ind=1:n.imputations
    fprintf(['Tree Imputation ' num2str(ind) '\n']);
    trees.binary{ind}.view
end
diary OFF

if n.imputations>=ideal.imputations
    if n.permutations>=ideal.permutations
        fprintf('Saving your work\n');
        save([dirs.process '_' num2str(n.imputations) '_' num2str(n.permutations) '.mat']);
    elseif n.permutations
        fprintf('Saving your work\n');
        save([dirs.process '_' num2str(n.imputations) '_' num2str(n.permutations) '_' num2str(floor(rand()*100000)) '.mat']);
    else
        fprintf('Saving your work\n');
        save([dirs.process '_' num2str(n.imputations) '_0.mat']);
    end
end
