%% This compiles the permutations from ES_Semiology into a useable, more memory friendly format
% Wesley Kerr, June 2017, wesleytk@g.ucla.edu

dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.analysis =[dirs.base 'Dropbox/ES_Semiology/'];
dirs.data     =[dirs.base 'Documents/EMU/CI/Semiology/'];
dirs.retroDx  =[dirs.data 'Retro5_ForDx.csv'];
dirs.retrodata=[dirs.data 'Retro6_Semiology.csv'];
dirs.retroarff=[dirs.data 'Retro6_Semiology'];
dirs.retrosum =[dirs.analysis 'Retro6_ModelSummary_age.csv'];
dirs.retrotreesum =[dirs.analysis 'Retro6_ModelSummaryTree_age.csv'];
dirs.sigmodel =[dirs.analysis 'Retro6_SigModel_age.csv'];
dirs.prospDx  =[dirs.data 'Prosp_Diagnosis161122b.csv'];
dirs.prospdata=[dirs.data 'Prosp_Semiology161121.csv'];
dirs.prosparff=[dirs.analysis 'Prosp5_Semiology'];
dirs.pro2ret  =[dirs.analysis 'Semiology_Pro2Ret.csv'];
dirs.descrip  =[dirs.analysis 'Semiology_Descrip_Class.csv'];
dirs.pairwise =[dirs.analysis 'Semiology_DescripPairwise.csv'];
dirs.table1   =[dirs.analysis 'Semiology_Table1.csv'];
dirs.Stable1  =[dirs.analysis 'Semiology_STable1.csv'];
dirs.process  =[dirs.data 'Semiology_Processed'];
dirs.treeout  =[dirs.analysis 'Semiology_TreeOutput.txt'];
dirs.perftable=[dirs.analysis 'Semiology_Perf_age.csv'];

do.loadtrees=0;
do.verbose  =1; % note that after loading, this needs to be set again below (line 100-ish)

%% Load the Information
if do.verbose
    fprintf('Loading Permutation Results\n');
end
dirs.doneperm=dir([dirs.process '_age_*_*_*.mat']);
n.doneperms=0;
for knd=1:length(dirs.doneperm)
    if knd>1
        tmps.perm.mi.mo=perm.mi.mo;
        tmps.perm.mi.dev=perm.mi.dev;
        tmps.perm.mi.se=perm.mi.se;
        tmps.perm.mi.tree.mo=perm.mi.tree.mo;
        tmps.perm.mi.pred=perm.mi.pred;
        tmps.perm.mi.tree.pred=perm.mi.tree.pred;
        tmps.data.perm.Dx=perm.data.Dx;
        tmps.ix.perm.hazDx=perm.ix.hazDx;
    end
    load([dirs.data dirs.doneperm(knd).name],'out','data','ix');
    tmps.dev=sum(out.perm.mi.dev);
    ix.newperms=find(tmps.dev>0);
    n.newperms=length(ix.newperms);
    perm.mi.mo =zeros(size(out.perm.mi.mo,1),size(out.perm.mi.mo,2),n.doneperms+n.newperms);
    perm.mi.dev=zeros(size(out.perm.mi.dev,1),n.doneperms+n.newperms);
    perm.mi.se =zeros(size(out.perm.mi.se,1),size(out.perm.mi.se,2),n.doneperms+n.newperms);
    perm.mi.pred=zeros(size(out.perm.mi.pred,1),size(out.perm.mi.pred,2),n.doneperms+n.newperms);
    perm.mi.tree.pred=zeros(size(out.perm.mi.tree.pred,1),size(out.perm.mi.tree.pred,2),n.doneperms+n.newperms);
    perm.mi.tree.mo=zeros(size(out.perm.mi.tree.mo,1),size(out.perm.mi.tree.mo,2),n.doneperms+n.newperms);
    perm.data.Dx=zeros(size(data.perm.Dx,1),size(data.perm.Dx,2),n.doneperms+n.newperms);
    perm.ix.hazDx=zeros(size(ix.perm.hazDx,1),n.doneperms+n.newperms);
    if knd==1
        perm.mi.mo=out.perm.mi.mo;
        perm.mi.dev=out.perm.mi.dev;
        perm.mi.se=out.perm.mi.se;
        perm.mi.pred=out.perm.mi.pred;
        perm.mi.tree.pred=out.perm.mi.tree.pred;
        perm.mi.tree.mo=out.perm.mi.tree.mo;
        perm.data.Dx=data.perm.Dx;
        perm.ix.hazDx=ix.perm.hazDx;
    else
        perm.mi.mo(:,:,1:n.doneperms)=tmps.perm.mi.mo;
        perm.mi.dev(:,1:n.doneperms)=tmps.perm.mi.dev;
        perm.mi.se(:,:,1:n.doneperms)=tmps.perm.mi.se;
        perm.mi.pred(:,:,1:n.doneperms)=tmps.perm.mi.pred;
        perm.mi.tree.pred(:,:,1:n.doneperms)=tmps.perm.mi.tree.pred;
        perm.mi.tree.mo(:,:,1:n.doneperms)=tmps.perm.mi.tree.mo;
        perm.data.Dx(:,:,1:n.doneperms)=tmps.data.perm.Dx;
        perm.ix.hazDx(:,1:n.doneperms)=tmps.ix.perm.hazDx;
        if n.newperms
            perm.mi.mo(:,:,n.doneperms+1:end)=out.perm.mi.mo(:,:,ix.newperms);
            perm.mi.dev(:,n.doneperms+1:end)=out.perm.mi.dev(:,ix.newperms);
            perm.mi.se(:,:,n.doneperms+1:end)=out.perm.mi.se(:,:,ix.newperms);
            perm.mi.pred(:,:,n.doneperms+1:end)=out.perm.mi.pred(:,:,ix.newperms);
            perm.mi.tree.pred(:,:,n.doneperms+1:end)=out.perm.mi.tree.pred(:,:,ix.newperms);
            perm.mi.tree.mo(:,:,n.doneperms+1:end)=out.perm.mi.tree.mo(:,:,ix.newperms);
            perm.data.Dx(:,:,n.doneperms+1:end)=data.perm.Dx(:,:,ix.newperms);
            perm.ix.hazDx(:,n.doneperms+1:end)=ix.perm.hazDx(:,ix.newperms);
        end
    end
    n.doneperms=n.doneperms+n.newperms;
    fprintf(['Loaded file ' num2str(knd) '/' num2str(length(dirs.doneperm)) ' with ' num2str(n.doneperms) 'perms loaded\n']);
end

tmps.doneperms=n.doneperms;
dirs.done    =dir([dirs.process '_age_*_0.mat']);
if isempty(dirs.done)
    % use what you got from the last permutation
    load([dirs.data dirs.doneperm(end).name],'out','n','do','heads','ix','data');
else
    load([dirs.data dirs.done.name],'out','n','do','heads','ix','data');
end
do.permutations=1;
n.permutations=tmps.doneperms;
out.perm.mi.mo=perm.mi.mo;
out.perm.mi.dev=perm.mi.dev;
out.perm.mi.se=perm.mi.se;
out.perm.mi.pred=perm.mi.pred;
out.perm.mi.tree.pred=perm.mi.tree.pred;
out.perm.mi.tree.mo=perm.mi.tree.mo;
data.perm.Dx=perm.data.Dx;
ix.perm.hazDx=perm.ix.hazDx;
clear perm
if exist('do.age','var')
    if do.age
        save([dirs.process '_age_' num2str(n.permutations) '_compiled.mat'],'-v7.3');
    else
        save([dirs.process '_' num2str(n.permutations) '_compiled.mat'],'-v7.3');
    end
else
    save([dirs.process '_' num2str(n.permutations) '_compiled.mat'],'-v7.3');
end
do.verbose=1;
if do.verbose
    fprintf(['Permutation Results Loaded for ' num2str(n.permutations) '\n']);
end

do.ROC      =0; % if you want to calculate ROC curves (can take LOTS of memory)
do.AUC      =1; % this calculates just the AUC, not the ROC for each curve (hopes to be memory efficient)
do.mi       =0; % if you want to calculate statistics within each imputation (also memory)
do.display  =1;
% If you have to specify the below, your base model doesn't have age included in
% the model
% do.age      =1;
% ix.classuse =1:35;

summary.AUCs=zeros(4,3);
% Index 1:
% Tree
% LR
% Permutations
% Naive
% Index 2:
% Mean
% 95% CI LB
% 95% CI UB

%% Process the Information

out.perm.mo.est =squeeze(mean(out.perm.mi.mo,2));
out.perm.mi.win =squeeze(mean(out.perm.mi.se.^2,2));
out.perm.mi.btwn=squeeze(var(permute(out.perm.mi.mo,[2,1,3])));
out.perm.mi.com =out.perm.mi.win+(1+1/n.imputations)*out.perm.mi.btwn;
out.perm.mo.tsta=out.perm.mo.est./(out.perm.mi.com).^(1/2);
out.mo.phat=zeros(size(out.mo.est));
out.mo.CI  =zeros(size(out.mo.est,1),2);
for fnd=1:length(out.mo.est)
    out.mo.phat(fnd)=2*min([sum(out.mo.est(fnd)<=out.perm.mo.est(fnd,:)) sum(out.mo.est(fnd)>=out.perm.mo.est(fnd,:))])/n.permutations;
%     out.mo.phat(fnd)=sum(abs(out.mo.est(fnd))<=abs(out.perm.mo.est(fnd,:)))/n.permutations;
%     out.mo.phat(fnd)=sum(abs(out.mo.tsta(fnd))<=abs(out.perm.mo.tsta(fnd,:)))/n.permutations;
    tmp.filler=sort(squeeze(out.perm.mo.est(fnd,:)));
    out.mo.CI(fnd,1)=tmp.filler(floor(0.025*n.permutations));
    out.mo.CI(fnd,2)=tmp.filler(ceil( 0.975*n.permutations));
%     if out.mo.est(fnd)<=tmp.filler(floor(0.5*n.permutations))
%         out.mo.phat(fnd)=sum(out.mo.est(fnd)<=out.perm.mo.est(fnd,:))/n.permutations;
%     else
%         out.mo.phat(fnd)=sum(out.mo.est(fnd)>=out.perm.mo.est(fnd,:))/n.permutations;
%     end
end

fid=fopen(dirs.retrosum,'w');
if do.permutations
fprintf(fid,'Variable,Weight,SEWeight,95LB,95UB,phat\n');
else
    fprintf(fid,'Variable,Weight,SEWeight,p\n');
end
for ind=1:length(out.mo.est)
    if do.age
        if ind==1
            fprintf(fid,'Intercept,');
        else
            fprintf(fid,[heads.retro{ind-1} ',']);
        end
    elseif ind==1
        fprintf(fid,'Intercept,');
        %         fprintf('Assuming you excluded Age\n'); ***
    else
        fprintf(fid,[heads.retro{ind} ',']);
    end
    if do.permutations
        fprintf(fid,[num2str(out.mo.est(ind)) ',' num2str(sqrt(out.mi.com(ind))) ',' num2str(out.mo.CI(ind,1)) ',' num2str(out.mo.CI(ind,2)) ',' num2str(out.mo.phat(ind)) '\n']);
    else
        fprintf(fid,[num2str(out.mo.est(ind)) ',' num2str(sqrt(out.mi.com(ind))) ',' num2str(out.mo.p(ind)) '\n']);
    end
end
fclose(fid);

if do.display
    figure;
    % rescaling AoO/Dur/Age to decades
    if exist('ix.retro.Dur','var')
        out.rescale=(ones(1,length(ix.classuse))+9*(ix.classuse(end:-1:1)==ix.retro.Dur)+9*(ix.classuse(end:-1:1)==ix.retro.Ons)+9*(ix.classuse(end:-1:1)==1))';
    else
        out.rescale=ones(1,length(out.mo.est)-1)+9*(ix.classuse(end:-1:1)==1);
    end
    barmod=barh(out.mo.est(end:-1:2).*out.rescale','BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
    set(gca,'fontsize',18);
    set(gca,'ytick',1:length(ix.classuse),'yticklabel',{heads.retro{ix.classuse(end:-1:1)}});
    set(gca,'ylim',[0.5 length(ix.classuse)+0.5]);
    set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
    set(gca,'xlim',log([1/5 5]));
    xlabel('PNES <- Odds Ratio -> ES');
    hold on
    if do.permutations
        barerrLB=barh(out.mo.CI(end:-1:2,1).*out.rescale','BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
        barerrUB=barh(out.mo.CI(end:-1:2,2).*out.rescale','BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    else
        ebs=errbar(out.mo.est(end:-1:2).*out.rescale',1:length(out.rescale)',1.96*sqrt(out.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
    end
    hold off
end

if n.permutations>=10000
    ix.sigpred=find(out.mo.phat<0.05);
else
    ix.sigpred=find(out.mo.p<0.05);
end
if ~isempty(intersect(1,ix.sigpred)) % Remove the Intercept
    ix.sigpred=ix.sigpred(2:end);
end
out.sig.mi.mo=zeros(length(ix.sigpred)+1,n.imputations);
out.sig.mi.se=out.sig.mi.mo;
out.perm.sig.mi.mo=zeros(length(ix.sigpred)+1,n.imputations,n.permutations);
out.perm.sig.mi.se=out.perm.sig.mi.mo;
for mnd=1:n.imputations
    if do.age
        modeldata.Xr=data.retrofilled(ix.retro.hazDx,ix.sigpred-1,mnd);
    else
        modeldata.Xr=data.retrofilled(ix.retro.hazDx,ix.sigpred,mnd);
    end
    if mnd==1 && ~do.age
        fprintf('Currently excluding Age\n');
    end
    modeldata.Yr=(data.Dx(ix.retro.hazDx,2)==1)*1;
    [out.sig.mi.mo(:,mnd),tmp.filler,tmp.out.mi.stats]=glmfit(modeldata.Xr,modeldata.Yr,'binomial','link','logit');
    out.sig.mi.se(:,mnd)=tmp.out.mi.stats.se;
    if do.permutations
        for rnd=1:n.permutations
            modeldata.Yperm=squeeze((data.perm.Dx(ix.perm.hazDx(:,rnd),2)==1)*1);
            warning off
            [out.perm.sig.mi.mo(:,mnd,rnd),tmp.filler,tmp.out.perm.mi.stats]=glmfit(modeldata.Xr,modeldata.Yperm,'binomial','link','logit');
            out.perm.sig.mi.se(:,mnd,rnd)=tmp.out.perm.mi.stats.se;
            warning on
        end
    end
    fprintf(['Refit significant model imputation ' num2str(mnd) ' of ' num2str(n.imputations) '\n']);
end

out.sig.mo.est =mean(out.sig.mi.mo,2);
out.sig.mi.win =mean(out.sig.mi.se.^2,2);
out.sig.mi.btwn=var(out.sig.mi.mo')';
out.sig.mi.com =out.sig.mi.win+(1+1/n.imputations)*out.sig.mi.btwn;
out.sig.mo.tsta=out.sig.mo.est./(out.sig.mi.com).^(1/2);
out.sig.mo.df  =(n.imputations-1)*(1+out.sig.mi.win./out.sig.mi.btwn/(1+1/n.imputations)).^2;
% out.mi.gamma=(1+1/n.imputatons)*out.mi.btwn./out.mi.com;
out.sig.mo.p=zeros(size(out.sig.mo.est));
for fnd=1:length(out.sig.mo.est)
    out.sig.mo.p(fnd)=tcdf(-abs(out.sig.mo.tsta(fnd)),out.sig.mo.df(fnd))*2;
end

% Permutations
if do.permutations
    out.perm.sig.mo.est =squeeze(mean(out.perm.sig.mi.mo,2));
    out.perm.sig.mi.win =squeeze(mean(out.perm.sig.mi.se.^2,2));
    out.perm.sig.mi.btwn=squeeze(var(permute(out.perm.sig.mi.mo,[2,1,3])));
    out.perm.sig.mi.com =out.perm.sig.mi.win+(1+1/n.imputations)*out.perm.sig.mi.btwn;
    out.perm.sig.mo.tsta=out.perm.sig.mo.est./(out.perm.sig.mi.com).^(1/2);
    out.sig.mo.phat=zeros(size(out.sig.mo.est));
    out.sig.mo.CI  =zeros(size(out.sig.mo.est,1),2);
    for fnd=1:length(out.sig.mo.est)
        out.sig.mo.phat(fnd)=2*min([sum(out.sig.mo.est(fnd)<=out.perm.sig.mo.est(fnd,:)) sum(out.sig.mo.est(fnd)>=out.perm.sig.mo.est(fnd,:))])/n.permutations;
%         out.sig.mo.phat(fnd)=sum(abs(out.sig.mo.tsta(fnd))<=abs(out.perm.sig.mo.tsta(fnd,:)))/n.permutations;
        tmp.filler=sort(squeeze(out.perm.sig.mo.est(fnd,:)));
        out.sig.mo.CI(fnd,1)=tmp.filler(floor(0.025*n.permutations));
        out.sig.mo.CI(fnd,2)=tmp.filler(ceil( 0.975*n.permutations));
    end
end

fid=fopen(dirs.sigmodel,'w');
if do.permutations
    fprintf(fid,'Variable,Weight,SEWeight,95LB,95UB,phat\n');
else
    fprintf(fid,'Variable,Weight,SEWeight,p\n');
end
for ind=1:length(out.sig.mo.est)
    if do.age 
        if ind==1
            fprintf(fid,'Intercept,');
        else
            fprintf(fid,[heads.retro{ix.sigpred(ind-1)-1} ',']);
        end
    elseif ind==1
        fprintf(fid,'Intercept,');
        fprintf('Assuming you excluded Age\n');
    else
        fprintf(fid,[heads.retro{ix.sigpred(ind-1)} ',']);
    end
    if do.permutations && n.permutations>=10000 
        fprintf(fid,[num2str(out.sig.mo.est(ind)) ',' num2str(sqrt(out.sig.mi.com(ind))) ',' num2str(out.sig.mo.CI(ind,1)) ',' num2str(out.sig.mo.CI(ind,2)) ',' num2str(out.sig.mo.phat(ind)) '\n']);
    else
        fprintf(fid,[num2str(out.sig.mo.est(ind)) ',' num2str(sqrt(out.sig.mi.com(ind))) ',' num2str(out.sig.mo.p(ind)) '\n']);
    end
end
fclose(fid);

if do.display
    figure;
    clear out.rescale
    if exist('ix.retro.Dur','var')
        % rescaling AoO/Dur to decades
        out.rescale=(ones(length(ix.sigpred),1)+9*(ix.sigpred(end:-1:1)==ix.retro.Dur)+9*(ix.sigpred(end:-1:1)==ix.retro.Ons));
    else
        if intersect(ix.sigpred,2)
            out.rescale=ones(1,length(out.sig.mo.est)-1)+9*(ix.sigpred(end:-1:1)==2)';
        else
            out.rescale=ones(1,length(out.sig.mo.est)-1);
        end
    end
    barmod=barh(out.sig.mo.est(end:-1:2).*out.rescale','BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 0 0]);
    set(gca,'fontsize',18);
    set(gca,'ytick',1:length(ix.sigpred),'yticklabel',{heads.retro{ix.sigpred(end:-1:1)-1}});
    set(gca,'ylim',[0.5 length(ix.sigpred)+0.5]);
    set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
    set(gca,'xlim',log([1/10 10]));
    xlabel('PNES <- Odds Ratio -> ES');
    hold on
    if do.permutations
        barerrLB=barh(out.sig.mo.CI(end:-1:2,1).*out.rescale','BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[0.5 0.5 0.5]);
        barerrUB=barh(out.sig.mo.CI(end:-1:2,2).*out.rescale','BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[0.5 0.5 0.5]);
    else
        ebs=errbar(out.sig.mo.est(end:-1:2).*out.rescale',1:length(ix.sigpred),1.96*sqrt(out.sig.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
    end
    hold off
end

%% Process the Models for trees

out.mo.tree.est =mean(out.mi.tree.mo,2);
% Permutations
% Gini is a >= statistic, so this is a one-way test
if do.permutations
    out.perm.mo.tree.est =squeeze(mean(out.perm.mi.tree.mo,2));
    out.mo.tree.phat=zeros(size(out.mo.tree.est));
    out.mo.tree.CI  =zeros(size(out.mo.tree.est));
    for fnd=1:length(out.mo.est)
        out.mo.tree.phat(fnd)=mean(out.mo.tree.est(fnd)<=out.perm.mo.tree.est(fnd,:));
        tmp.filler=sort(squeeze(out.perm.mo.tree.est(fnd,:)));
        out.mo.tree.CI(fnd)=tmp.filler(floor(0.95*n.permutations));
    end
end

fid=fopen(dirs.retrotreesum,'w');
if do.permutations
    fprintf(fid,'Variable,Gini,95UB,phat\n');
else
    fprintf(fid,'Variable,Weight\n');
end
for ind=1:length(out.mo.tree.est)
    if do.age 
        if ind==1
            fprintf(fid,'Intercept,');
        else
            fprintf(fid,[heads.retro{ind-1} ',']);
        end
    elseif ind==1
        fprintf(fid,'Intercept,');
        fprintf('Assuming you excluded Age\n');
    else
        fprintf(fid,[heads.retro{ind} ',']);
    end
    if do.permutations
        fprintf(fid,[num2str(out.mo.tree.est(ind)) ',' num2str(out.mo.tree.CI(ind)) ',' num2str(out.mo.tree.phat(ind)) '\n']);
    else
        fprintf(fid,[num2str(out.mo.est(ind)) ',' num2str(sqrt(out.mi.com(ind))) ',' num2str(out.mo.p(ind)) '\n']);
    end
end
fclose(fid);

if do.display
    figure;
    barmod=barh(out.mo.tree.est(end:-1:2),'BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
    set(gca,'fontsize',18);
    set(gca,'ytick',1:length(ix.classuse),'yticklabel',{heads.retro{ix.classuse(end:-1:1)}});
    set(gca,'ylim',[0.5 length(ix.classuse)+0.5]);
    % set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
    % set(gca,'xlim',log([1/5 5]));
    xlabel('Gini Importance');
    hold on
    if do.permutations
        %     barerrLB=barh(out.mo.tree.CI(end:-1:2,1),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
        barerrUB=barh(out.mo.tree.CI(end:-1:2),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    else
        % there is no estimate of error for importance
        %     ebs=errbar(out.mo.est(end:-1:2).*out.rescale',1:length(out.rescale)',1.96*sqrt(out.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
    end
    hold off
end

if do.permutations
    ix.tree.sigpred=find(out.mo.tree.phat<0.05);
    [tmpx,ix.tree.sigpredord]=sort(out.mo.tree.est(ix.tree.sigpred),'ascend');
else
    ix.tree.sigpred=find(out.mo.tree.est>0);
end
if do.display
    figure;
    barmod=barh(out.mo.tree.est(ix.tree.sigpred(ix.tree.sigpredord)),'BarWidth',1,'Facecolor',[1 0 0],'Edgecolor',[1 1 1]);
    set(gca,'fontsize',18);
    if do.age
        set(gca,'ytick',1:length(ix.tree.sigpred),'yticklabel',{heads.retro{ix.tree.sigpred(ix.tree.sigpredord)-1}});
    else
        set(gca,'ytick',1:length(ix.tree.sigpred),'yticklabel',{heads.retro{ix.tree.sigpred(ix.tree.sigpredord)}});
    end
    set(gca,'ylim',[0.5 length(ix.tree.sigpred)+0.5]);
    % set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
    % set(gca,'xlim',log([1/5 5]));
    xlabel('Gini Importance');
    hold on
    if do.permutations
        %     barerrLB=barh(out.mo.tree.CI(ix.tree.sigpred,1),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
        barerrUB=barh(out.mo.tree.CI(ix.tree.sigpred(ix.tree.sigpredord)),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
    else
        % there is no estimate of error for importance
        %     ebs=errbar(out.mo.est(end:-1:2).*out.rescale',1:length(out.rescale)',1.96*sqrt(out.mi.com(end:-1:2)).*out.rescale','horiz','LineWidth',3,'Color',[0 0 0]);
    end
    hold off
end

%% Process the Predictions
fprintf('Assess the performance\n');

if do.permutations
    out.perm.pred        =zeros(size(out.mi.pred,1),3,n.permutations);
    if do.ROC
        out.perm.ROC         =zeros(n.prosp.Dx,2,n.permutations);
        summary.perm.AUC     =zeros(n.permutations,1);
    end
    if ~do.ROC && do.AUC
        out.perm.ROC         =zeros(n.prosp.Dx,2);
        summary.perm.AUC     =zeros(n.permutations,1);
    end
    summary.perm.sens    =zeros(n.permutations,1);
    summary.perm.spec    =zeros(n.permutations,1);
    summary.perm.ESPV    =zeros(n.permutations,1);
    summary.perm.PSPV    =zeros(n.permutations,1);
    summary.perm.ovacc   =zeros(n.permutations,1);
    if do.mi
        out.perm.mi.preds    =zeros(size(out.mi.pred,1),n.imputations,2,n.permutations);
        if do.ROC
            out.perm.mi.ROC      =zeros(n.prosp.Dx,n.imputations,2,n.permutations);
            summary.perm.mi.AUC  =zeros(n.imputations,n.permutations);
        end
        summary.perm.mi.sens =zeros(n.imputations,n.permutations);
        summary.perm.mi.spec =zeros(n.imputations,n.permutations);
        summary.perm.mi.ESPV =zeros(n.imputations,n.permutations);
        summary.perm.mi.PSPV =zeros(n.imputations,n.permutations);
        summary.perm.mi.ovacc=zeros(n.imputations,n.permutations);
    end
    
    for rnd=1:n.permutations
        % 1: continuous prediction: average in logit space
        % 2: binary prediction
        % 3: yhat
        % proposed.trans=log(proposed.raw./(1-proposed.raw));
        tmp.preds.logit=log(out.perm.mi.pred(:,:,rnd)./(1-out.perm.mi.pred(:,:,rnd)));
        tmp.preds.probs=mean(tmp.preds.logit,2);
        out.perm.pred(:,1,rnd)=exp(tmp.preds.probs)./(1+exp(tmp.preds.probs));
        out.perm.pred(:,2,rnd)=round(out.perm.pred(:,1,rnd))*2-1;
        out.perm.pred(:,3,rnd)=1*(out.perm.pred(:,2,rnd)==data.prosp.Dx(ix.prosp.hazDx,2));
        if do.ROC
            tmp.thresh=sort(out.perm.pred(:,1,rnd));
            for snd=1:n.prosp.Dx
                out.perm.ROC(snd,1,rnd)=sum(out.perm.pred(ix.testp.classid{1},1,rnd)>=tmp.thresh(snd),1)/length(ix.testp.classid{1});
                out.perm.ROC(snd,2,rnd)=1-sum(out.perm.pred(ix.testp.classid{5},1,rnd)<tmp.thresh(snd),1)/length(ix.testp.classid{5});
                if snd>1
                    summary.perm.AUC(rnd)=summary.perm.AUC(rnd)+(1-out.perm.ROC(snd,2,rnd))*(out.perm.ROC(snd-1,1,rnd)-out.perm.ROC(snd,1,rnd));
                end
            end
            
            if do.mi
                % 1: binary prediction
                % 2: yhat
                out.perm.mi.preds(:,:,1,rnd)=round(out.perm.mi.pred(:,:,1))*2-1;
                out.perm.mi.preds(:,:,2,rnd)=1*(out.perm.mi.preds(:,:,1,rnd)==repmat(data.prosp.Dx(ix.prosp.hazDx,2),[1 n.imputations]));
                for mnd=1:n.imputations
                    tmp.thresh=sort(out.perm.mi.pred(:,mnd,1));
                    for snd=1:n.prosp.Dx
                        out.perm.mi.ROC(snd,mnd,1,rnd)=sum(out.perm.mi.pred(ix.testp.classid{1},mnd,rnd)>=tmp.thresh(snd))/length(ix.testp.classid{1});
                        out.perm.mi.ROC(snd,mnd,2,rnd)=1-sum(out.perm.mi.pred(ix.testp.classid{5},mnd,rnd) <tmp.thresh(snd))/length(ix.testp.classid{5});
                        if snd>1
                            summary.perm.mi.AUC(mnd,rnd)=summary.perm.mi.AUC(mnd,rnd)+(1-out.perm.mi.ROC(snd,mnd,2,rnd))*(out.perm.mi.ROC(snd-1,mnd,1,rnd)-out.perm.mi.ROC(snd,mnd,1,rnd));
                        end
                    end
                end
            end
        elseif do.AUC
            tmp.thresh=sort(out.perm.pred(:,1,rnd));
            out.perm.ROC         =zeros(n.prosp.Dx,2);
            for snd=1:n.prosp.Dx
                out.perm.ROC(snd,1)=sum(out.perm.pred(ix.testp.classid{1},1,rnd)>=tmp.thresh(snd),1)/length(ix.testp.classid{1});
                out.perm.ROC(snd,2)=1-sum(out.perm.pred(ix.testp.classid{5},1,rnd)<tmp.thresh(snd),1)/length(ix.testp.classid{5});
                if snd>1
                    summary.perm.AUC(rnd)=summary.perm.AUC(rnd)+(1-out.perm.ROC(snd,2))*(out.perm.ROC(snd-1,1)-out.perm.ROC(snd,1));
                end
            end
        end
        
        % %% Performance Summary Figures
        
        % combining the imputations        
        summary.perm.sens(rnd) =mean(out.perm.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3,rnd),1);
        summary.perm.spec(rnd) =mean(out.perm.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3,rnd),1);
        summary.perm.ESPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.pred(:,2,rnd)==1)),2)==1);
        summary.perm.PSPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.pred(:,2,rnd)==-1)),2)==-1);
        summary.perm.ovacc(rnd)=mean(out.perm.pred(:,3,rnd),1);
        
        if do.mi
            % by each imputation separately
            summary.perm.mi.sens(:,rnd)=mean(out.perm.mi.preds(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),:,2,rnd),1);
            summary.perm.mi.spec(:,rnd)=mean(out.perm.mi.preds(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),:,2,rnd),1);
            for mnd=1:n.imputations
                summary.perm.mi.ESPV(mnd,rnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.mi.preds(:,mnd,1,rnd)==1)),2)==1);
                summary.perm.mi.PSPV(mnd,rnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.mi.preds(:,mnd,1,rnd)==-1)),2)==-1);
            end
            summary.perm.mi.ovacc(:,rnd)=mean(out.perm.mi.preds(:,:,2,rnd),1);
        end
        clear tmp;
    end
end
fprintf('Calculations Finished, now just writing out and displaying\n');

% Logistic Regression First
out.prosp.pred     =zeros(size(out.mi.pred,1),3);
% 1: continuous prediction: average in logit space
% 2: binary prediction
% 3: yhat
% proposed.trans=log(proposed.raw./(1-proposed.raw));
tmp.preds.logit=log(out.mi.pred./(1-out.mi.pred));
tmp.preds.probs=mean(tmp.preds.logit(:,:,1),2);
out.prosp.pred(:,1)=exp(tmp.preds.probs)./(1+exp(tmp.preds.probs));
out.prosp.pred(:,2)=round(out.prosp.pred(:,1))*2-1;
out.prosp.pred(:,3)=1*(out.prosp.pred(:,2)==data.prosp.Dx(ix.prosp.hazDx,2));

[summary.AUCs(2,1),summary.AUCs(2,2:3)]=auc([data.prosp.Dx(ix.prosp.hazDx,2)';out.prosp.pred(:,1)']',0.05,'hanley');

out.prosp.ROC=zeros(n.prosp.Dx,2);
summary.AUC=0;
tmp.thresh=sort(out.prosp.pred(:,1));
for snd=1:n.prosp.Dx
    out.prosp.ROC(snd,1)=sum(out.prosp.pred(ix.testp.classid{1},1)>=tmp.thresh(snd))/length(ix.testp.classid{1});
    out.prosp.ROC(snd,2)=1-sum(out.prosp.pred(ix.testp.classid{5},1)<tmp.thresh(snd))/length(ix.testp.classid{5});
    if snd>1
        summary.AUC=summary.AUC+(1-out.prosp.ROC(snd,2))*(out.prosp.ROC(snd-1,1)-out.prosp.ROC(snd,1));
    end
end

if do.display
    if do.ROC
        figure;
        p2=plot(out.prosp.ROC(:,2),out.prosp.ROC(:,1),'LineWidth',2,'color','black');
        hold on
        if do.permutations
            fprintf('We cannot handle an ROC curve yet\n');
            %     for rnd=1:n.permutations
            %         p3=plot(out.perm.ROC(:,2,rnd),out.perm.ROC(:,1,rnd),'LineWidth',2,'color',[0.8 0.8 0.8]);
            %     end
        end
        hold off
        set(gca,'fontsize',14);
        axis square
        title('Combined Prediction');
        xlabel('Percent ES above threshold (false positive rate)');
        ylabel('Percent PNES above threshold (true positive rate)');
        set(gca,'xlim',[0 1],'ylim',[0 1]);
        set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
        set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    end
end

% Now trees
out.prosp.tree.pred=zeros(size(out.mi.tree.pred,1),3);
% 1: Continuous prediction: average across imputations
% 2: binary prediction
% 3: yhat
out.prosp.tree.pred(:,1)=mean(out.mi.tree.pred,2);
out.prosp.tree.pred(:,2)=round(out.prosp.tree.pred(:,1))*2-1;
out.prosp.tree.pred(:,3)=1*(out.prosp.tree.pred(:,2)==data.prosp.Dx(ix.prosp.hazDx,2));

[summary.AUCs(1,1),summary.AUCs(1,2:3)]=auc([data.prosp.Dx(ix.prosp.hazDx,2)';out.prosp.tree.pred(:,1)']',0.05,'hanley');

out.prosp.tree.ROC=zeros(n.prosp.Dx,2);
summary.tree.AUC=0;
tmp.thresh=sort(out.prosp.tree.pred(:,1));
for snd=1:n.prosp.Dx
    out.prosp.tree.ROC(snd,1)=sum(out.prosp.tree.pred(ix.testp.classid{1},1)>=tmp.thresh(snd))/length(ix.testp.classid{1});
    out.prosp.tree.ROC(snd,2)=1-sum(out.prosp.tree.pred(ix.testp.classid{5},1)<tmp.thresh(snd))/length(ix.testp.classid{5});
    if snd>1
        summary.tree.AUC=summary.tree.AUC+(1-out.prosp.tree.ROC(snd,2))*(out.prosp.tree.ROC(snd-1,1)-out.prosp.tree.ROC(snd,1));
    end
end

if do.permutations
    out.perm.tree.pred=zeros(size(out.perm.mi.tree.pred,1),3,n.permutations);
    % 1: Continuous prediction: average across imputations
    % 2: binary prediction
    % 3: Accuracy
    out.perm.tree.pred(:,1,:)=mean(out.perm.mi.tree.pred,2);
    out.perm.tree.pred(:,2,:)=round(out.perm.tree.pred(:,1,:))*2-1;   
    
    % combining the imputations
    summary.tree.perm.sens=zeros(n.permutations,1);
    summary.tree.perm.spec=summary.tree.perm.sens;
    summary.tree.perm.ESPV=summary.tree.perm.sens;
    summary.tree.perm.PSPV=summary.tree.perm.sens;
    summary.tree.perm.ovacc=summary.tree.perm.sens;
    for rnd=1:n.permutations
        out.perm.tree.pred(:,3,rnd)=1*(out.perm.tree.pred(:,2,rnd)==data.prosp.Dx(ix.prosp.hazDx,2));
        summary.tree.perm.sens(rnd) =mean(out.perm.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3,rnd),1);
        summary.tree.perm.spec(rnd) =mean(out.perm.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3,rnd),1);
        summary.tree.perm.ESPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.tree.pred(:,2,rnd)==1)),2)==1);
        summary.tree.perm.PSPV(rnd) =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.perm.tree.pred(:,2,rnd)==-1)),2)==-1);
        summary.tree.perm.ovacc(rnd)=mean(out.perm.tree.pred(:,3,rnd),1);
    end

    
    if do.ROC
        fprintf('Working on ROC curves\n');
        out.perm.tree.ROC=zeros(n.prosp.Dx,2,n.permutations);
        summary.perm.tree.AUC=zeros(n.permutations,1);
        for rnd=1:n.permutations
            tmp.thresh=sort(out.perm.tree.pred(:,1,rnd));
            if length(unique(tmp.thresh))>1
                for snd=1:n.prosp.Dx
                    out.perm.tree.ROC(snd,1,rnd)=sum(out.perm.tree.pred(ix.testp.classid{1},1,rnd)>=tmp.thresh(snd))/length(ix.testp.classid{1});
                    out.perm.tree.ROC(snd,2,rnd)=1-sum(out.perm.tree.pred(ix.testp.classid{5},1,rnd)<tmp.thresh(snd))/length(ix.testp.classid{5});
                    if snd>1
                        summary.perm.tree.AUC(rnd)=summary.perm.tree.AUC(rnd)+(1-out.perm.tree.ROC(snd,2,rnd))*(out.perm.tree.ROC(snd-1,1,rnd)-out.perm.tree.ROC(snd,1,rnd));
                    end
                end
            else
                out.perm.tree.ROC(1,1,rnd)=1;
                out.perm.tree.ROC(1,2,rnd)=0;
                summary.perm.tree.AUC(rnd)=max(length(ix.testp.classid{1}),length(ix.testp.classid{5}))/(length(ix.testp.classid{1})+length(ix.testp.classid{5}));
            end
        end
    elseif do.AUC
        fprintf('Working on AUCs\n');
        summary.perm.tree.AUC=zeros(n.permutations,1);
        for rnd=1:n.permutations
            out.perm.tree.ROC=zeros(n.prosp.Dx,2);
            tmp.thresh=sort(out.perm.tree.pred(:,1,rnd));
            if length(unique(tmp.thresh))>1
                for snd=1:n.prosp.Dx
                    out.perm.tree.ROC(snd,1)=sum(out.perm.tree.pred(ix.testp.classid{1},1,rnd)>=tmp.thresh(snd))/length(ix.testp.classid{1});
                    out.perm.tree.ROC(snd,2)=1-sum(out.perm.tree.pred(ix.testp.classid{5},1,rnd)<tmp.thresh(snd))/length(ix.testp.classid{5});
                    if snd>1
                        summary.perm.tree.AUC(rnd)=summary.perm.tree.AUC(rnd)+(1-out.perm.tree.ROC(snd,2))*(out.perm.tree.ROC(snd-1,1)-out.perm.tree.ROC(snd,1));
                    end
                end
            else
                out.perm.tree.ROC(1,1)=1;
                out.perm.tree.ROC(1,2)=0;
                summary.perm.tree.AUC(rnd)=max(length(ix.testp.classid{1}),length(ix.testp.classid{5}))/(length(ix.testp.classid{1})+length(ix.testp.classid{5}));
            end
        end
    end
end
fprintf('Back to writing out and displaying\n');

if do.display
    if do.ROC
        figure;
        p2=plot(out.prosp.tree.ROC(:,2),out.prosp.tree.ROC(:,1),'LineWidth',2,'color','black');
        hold on
        if do.permutations
            for rnd=1:n.permutations
                p3=plot(out.perm.tree.ROC(:,2,rnd),out.perm.tree.ROC(:,1,rnd),'LineWidth',2,'color',[0.8 0.8 0.8]);
            end
        end
        hold off
        set(gca,'fontsize',14);
        axis square
        title('Combined Prediction - Tree');
        xlabel('Percent ES above threshold (false positive rate)');
        ylabel('Percent PNES above threshold (true positive rate)');
        set(gca,'xlim',[0 1],'ylim',[0 1]);
        set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
        set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    end
end

if do.mi
    % Back to Logistic Regression by Imputation
    % (this doesn't make sense in trees)
    out.prosp.mi.pred=zeros(size(out.mi.pred,1),n.imputations,2);
    % 1: binary prediction
    % 2: yhat
    out.prosp.mi.pred(:,:,1)=round(out.mi.pred(:,:,1))*2-1;
    out.prosp.mi.pred(:,:,2)=1*(out.prosp.mi.pred(:,:,1)==repmat(data.prosp.Dx(ix.prosp.hazDx,2),[1 n.imputations]));
    out.prosp.oth.pred=round(out.mi.oth.pred)*2-1;
    out.prosp.mi.ROC=zeros(n.prosp.Dx,n.imputations,2);
    summary.mi.AUC=zeros(n.imputations,1);
    for mnd=1:n.imputations
        tmp.thresh=sort(out.mi.pred(:,mnd,1));
        for snd=1:n.prosp.Dx
            out.prosp.mi.ROC(snd,mnd,1)=sum(out.mi.pred(ix.testp.classid{1},mnd,1)>=tmp.thresh(snd))/length(ix.testp.classid{1});
            out.prosp.mi.ROC(snd,mnd,2)=1-sum(out.mi.pred(ix.testp.classid{5},mnd,1) <tmp.thresh(snd))/length(ix.testp.classid{5});
            if snd>1
                summary.mi.AUC(mnd)=summary.mi.AUC(mnd)+(1-out.prosp.mi.ROC(snd,mnd,2))*(out.prosp.mi.ROC(snd-1,mnd,1)-out.prosp.mi.ROC(snd,mnd,1));
            end
        end
    end
    if do.display
        figure;
        p2=plot(out.prosp.mi.ROC(:,:,2),out.prosp.mi.ROC(:,:,1),'LineWidth',2);
        hold on
        if do.permutations
            for rnd=1:n.permutations
                p3=plot(out.perm.mi.ROC(:,:,2,rnd),out.perm.mi.ROC(:,:,1,rnd),'LineWidth',2,'color',[0.8 0.8 0.8]);
            end
        end
        hold off
        set(gca,'fontsize',14);
        axis square
        title('Prediction by imputation');
        xlabel('Percent ES above threshold (false positive rate)');
        ylabel('Percent PNES above threshold (true positive rate)');
        set(gca,'xlim',[0 1],'ylim',[0 1]);
        set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
        set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    end
end



%% Performance Summary Figures

% combining the imputations
clear tmp
summary.sens =mean(out.prosp.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3),1);
summary.sensCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(1),summary.sens)/n.prosp.classes(1),binoinv(normcdf(1,0,1),n.prosp.classes(1),summary.sens)/n.prosp.classes(1)];
summary.spec =mean(out.prosp.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3),1);
summary.specCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(5),summary.spec)/n.prosp.classes(5),binoinv(normcdf(1,0,1),n.prosp.classes(5),summary.spec)/n.prosp.classes(5)];
tmp.n=sum(out.prosp.pred(:,2)==1);
summary.ESPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.pred(:,2)==1)),2)==1);
summary.ESPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.ESPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.ESPV)/tmp.n];
tmp.n=sum(out.prosp.pred(:,2)==-1);
summary.PSPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.pred(:,2)==-1)),2)==-1);
summary.PSPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.PSPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.PSPV)/tmp.n];
summary.ovacc=mean(out.prosp.pred(:,3),1);
summary.ovaccCI=[binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.ovacc)/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.ovacc)/n.prosp.Dx];
tmp.list=sort(summary.perm.AUC);
summary.AUCs(3,:)=[tmp.list(round(0.5*n.permutations)),tmp.list(floor(0.025*n.permutations)),tmp.list(ceil(0.975*n.permutations))];

if do.permutations
    summary.p.sens =permtest(summary.sens ,summary.perm.sens ,0);
    summary.p.spec =permtest(summary.spec ,summary.perm.spec ,0);
    summary.p.ESPV =permtest(summary.ESPV ,summary.perm.ESPV ,0);
    summary.p.PSPV =permtest(summary.PSPV ,summary.perm.PSPV ,0);
    summary.p.ovacc=permtest(summary.ovacc,summary.perm.ovacc,0);
    summary.p.AUC  =permtest(summary.AUC  ,summary.perm.AUC  ,0);
end

% now trees
clear tmp
summary.tree.sens =mean(out.prosp.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),3),1);
summary.tree.sensCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(1),summary.tree.sens)/n.prosp.classes(1),binoinv(normcdf(1,0,1),n.prosp.classes(1),summary.tree.sens)/n.prosp.classes(1)];
summary.tree.spec =mean(out.prosp.tree.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),3),1);
summary.tree.specCI=[binoinv(normcdf(-1,0,1),n.prosp.classes(5),summary.tree.spec)/n.prosp.classes(5),binoinv(normcdf(1,0,1),n.prosp.classes(5),summary.tree.spec)/n.prosp.classes(5)];
tmp.n=sum(out.prosp.tree.pred(:,2)==1);
summary.tree.ESPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.tree.pred(:,2)==1)),2)==1);
summary.tree.ESPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.tree.ESPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.tree.ESPV)/tmp.n];
tmp.n=sum(out.prosp.tree.pred(:,2)==-1);
summary.tree.PSPV =mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.tree.pred(:,2)==-1)),2)==-1);
summary.tree.PSPVCI=[binoinv(normcdf(-1,0,1),tmp.n,summary.tree.PSPV)/tmp.n,binoinv(normcdf(1,0,1),tmp.n,summary.tree.PSPV)/tmp.n];
summary.tree.ovacc=mean(out.prosp.tree.pred(:,3),1);
summary.tree.ovaccCI=[binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.tree.ovacc)/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.tree.ovacc)/n.prosp.Dx];
tmp.list=sort(summary.perm.tree.AUC);
summary.tree.AUCs(3,:)=[tmp.list(round(0.5*n.permutations)),tmp.list(floor(0.025*n.permutations)),tmp.list(ceil(0.975*n.permutations))];


if do.permutations
    summary.tree.p.sens =permtest(summary.tree.sens ,summary.tree.perm.sens ,0);
    summary.tree.p.spec =permtest(summary.tree.spec ,summary.tree.perm.spec ,0);
    summary.tree.p.ESPV =permtest(summary.tree.ESPV ,summary.tree.perm.ESPV ,0);
    summary.tree.p.PSPV =permtest(summary.tree.PSPV ,summary.tree.perm.PSPV ,0);
    summary.tree.p.ovacc=permtest(summary.tree.ovacc,summary.tree.perm.ovacc,0);
    summary.tree.p.AUC  =permtest(summary.tree.AUC  ,summary.perm.tree.AUC  ,0);
end

if do.mi
    % Logistic Regression by each imputation separately
    summary.mi.sens =mean(out.prosp.mi.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==1),:,2),1);
    summary.mi.spec =mean(out.prosp.mi.pred(find(data.prosp.Dx(ix.prosp.hazDx,2)==-1),:,2),1);
    summary.mi.ESPV =zeros(n.imputations,1);
    summary.mi.PSPV =summary.mi.ESPV;
    for mnd=1:n.imputations
        summary.mi.ESPV(mnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.mi.pred(:,mnd,1)==1)),2)==1);
        summary.mi.PSPV(mnd)=mean(data.prosp.Dx(ix.prosp.hazDx(find(out.prosp.mi.pred(:,mnd,1)==-1)),2)==-1);
    end
    summary.mi.ovacc=mean(out.prosp.mi.pred(:,:,2),1);
    
    summary.mi.p.sens =zeros(n.imputations,1);
    summary.mi.p.spec =zeros(n.imputations,1);
    summary.mi.p.ESPV =zeros(n.imputations,1);
    summary.mi.p.PSPV =zeros(n.imputations,1);
    summary.mi.p.ovacc=zeros(n.imputations,1);
    clear tmp;
    if do.permutations
        for mnd=1:n.imputations
            tmp                    =permtest(summary.mi.sens(mnd) ,squeeze(summary.perm.mi.sens(mnd,:)) ,0);
            summary.mi.p.sens(mnd) =tmp.quantiles;
            tmp                    =permtest(summary.mi.spec(mnd) ,squeeze(summary.perm.mi.spec(mnd,:)) ,0);
            summary.mi.p.spec(mnd) =tmp.quantiles;
            tmp                    =permtest(summary.mi.ESPV(mnd) ,squeeze(summary.perm.mi.ESPV(mnd,:)) ,0);
            summary.mi.p.ESPV(mnd) =tmp.quantiles;
            tmp                    =permtest(summary.mi.PSPV(mnd) ,squeeze(summary.perm.mi.PSPV(mnd,:)) ,0);
            summary.mi.p.PSPV(mnd) =tmp.quantiles;
            tmp                    =permtest(summary.mi.ovacc(mnd),squeeze(summary.perm.mi.ovacc(mnd,:)),0);
            summary.mi.p.ovacc(mnd)=tmp.quantiles;
        end
    end
end

summary.chance.ovacc  =max(n.prosp.classes([1 5]))/sum(n.prosp.classes([1 5]));
summary.chance.ovacc95(1)=binoinv(0.025,sum(n.prosp.classes([1 5])),summary.chance.ovacc)/sum(n.prosp.classes([1 5]));
summary.chance.ovacc95(2)=binoinv(0.975,sum(n.prosp.classes([1 5])),summary.chance.ovacc)/sum(n.prosp.classes([1 5]));

%% Performance Figure
summary.perf=[summary.ovacc,summary.sens,summary.spec,summary.ESPV,summary.PSPV];
summary.perfCI=[summary.ovaccCI;summary.sensCI;summary.specCI;summary.ESPVCI;summary.PSPVCI];
summary.tree.perf=[summary.tree.ovacc,summary.tree.sens,summary.tree.spec,summary.tree.ESPV,summary.tree.PSPV];
summary.tree.perfCI=[summary.tree.ovaccCI;summary.tree.sensCI;summary.tree.specCI;summary.tree.ESPVCI;summary.tree.PSPVCI];
summary.naive=[max(n.prosp.classes(ix.DxES),n.prosp.classes(ix.DxPNES))/n.prosp.Dx,1,0,max(n.prosp.classes(ix.DxES),n.prosp.classes(ix.DxPNES))/n.prosp.Dx,0];
summary.naiveCI=[binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx;
    binoinv(normcdf(-1,0,1),n.prosp.classes(ix.DxES),1-1/n.prosp.classes(ix.DxES)/2)/n.prosp.classes(ix.DxES),binoinv(normcdf(1,0,1),n.prosp.classes(ix.DxES),1-1/n.prosp.classes(ix.DxES)/2)/n.prosp.classes(ix.DxES);
    binoinv(normcdf(-1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES),binoinv(normcdf(1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES);
    binoinv(normcdf(-1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx,binoinv(normcdf(1,0,1),n.prosp.Dx,summary.naive(1))/n.prosp.Dx;
    binoinv(normcdf(-1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES),binoinv(normcdf(1,0,1),n.prosp.classes(ix.DxPNES),1/n.prosp.classes(ix.DxPNES)/2)/n.prosp.classes(ix.DxPNES)];
[summary.AUCs(4,1),summary.AUCs(4,2:3)]=auc([data.prosp.Dx(ix.prosp.hazDx,2)';ones(1,length(ix.prosp.hazDx))]',0.05,'hanley');
tmp.med=floor(n.permutations/2);
tmp.CI95=[floor(n.permutations*0.025),ceil(n.permutations*0.975)];    
summary.tree.perms=[median(summary.tree.perm.ovacc),median(summary.tree.perm.sens),median(summary.tree.perm.spec),median(summary.tree.perm.ESPV),median(summary.tree.perm.PSPV)];
summary.tree.permsCI=zeros(5,2);
tmp.perms=sort(summary.tree.perm.ovacc);
summary.tree.permsCI(1,1)=tmp.perms(tmp.CI95(1));
summary.tree.permsCI(1,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.tree.perm.sens);
summary.tree.permsCI(2,1)=tmp.perms(tmp.CI95(1));
summary.tree.permsCI(2,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.tree.perm.spec);
summary.tree.permsCI(3,1)=tmp.perms(tmp.CI95(1));
summary.tree.permsCI(3,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.tree.perm.ESPV);
summary.tree.permsCI(4,1)=tmp.perms(tmp.CI95(1));
summary.tree.permsCI(4,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.tree.perm.PSPV);
summary.tree.permsCI(5,1)=tmp.perms(tmp.CI95(1));
summary.tree.permsCI(5,2)=tmp.perms(tmp.CI95(2));
summary.perms=[median(summary.perm.ovacc),median(summary.perm.sens),median(summary.perm.spec),median(summary.perm.ESPV),median(summary.perm.PSPV)];

summary.permsCI=zeros(5,2);
tmp.perms=sort(summary.perm.ovacc);
summary.permsCI(1,1)=tmp.perms(tmp.CI95(1));
summary.permsCI(1,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.perm.sens);
summary.permsCI(2,1)=tmp.perms(tmp.CI95(1));
summary.permsCI(2,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.perm.spec);
summary.permsCI(3,1)=tmp.perms(tmp.CI95(1));
summary.permsCI(3,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.perm.ESPV);
summary.permsCI(4,1)=tmp.perms(tmp.CI95(1));
summary.permsCI(4,2)=tmp.perms(tmp.CI95(2));
tmp.perms=sort(summary.perm.PSPV);
summary.permsCI(5,1)=tmp.perms(tmp.CI95(1));
summary.permsCI(5,2)=tmp.perms(tmp.CI95(2));

summary.chan=zeros(5,4); % -1 SD, Median, +1 SD, 97.5%
cutoff.quantiles=[normcdf(-1,0,1),0.5,normcdf(1,0,1),0.975];
if do.permutations
    tmp=sort(summary.perm.ovacc);
    for ind=1:4
        summary.chan(1,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.sens);
    for ind=1:4
        summary.chan(2,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.spec);
    for ind=1:4
        summary.chan(3,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.ESPV);
    for ind=1:4
        summary.chan(4,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
    tmp=sort(summary.perm.PSPV);
    for ind=1:4
        summary.chan(5,ind)=tmp(ceil(length(tmp)*cutoff.quantiles(ind)));
    end
end

if do.display
    figure
    bar3=barh(summary.perf(5:-1:1),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
    set(gca,'fontsize',16);
    set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
    set(gca,'ylim',[0.5 5.5]);
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    hold on
    cha3=barh(summary.chan(5:-1:1,4),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
    cnt=1;
    for jnd=5:-1:1
        ebs3=errbar(summary.perf(jnd),cnt,abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        cnt=cnt+1;
    end
    hold off
    
    figure
    bar3=barh(summary.tree.perf(5:-1:1),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
    set(gca,'fontsize',16);
    title('Tree');
    set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
    set(gca,'ylim',[0.5 5.5]);
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    hold on
    cha3=barh(summary.chan(5:-1:1,4),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
    cnt=1;
    for jnd=5:-1:1
        ebs3=errbar(summary.tree.perf(jnd),cnt,abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        cnt=cnt+1;
    end
    hold off
    
    figure;
    if do.permutations
        bar4=barh([summary.naive(5:-1:1)',summary.chan(5:-1:1,2),summary.perf(5:-1:1)'],'BarWidth',1);
    else
        bar4=barh([summary.naive(5:-1:1)',summary.perf(5:-1:1)'],'BarWidth',1);
    end
    set(gca,'fontsize',16);
    set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    set(bar4(1),'FaceColor',[0.70 0.3 1],...
        'DisplayName','Naive Assumption');
    if do.permutations
        set(bar4(2),'FaceColor',[0.3 1 0.7],...
            'DisplayName','Permuted Data');
        set(bar4(3),'FaceColor',[1 0.3 0.7],...
            'DisplayName','Our Model');
    else
        set(bar4(2),'FaceColor',[1 0.3 0.7],...
            'DisplayName','Our Model');
    end
    legend1 = legend(gca,'show');
    hold on
    cnt=1;
    if do.permutations
        offset=[-0.23,0,0.23];
    else
        offset=[-0.14,0.14];
    end
    for jnd=5:-1:1
        ebs4=errbar(summary.naive(jnd),cnt+offset(1),abs(summary.naive(jnd)-summary.naiveCI(jnd,1)),abs(summary.naive(jnd)-summary.naiveCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        if do.permutations
            ebs4=errbar(summary.chan(jnd,2),cnt+offset(2),abs(summary.chan(jnd,2)-summary.chan(jnd,1)),abs(summary.chan(jnd,2)-summary.chan(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
            ebs4=errbar(summary.perf(jnd),cnt+offset(3),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        else
            ebs4=errbar(summary.perf(jnd),cnt+offset(2),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        end
        cnt=cnt+1;
    end
    hold off
    
    figure;
    if do.permutations
        bar4=barh([summary.naive(5:-1:1)',summary.chan(5:-1:1,2),summary.tree.perf(5:-1:1)'],'BarWidth',1);
    else
        bar4=barh([summary.naive(5:-1:1)',summary.tree.perf(5:-1:1)'],'BarWidth',1);
    end
    set(gca,'fontsize',16);
    set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    set(bar4(1),'FaceColor',[0.70 0.3 1],...
        'DisplayName','Naive Assumption');
    if do.permutations
        set(bar4(2),'FaceColor',[0.3 1 0.7],...
            'DisplayName','Permuted Data');
        set(bar4(3),'FaceColor',[1 0.3 0.7],...
            'DisplayName','Our Tree Model');
    else
        set(bar4(2),'FaceColor',[1 0.3 0.7],...
            'DisplayName','Our Tree Model');
    end
    legend1 = legend(gca,'show');
    hold on
    cnt=1;
    if do.permutations
        offset=[-0.23,0,0.23];
    else
        offset=[-0.14,0.14];
    end
    for jnd=5:-1:1
        ebs4=errbar(summary.naive(jnd),cnt+offset(1),abs(summary.naive(jnd)-summary.naiveCI(jnd,1)),abs(summary.naive(jnd)-summary.naiveCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        if do.permutations
            ebs4=errbar(summary.chan(jnd,2),cnt+offset(2),abs(summary.chan(jnd,2)-summary.chan(jnd,1)),abs(summary.chan(jnd,2)-summary.chan(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
            ebs4=errbar(summary.tree.perf(jnd),cnt+offset(3),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        else
            ebs4=errbar(summary.tree.perf(jnd),cnt+offset(2),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        end
        cnt=cnt+1;
    end
    hold off
    
    figure;
    if do.permutations
        bar4=barh([summary.naive(5:-1:1)',summary.chan(5:-1:1,2),summary.perf(5:-1:1)',summary.tree.perf(5:-1:1)'],'BarWidth',1);
    else
        bar4=barh([summary.naive(5:-1:1)',summary.perf(5:-1:1)',summary.tree.perf(5:-1:1)'],'BarWidth',1);
    end
    set(gca,'fontsize',16);
    set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    set(bar4(1),'FaceColor',[0.70 0.3 1],...
        'DisplayName','Naive Assumption');
    if do.permutations
        set(bar4(2),'FaceColor',[0.3 1 0.7],...
            'DisplayName','Permuted Data');
        set(bar4(3),'FaceColor',[1 0.3 0.7],...
            'DisplayName','Our Model');
        set(bar4(4),'FaceColor',[0.5 0.3 0.7],...
            'DisplayName','Our Tree Model');
    else
        set(bar4(2),'FaceColor',[1 0.3 0.7],...
            'DisplayName','Our Model');
        set(bar4(3),'FaceColor',[0.5 0.3 0.7],...
            'DisplayName','Our Tree Model');
    end
    legend1 = legend(gca,'show');
    hold on
    cnt=1;
    if do.permutations
        offset=[-0.26,-0.09,0.09,0.26];
    else
        offset=[-0.23,0,0.23];
    end
    for jnd=5:-1:1
        ebs4=errbar(summary.naive(jnd),cnt+offset(1),abs(summary.naive(jnd)-summary.naiveCI(jnd,1)),abs(summary.naive(jnd)-summary.naiveCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        if do.permutations
            ebs4=errbar(summary.chan(jnd,2),cnt+offset(2),abs(summary.chan(jnd,2)-summary.chan(jnd,1)),abs(summary.chan(jnd,2)-summary.chan(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
            ebs4=errbar(summary.perf(jnd),cnt+offset(3),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
            ebs4=errbar(summary.tree.perf(jnd),cnt+offset(4),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        else
            ebs4=errbar(summary.perf(jnd),cnt+offset(2),abs(summary.perf(jnd)-summary.perfCI(jnd,1)),abs(summary.perf(jnd)-summary.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
            ebs4=errbar(summary.tree.perf(jnd),cnt+offset(3),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,1)),abs(summary.tree.perf(jnd)-summary.tree.perfCI(jnd,2)),'horiz','LineWidth',3,'Color',[0 0 0]);
        end
        cnt=cnt+1;
    end
    hold off
end

%% Performance Table

fid=fopen(dirs.perftable,'w');
if do.permutations
    fprintf(fid,',Tree,,Logistic,,Permutations,,Naive\n');
else
    fprintf(fid,',Tree,,Logistic,,Naive\n');
end
for mnd=1:(3+do.permutations)
    fprintf(fid,',Mean,95 CI');
end
fprintf(fid,'\n');
fprintf(fid,'Accuracy,');
fprintf(fid,[num2str(round(summary.tree.ovacc*100,0)) ',' num2str(floor(summary.tree.ovaccCI(1)*100)) '--' num2str(ceil(summary.tree.ovaccCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.ovacc*100,0)) ',' num2str(floor(summary.ovaccCI(1)*100)) '--' num2str(ceil(summary.ovaccCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.chan(1,2)*100,0)) ',' num2str(floor(summary.chan(1,1)*100)) '--' num2str(ceil(summary.chan(1,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(1)*100,0)) ',' num2str(floor(summary.naiveCI(1,1)*100)) '--' num2str(ceil(summary.naiveCI(1,2)*100)) '\n']);
fprintf(fid,'Sensitivity,');
fprintf(fid,[num2str(round(summary.tree.sens*100,0)) ',' num2str(floor(summary.tree.sensCI(1)*100)) '--' num2str(ceil(summary.tree.sensCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.sens*100,0)) ',' num2str(floor(summary.sensCI(1)*100)) '--' num2str(ceil(summary.sensCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.chan(2,2)*100,0)) ',' num2str(floor(summary.chan(2,1)*100)) '--' num2str(ceil(summary.chan(2,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(2)*100,0)) ',' num2str(floor(summary.naiveCI(2,1)*100)) '--' num2str(ceil(summary.naiveCI(2,2)*100)) '\n']);
fprintf(fid,'Specificity,');
fprintf(fid,[num2str(round(summary.tree.spec*100,0)) ',' num2str(floor(summary.tree.specCI(1)*100)) '--' num2str(ceil(summary.tree.specCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.spec*100,0)) ',' num2str(floor(summary.specCI(1)*100)) '--' num2str(ceil(summary.specCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.chan(3,2)*100,0)) ',' num2str(floor(summary.chan(3,1)*100)) '--' num2str(ceil(summary.chan(3,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(3)*100,0)) ',' num2str(floor(summary.naiveCI(3,1)*100)) '--' num2str(ceil(summary.naiveCI(3,2)*100)) '\n']);
fprintf(fid,'ES-PV,');
fprintf(fid,[num2str(round(summary.tree.ESPV*100,0)) ',' num2str(floor(summary.tree.ESPVCI(1)*100)) '--' num2str(ceil(summary.tree.ESPVCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.ESPV*100,0)) ',' num2str(floor(summary.ESPVCI(1)*100)) '--' num2str(ceil(summary.ESPVCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.chan(4,2)*100,0)) ',' num2str(floor(summary.chan(4,1)*100)) '--' num2str(ceil(summary.chan(4,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(4)*100,0)) ',' num2str(floor(summary.naiveCI(4,1)*100)) '--' num2str(ceil(summary.naiveCI(4,2)*100)) '\n']);
fprintf(fid,'PNES-PV,');
fprintf(fid,[num2str(round(summary.tree.PSPV*100,0)) ',' num2str(floor(summary.tree.PSPVCI(1)*100)) '--' num2str(ceil(summary.tree.PSPVCI(2)*100)) ',']);
fprintf(fid,[num2str(round(summary.PSPV*100,0)) ',' num2str(floor(summary.PSPVCI(1)*100)) '--' num2str(ceil(summary.PSPVCI(2)*100)) ',']);
if do.permutations
    fprintf(fid,[num2str(round(summary.chan(5,2)*100,0)) ',' num2str(floor(summary.chan(5,1)*100)) '--' num2str(ceil(summary.chan(5,4)*100)) ',']);
end
fprintf(fid,[num2str(round(summary.naive(5)*100,0)) ',' num2str(floor(summary.naiveCI(5,1)*100)) '--' num2str(ceil(summary.naiveCI(5,2)*100)) '\n']);
if do.AUC
    fprintf(fid,'AUC,');
    fprintf(fid,[num2str(round(summary.tree.AUC*100,0)) ',' num2str(floor(summary.AUCs(1,2)*100)) '--' num2str(ceil(summary.AUCs(1,3)*100)) ',']);
    fprintf(fid,[num2str(round(summary.AUC*100,0)) ',' num2str(floor(summary.AUCs(2,2)*100)) '--' num2str(ceil(summary.AUCs(2,3)*100)) ',']);
    if do.permutations
        fprintf(fid,[num2str(round(summary.AUCs(3,1)*100,0)) ',' num2str(floor(summary.AUCs(3,2)*100)) '--' num2str(ceil(summary.AUCs(3,3)*100)) ',']);
    end
    fprintf(fid,[num2str(round(summary.AUCs(4,1)*100,0)) ',' num2str(floor(summary.AUCs(4,2)*100)) '--' num2str(ceil(summary.AUCs(4,3)*100)) ',']);
%     fprintf(fid,[num2str(round(summary.naive(5)*100,0)) ',' num2str(floor(summary.naiveCI(5,1)*100)) '--' num2str(ceil(summary.naiveCI(5,2)*100)) '\n']);
end
fclose(fid);

%% Predictions for Other Classes
%Logistic Regression for Other Classes
clear tmp;
out.prosp.oth.pred=NaN(size(out.mi.oth.pred,1),size(out.mi.oth.pred,4),2); % subject index, prob/bin, other class index
tmp.preds.oth.logit=log(out.mi.oth.pred./(1-out.mi.oth.pred));
tmp.preds.oth.probs=squeeze(mean(tmp.preds.oth.logit(:,:,1,:),2));
out.prosp.oth.pred(:,:,1)=exp(tmp.preds.oth.probs)./(1+exp(tmp.preds.oth.probs));
out.prosp.oth.pred(:,:,2)=round(out.prosp.oth.pred(:,:,1));

summary.oth.pred=zeros(3,3);
out.prosp.oth.tree.pred=squeeze(round(mean(out.mi.oth.tree.pred,2)));
for cnd=1:3
    tmp.ix=find(~isnan(out.prosp.oth.pred(:,cnd,1)));
    summary.oth.pred(cnd,1)=mean(out.prosp.oth.pred(tmp.ix,cnd,2));
    summary.oth.pred(cnd,2)=binoinv(0.025,length(tmp.ix),summary.oth.pred(cnd,1))/length(tmp.ix);
    summary.oth.pred(cnd,3)=binoinv(0.975,length(tmp.ix),summary.oth.pred(cnd,1))/length(tmp.ix);
    summary.oth.tree.pred(cnd,1)=mean(out.prosp.oth.tree.pred(tmp.ix,cnd));
    summary.oth.tree.pred(cnd,2)=binoinv(0.025,length(tmp.ix),summary.oth.tree.pred(cnd,1))/length(tmp.ix);
    summary.oth.tree.pred(cnd,3)=binoinv(0.975,length(tmp.ix),summary.oth.tree.pred(cnd,1))/length(tmp.ix);
end