%% This compiles the raw data from ES_Semiology into friendly figures for publication
% Wesley Kerr, July 2017, wesleytk@g.ucla.edu
%
% Displays to Make:
% 4. Descriptive models - 5 class
% 4a. Models - need fix age and table output
% 4b. Pairwise comparisons
% 4c. Descriptive Figures
%
% 5. Raw data display
% 5a. Continuous
% 5b. Binary
% 5c. Limit to just significant factors


dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.analysis =[dirs.base 'Dropbox/ES_Semiology/'];
dirs.data     =[dirs.base 'Documents/EMU/CI/Semiology/'];
dirs.retroDx  =[dirs.data 'Retro5_ForDx.csv'];
dirs.retrodata=[dirs.data 'Retro6_Semiology.csv'];
dirs.retroarff=[dirs.data 'Retro6_Semiology'];
dirs.retrosum =[dirs.analysis 'Retro6_ModelSummary.csv'];
dirs.retrotreesum =[dirs.analysis 'Retro6_ModelSummaryTree.csv'];
dirs.sigmodel =[dirs.analysis 'Retro6_SigModel.csv'];
dirs.prospDx  =[dirs.data 'Prosp_Diagnosis161122b.csv'];
dirs.prospdata=[dirs.data 'Prosp_Semiology161121.csv'];
dirs.prosparff=[dirs.analysis 'Prosp5_Semiology'];
dirs.pro2ret  =[dirs.analysis 'Semiology_Pro2Ret.csv'];
dirs.descrip  =[dirs.analysis 'Semiology_Descrip_Class.csv'];
dirs.pairwise =[dirs.analysis 'Semiology_DescripPairwise.csv'];
dirs.table1   =[dirs.analysis 'Semiology_Table1.csv'];
dirs.Stable1  =[dirs.analysis 'Semiology_STable1.csv'];
dirs.StableRvP=[dirs.analysis 'Semiology_STableRvP.csv'];
dirs.process  =[dirs.data 'Semiology_Processed'];
dirs.treeout  =[dirs.analysis 'Semiology_TreeOutput.txt'];
dirs.perftable=[dirs.analysis 'Semiology_Perf.csv'];

do.display=1; % Yes, this is a display script, but it's also summarizing tables

Colors5=[78 195 199;
    137 88 129;
    243 108 54;
    199 178 158;
    130 71 55]/256;

%% Load Data
dirs.done    =dir([dirs.process '*_0.mat']);
load([dirs.data dirs.done.name],'out','n','heads','ix','data','summary');
ix.dur=3;
ix.szf=4;

%% Descriptive Trend Figure - PNES vs ES
for znd=ix.data.cont
    if do.display
        figure;
    end
    
    if exist('ix.retro.Dur','var')
        if znd==4
            ssigma=2;
        elseif intersect(znd,[1,3])
            ssigma=2; % Gaussian window
        elseif intersect(znd,[5,6])
            ssigma=0.3;
        else
            ssigma=0.001;
        end
    else
        if intersect(znd,ix.retro.Age)
            ssigma=2;
        elseif intersect(znd,ix.retro.transform)
            ssigma=0.3;
        else
            ssigma=0.001;
        end
    end
    
    % make exact figure
    tmps.percvals=unique(data.retro(find(~isnan(data.retro(:,znd))),znd));
    tmps.perchist=zeros(length(tmps.percvals),2);
    for ind=1:length(tmps.percvals)
        tmps.perchist(ind,1)=sum(data.retro(ix.retro.classid{ix.DxPNES},znd)==tmps.percvals(ind));
        tmps.perchist(ind,2)=sum(data.retro(ix.retro.classid{ix.DxES},znd)==tmps.percvals(ind));
    end
    % add smoothing
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,7)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    else
        if intersect(znd,[3,4])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,5)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    end
    n.percvals=length(perc.val);
    perc.loess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
    % Gaussian smoothing kernel applied onto tmps.perchist
    for ind=1:n.percvals
        for jnd=1:length(tmps.percvals)
            perc.loess(ind,1)=perc.loess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
            perc.loess(ind,2)=perc.loess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
            perc.loess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
        end
    end
    perc.loess=perc.loess./repmat(perc.loess(:,3),[1 3]);
    perc.rfreqbars=zeros(n.percvals,3);
    perc.rfreqbars(:,2)=perc.loess(:,1)./perc.loess(:,2);
    for ind=1:n.percvals
        if perc.rfreqbars(ind,2)==1
            perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),1-1/2/floor(perc.loess(ind,2)))/floor(perc.loess(ind,2)));
        else
            perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),perc.rfreqbars(ind,2))/floor(perc.loess(ind,2)));
        end
        if perc.loess(ind,2)<2
            perc.rfreqbars(ind,:)=NaN;
        end
    end
    if do.display
        hold on
        pl4=plot(perc.val,perc.loess(:,1)./perc.loess(:,2),'Color',[0 0 0],'LineWidth',2);
        ebs=errbar(perc.val,perc.rfreqbars(:,2),perc.rfreqbars(:,1),perc.rfreqbars(:,3),'LineWidth',3,'Color',[0 0 0]);
        hold off
        
        title('Retrospective Data');
        ylabel('Percent Patients with PNES vs ES');
        xlabel(heads.retro{znd});
        set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    end
    if exist('ix.retro.Dur','var')
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==4
            iy.min=1;
            iy.max=75;
        elseif znd==3
            iy.min=0;
            iy.max=40;
        elseif znd==5
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==6
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    else
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==3
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==4
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    end
    if do.display
        set(gca,'xlim',[iy.min iy.max]);
    end
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            if znd==5 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==6 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            if do.display
                set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
            end
        end
    else
        if intersect(znd,[3,4])
            if znd==3 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==4 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            if do.display
                set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
            end
        end
    end
    
    %% Descriptive Trend Figure - 5 classes
    if do.display
        figure;
    end
    %     ssigma=0.015; % Gaussian window
    
    % make exact figure
    ix.retro.notmissing=find(~isnan(data.retro(:,znd)));
    tmps5.percvals=unique(data.retro(ix.retro.notmissing,znd));
    tmps5.perchist=zeros(length(tmps.percvals),n.class);
    for ind=1:length(tmps5.percvals)
        for cnd=1:n.class
            tmps5.perchist(ind,cnd)=sum(data.retro(intersect(ix.retro.classid{cnd},ix.retro.notmissing),znd)==tmps5.percvals(ind));
        end
    end
    % add smoothing
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,7)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    else
        if intersect(znd,[3,4])
            perc.val=min(data.retro(:,znd)):(max(data.retro(:,znd))-min(data.retro(:,znd)))/100:max(data.retro(:,znd));
        elseif intersect(znd,5)
            perc.val=1:max(data.retro(:,znd));
        else
            perc.val=0:max(data.retro(:,znd));
        end
    end
    n.percvals=length(perc.val);
    perc.r5loess=zeros(n.percvals,2,n.class); %1: freq, 2:n
    % Gaussian smoothing kernel applied onto tmps5.perchist
    for ind=1:n.percvals
        for jnd=1:length(tmps5.percvals)
            for cnd=1:n.class
                perc.r5loess(ind,1,cnd)=perc.r5loess(ind,1,cnd)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*tmps5.perchist(jnd,cnd);
            end
            perc.r5loess(ind,2,1)=perc.r5loess(ind,2,1)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*sum(tmps5.perchist(jnd,:),2);
        end
    end
    perc.r5loess=perc.r5loess./normpdf(0,0,ssigma); % norming to make the weight of a patient at this specific value 1
    perc.r5freqbars=zeros(n.percvals,n.class); % Note that we don't have error bars because that would be too messy
    perc.r5freqbars=squeeze(perc.r5loess(:,1,:))./repmat(perc.r5loess(:,2,1),[1 n.class]);
    for ind=1:n.percvals
        if perc.r5loess(ind,2,1)<2
            perc.r5freqbars(ind,:)=NaN;
        end
    end
    ordcl=5:-1:1;
    if do.display
        bar5=bar(perc.val,perc.r5freqbars(:,ordcl),'stacked','BarWidth',1);
        title('Retrospective Data');
        set(gca,'fontsize',16);
        ylabel('Percent of All Patients');
        xlabel(heads.retro{znd});
        set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
    end
    %     set(gca,'xlim',[-0.01 0.4],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});
    if exist('ix.retro.Dur','var')
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==4
            iy.min=1;
            iy.max=75;
        elseif znd==3
            iy.min=0;
            iy.max=40;
        elseif znd==5
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==6
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    else
        if znd==1
            iy.min=13;
            iy.max=83;
            %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
            %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
        elseif znd==3
            iy.min=log(2);
            iy.max=log(5.2*60*60);
        elseif znd==4
            iy.min=min(perc.val);
            iy.max=log(30*30.5+1);
        else
            iy.min=min(perc.val);
            iy.max=max(perc.val);
        end
    end
    if do.display
        set(gca,'xlim',[iy.min iy.max]);
    end
    if exist('ix.retro.Dur','var')
        if intersect(znd,[5,6])
            if znd==5 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==6 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            if do.display
                set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
            end
        end
    else
        if intersect(znd,[3,4])
            if znd==3 % Duration
                iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                iy.xticks=log(iy.xtick);
                iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
            elseif znd==4 % SzF
                iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                iy.xticks=log(iy.xtick);
                iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
            end
            if do.display
                set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
            end
        end
    end
    if do.display
        set(bar5(ordcl(1)),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
            'DisplayName','ES');
        set(bar5(ordcl(2)),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(2),:),...
            'DisplayName','PSLE');
        set(bar5(ordcl(3)),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(3),:),...
            'DisplayName','Inconclusive');
        set(bar5(ordcl(4)),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(4),:),...
            'DisplayName','Mixed');
        set(bar5(ordcl(5)),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
            'DisplayName','PNES');
        legend1 = legend(gca,'show');
    end
end

% Splitting By Sex
ix.retro.Female=find(data.retro(:,ix.retro.Gender)==1);
ix.retro.Male  =setdiff(1:size(data.retro,1),ix.retro.Female);
for znd=ix.data.cont
    if do.display
        figure;
    end
    for sexnd=1:2
        if sexnd==1
            ix.tmp=ix.retro.Female;
        else
            ix.tmp=ix.retro.Male;
        end
        % make exact figure
        tmps.percvals=unique(data.retro(intersect(ix.tmp,find(~isnan(data.retro(:,znd)))),znd));
        tmps.perchist=zeros(length(tmps.percvals),2);
        for ind=1:length(tmps.percvals)
            tmps.perchist(ind,1)=sum(data.retro(intersect(ix.tmp,ix.retro.classid{ix.DxPNES}),znd)==tmps.percvals(ind));
            tmps.perchist(ind,2)=sum(data.retro(intersect(ix.tmp,ix.retro.classid{ix.DxES}),znd)==tmps.percvals(ind));
        end
        % add smoothing
        perc.val=0:max(data.retro(ix.tmp,znd));
        n.percvals=length(perc.val);
        perc.loess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
        % Gaussian smoothing kernel applied onto tmps.perchist
        for ind=1:n.percvals
            for jnd=1:length(tmps.percvals)
                perc.loess(ind,1)=perc.loess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
                perc.loess(ind,2)=perc.loess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
                perc.loess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
            end
        end
        perc.loess=perc.loess./repmat(perc.loess(:,3),[1 3]);
        perc.rfreqbars=zeros(n.percvals,3);
        perc.rfreqbars(:,2)=perc.loess(:,1)./perc.loess(:,2);
        for ind=1:n.percvals
            if perc.rfreqbars(ind,2)==1
                perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),1-1/2/floor(perc.loess(ind,2)))/floor(perc.loess(ind,2)));
            else
                perc.rfreqbars(ind,[1 3])=abs(perc.rfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),perc.rfreqbars(ind,2))/floor(perc.loess(ind,2)));
            end
            if perc.loess(ind,2)<2
                perc.rfreqbars(ind,:)=NaN;
            end
        end
        if do.display
            hold on
            if sexnd==1
                Colr=[0 0 0];
                pl4=plot(perc.val,perc.loess(:,1)./perc.loess(:,2),'Color',Colr,'LineWidth',2);
                ebs=errbar(perc.val,perc.rfreqbars(:,2),perc.rfreqbars(:,1),perc.rfreqbars(:,3),'LineWidth',3,'Color',Colr);
            else
                Colr=[0 0 1];
                pl4=plot(perc.val+0.25,perc.loess(:,1)./perc.loess(:,2),'Color',Colr,'LineWidth',2);
                ebs=errbar(perc.val+0.25,perc.rfreqbars(:,2),perc.rfreqbars(:,1),perc.rfreqbars(:,3),'LineWidth',3,'Color',Colr);
            end
            if sexnd==2
                hold off
            end
            
            if sexnd==1
                title('Retrospective Data by Sex');
            else
                %         title('Retrospective Data by Sex: Males Only');
            end
            ylabel('Percent Patients with PNES vs ES');
            xlabel(heads.retro{znd});
            
            set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
        end
        if exist('ix.retro.Dur','var')
            if znd==1
                iy.min=13;
                iy.max=83;
                %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
                %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
            elseif znd==4
                iy.min=1;
                iy.max=75;
            elseif znd==3
                iy.min=0;
                iy.max=40;
            elseif znd==5
                iy.min=log(2);
                iy.max=log(5.2*60*60);
            elseif znd==6
                iy.min=min(perc.val);
                iy.max=log(30*30.5+1);
            else
                iy.min=min(perc.val);
                iy.max=max(perc.val);
            end
        else
            if znd==1
                iy.min=13;
                iy.max=83;
                %         iy.min=min(find(perc.loess(:,2)>cutoff.rawsubmin));
                %         iy.max=max(find(perc.loess(:,2)>cutoff.rawsubmin));
            elseif znd==3
                iy.min=log(2);
                iy.max=log(5.2*60*60);
            elseif znd==4
                iy.min=min(perc.val);
                iy.max=log(30*30.5+1);
            else
                iy.min=min(perc.val);
                iy.max=max(perc.val);
            end
        end
        if do.display
            set(gca,'xlim',[iy.min iy.max]);
        end
        if exist('ix.retro.Dur','var')
            if intersect(znd,[5,6])
                if znd==5 % Duration
                    iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
                elseif znd==6 % SzF
                    iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
                end
                if do.display
                    set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
                end
            end
        else
            if intersect(znd,[3,4])
                if znd==3 % Duration
                    iy.xtick=[1,5,10,30,60,2*60,5*60,10*60,30*60,60*60,3*60*60,5*60*60];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1s','5s','10s','30s','1m','2m','5m','10m','30m','1h','3h','5h'};
                elseif znd==4 % SzF
                    iy.xtick=[12/365,1/6,1/3   ,1    ,52/12,3*52/12,30.5,3*30.5,10*30.5,30*30.5];
                    iy.xticks=log(iy.xtick);
                    iy.labels={'1/y','1/6m','1/3m','1/m','1/w','3/w'  ,'1/d','3/d','10/d','30/d'};
                end
                if do.display
                    set(gca,'xtick',iy.xticks,'xticklabel',iy.labels);
                end
            end
        end
    end
end


%% Binary 5 class figures
n.bin=length(ix.data.indicators);
datafigs.bin5class=zeros(5,n.bin);
cnt=0;
for fnd=1:n.bin
    cnt=cnt+1;
    for jnd=1:5
        datafigs.bin5class(jnd,cnt)=sum(data.retro(ix.retro.classid{jnd},ix.data.indicators(fnd)));
    end
end
datafigs.binbin=datafigs.bin5class([ix.DxES,ix.DxPNES],:);
datafigs.binbinsum=sum(datafigs.binbin,1);
datafigs.binbin=datafigs.binbin./repmat(sum(datafigs.binbin,1),[2 1]);
datafigs.binbinCI=zeros(2,n.bin);
for fnd=1:n.bin
    datafigs.binbinCI(1,fnd)=binoinv(0.025,datafigs.binbinsum(fnd),datafigs.binbin(1,fnd))/datafigs.binbinsum(fnd);
    datafigs.binbinCI(2,fnd)=binoinv(0.975,datafigs.binbinsum(fnd),datafigs.binbin(1,fnd))/datafigs.binbinsum(fnd);
end
datafigs.bin5sum=sum(datafigs.bin5class,1);
datafigs.bin5class=datafigs.bin5class./repmat(sum(datafigs.bin5class,1),[n.class 1]);

if do.display
    figure;
    bar5=barh(1:n.bin,datafigs.bin5class(:,end:-1:1)','stacked','BarWidth',1);
    set(gca,'fontsize',18);
    title('Retrospective Data');
    set(bar5(ordcl(5)),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
        'DisplayName','ES');
    set(bar5(ordcl(4)),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(4),:),...
        'DisplayName','PSLE');
    set(bar5(ordcl(3)),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(3),:),...
        'DisplayName','Inconclusive');
    set(bar5(ordcl(2)),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(2),:),...
        'DisplayName','Mixed');
    set(bar5(ordcl(1)),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
        'DisplayName','PNES');
    legend1 = legend(gca,'show');
    set(gca,'ylim',[1.5 n.bin+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(end:-1:1)}}); %,'XTickLabelRotation',90);
    xlabel('Percent of Patients with Each Factor');
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    hold on
    pl=plot([n.retro.classes(1)/sum(n.retro.classes) n.retro.classes(1)/sum(n.retro.classes)],[0 n.bin+1],':','LineWidth',3,'Color',[1 1 1]);
    hold off;
    
    figure;
    bar5=barh(1:n.bin,datafigs.binbin(:,end:-1:1)','stacked','BarWidth',1);
    set(gca,'fontsize',18);
    title('Retrospective Data');
    set(bar5(1),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
        'DisplayName','ES');
    set(bar5(2),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
        'DisplayName','PNES');
    legend1 = legend(gca,'show');
    set(gca,'ylim',[1.5 n.bin+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(end:-1:1)}}); %,'XTickLabelRotation',90);
    xlabel('ES-PV');
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    hold on
    pl=plot([summary.naive(1) summary.naive(1)],[0 n.bin+1],':','LineWidth',3,'Color',[0 0 0]);
    cnt=1;
    for fnd=n.bin:-1:1
        ebs=errbar(datafigs.binbin(1,fnd),cnt,abs(datafigs.binbin(1,fnd)-datafigs.binbinCI(1,fnd)),abs(datafigs.binbin(1,fnd)-datafigs.binbinCI(2,fnd)),'LineWidth',3,'Color',[0 0 0],'horiz');
        cnt=cnt+1;
    end
    hold off;
end

clear tmp;
tmp.filler=zeros(length(ix.data.indicators),1);
for fnd=1:length(ix.data.indicators)
    if ~isempty(intersect(ix.sigpred,ix.data.indicators(fnd)));
        tmp.filler(fnd)=1;
    end
end
ix.signdicators=find(tmp.filler);
n.signdicators =sum(tmp.filler);
if do.display
    figure;
    bar5=barh(1:n.signdicators,datafigs.bin5class(:,ix.signdicators(n.signdicators:-1:1))','stacked','BarWidth',1);
    set(gca,'fontsize',18);
    title('Retrospective Data');
    set(bar5(ordcl(5)),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
        'DisplayName','ES');
    set(bar5(ordcl(4)),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(4),:),...
        'DisplayName','PSLE');
    set(bar5(ordcl(3)),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(3),:),...
        'DisplayName','Inconclusive');
    set(bar5(ordcl(2)),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(2),:),...
        'DisplayName','Mixed');
    set(bar5(ordcl(1)),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
        'DisplayName','PNES');
    legend1 = legend(gca,'show');
    set(gca,'ylim',[0.5 n.signdicators+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(ix.signdicators(end:-1:1))}}); %,'XTickLabelRotation',90);
    xlabel('Percent of Patients with Each Factor');
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    hold on
    pl=plot([n.retro.classes(1)/sum(n.retro.classes) n.retro.classes(1)/sum(n.retro.classes)],[0 n.signdicators+1],':','LineWidth',3,'Color',[1 1 1]);
    hold off;
    
    figure;
    bar5=barh(1:n.signdicators,datafigs.binbin(:,ix.signdicators(n.signdicators:-1:1))','stacked','BarWidth',1);
    set(gca,'fontsize',18);
    title('Retrospective Data');
    set(bar5(1),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
        'DisplayName','ES');
    set(bar5(2),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
        'DisplayName','PNES');
    legend1 = legend(gca,'show');
    set(gca,'ylim',[0.5 n.signdicators+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.data.indicators(ix.signdicators(end:-1:1))}}); %,'XTickLabelRotation',90);
    xlabel('ES-PV');
    set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    hold on
    pl=plot([summary.naive(1) summary.naive(1)],[0 n.bin+1],':','LineWidth',3,'Color',[0 0 0]);
    cnt=1;
    for fnd=n.signdicators:-1:1
        ebs=errbar(datafigs.binbin(1,ix.signdicators(fnd)),cnt,abs(datafigs.binbin(1,ix.signdicators(fnd))-datafigs.binbinCI(1,ix.signdicators(fnd))),abs(datafigs.binbin(1,ix.signdicators(fnd))-datafigs.binbinCI(2,ix.signdicators(fnd))),'LineWidth',3,'Color',[0 0 0],'horiz');
        cnt=cnt+1;
    end
    hold off;
end

%% Table 1
ix.all.classid=cell(n.class,1);
ix.all.classid{1}=find(data.all.Dx(:,1)>1); % ES
ix.all.classid{2}=find(data.all.Dx(:,1)==-1); % PSLE
ix.all.classid{3}=find(data.all.Dx(:,1)==0); % Inconclusive
ix.all.classid{4}=find(data.all.Dx(:,1)==-5); % Mixed
ix.all.classid{5}=find(data.all.Dx(:,1)==-2); % PNES
ix.retvpro.classid=cell(n.class,2);
ix.retvpro.classid{1,1}=find(data.Dx(:,1)>1); % ES
ix.retvpro.classid{2,1}=find(data.Dx(:,1)==-1); % PSLE
ix.retvpro.classid{3,1}=find(data.Dx(:,1)==0); % Inconclusive
ix.retvpro.classid{4,1}=find(data.Dx(:,1)==-5); % Mixed
ix.retvpro.classid{5,1}=find(data.Dx(:,1)==-2); % PNES
ix.retvpro.classid{1,2}=find(data.prosp.Dx(:,1)>1); % ES
ix.retvpro.classid{2,2}=find(data.prosp.Dx(:,1)==-1); % PSLE
ix.retvpro.classid{3,2}=find(data.prosp.Dx(:,1)==0); % Inconclusive
ix.retvpro.classid{4,2}=find(data.prosp.Dx(:,1)==-5); % Mixed
ix.retvpro.classid{5,2}=find(data.prosp.Dx(:,1)==-2); % PNES

summary.all.class=zeros(n.class,4,6);
% Index 2
% 1: Class value
% 2: n
% 3: Age
% 4: Sex
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
ix.Demo=[ix.retro.Age,ix.retro.Gender];
for cnd=1:n.class
    summary.all.class(cnd,1,:)=data.all.Dx(ix.all.classid{cnd}(1),1);
    summary.all.class(cnd,2,:)=length(ix.all.classid{cnd});
    cnt=2;
    for jnd=ix.Demo
        cnt=cnt+1;
        summary.all.class(cnd,cnt,1)=nanmean(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,2)=min(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,3)=max(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,4)=nanstd(data.all.testp(ix.all.classid{cnd},jnd));
        summary.all.class(cnd,cnt,5)=summary.all.class(cnd,cnt,1)-1.96*summary.all.class(cnd,cnt,4)/sqrt(summary.all.class(cnd,2,1));
        summary.all.class(cnd,cnt,6)=summary.all.class(cnd,cnt,1)+1.96*summary.all.class(cnd,cnt,4)/sqrt(summary.all.class(cnd,2,1));
    end
end

% Write it!
fid=fopen(dirs.table1,'w');
fprintf(fid,', ,Age,Sex\n');
fprintf(fid,'Class,Count,Min (95CI) Max,F\n');
for ind=1:n.class
    fprintf(fid,[num2str(summary.all.class(ind,1,1)) ',' num2str(summary.all.class(ind,2,1)) ',']);
    for jnd=3:4
        if jnd==4
            fprintf(fid,[num2str(round(100*summary.all.class(ind,jnd,1))) ',']);
        else
            fprintf(fid,[num2str(summary.all.class(ind,jnd,2)) ' (' num2str(floor(summary.all.class(ind,jnd,5))) '-' num2str(ceil(summary.all.class(ind,jnd,6))) ') ' num2str(summary.all.class(ind,jnd,3)) ',']);
        end
    end
    fprintf(fid,'\n');
end
fclose(fid);

%% Supplemental Table 1
summary.retvpro.classes=zeros(n.class,4,6,2);
% Index 2
% 1: Class value
% 2: n
% 3: Age
% 4: Sex
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
% Index 4
% 1: Retrospective
% 2: Prospective
for rnd=1:2
    for cnd=1:n.class
        summary.retvpro.classes(cnd,1,:,:)=data.all.Dx(ix.all.classid{cnd}(1),1);
        summary.retvpro.classes(cnd,2,:,rnd)=length(ix.retvpro.classid{cnd,rnd});
        cnt=2;
        for jnd=ix.Demo
            cnt=cnt+1;
            if ~isempty(ix.retvpro.classid{cnd,rnd})
                if rnd==1
                    tmp.source=data.retro(ix.retvpro.classid{cnd,rnd},jnd);
                else
                    tmp.source=data.prosp.testp(ix.retvpro.classid{cnd,rnd},jnd);
                end
                summary.retvpro.classes(cnd,cnt,1,rnd)=nanmean(tmp.source);
                summary.retvpro.classes(cnd,cnt,2,rnd)=min(tmp.source);
                summary.retvpro.classes(cnd,cnt,3,rnd)=max(tmp.source);
                summary.retvpro.classes(cnd,cnt,4,rnd)=nanstd(tmp.source);
                summary.retvpro.classes(cnd,cnt,5,rnd)=summary.retvpro.classes(cnd,cnt,1,rnd)-1.96*summary.retvpro.classes(cnd,cnt,4,rnd)/sqrt(summary.retvpro.classes(cnd,2,1,rnd));
                summary.retvpro.classes(cnd,cnt,6,rnd)=summary.retvpro.classes(cnd,cnt,1,rnd)+1.96*summary.retvpro.classes(cnd,cnt,4,rnd)/sqrt(summary.retvpro.classes(cnd,2,1,rnd));
            end
        end
    end
end

% Write it!
fid=fopen(dirs.Stable1,'w');
fprintf(fid,',,,Age,Sex\n');
fprintf(fid,'Class,Dataset,Count,Min (95CI) Max,Mean\n');
for ind=1:n.class
    fprintf(fid,[num2str(summary.retvpro.classes(ind,1,1,rnd)) ',']);
    for rnd=1:2
        if rnd==1
            fprintf(fid,'Retro,');
        else
            fprintf(fid,',Prosp,');
        end
        fprintf(fid,[num2str(summary.retvpro.classes(ind,2,1,rnd)) ',']);
        for jnd=3:4
            if jnd==4
                fprintf(fid,[num2str(round(100*summary.retvpro.classes(ind,jnd,1,rnd))) ',']);
            else
                fprintf(fid,[num2str(summary.retvpro.classes(ind,jnd,2,rnd)) ' (' num2str(floor(summary.retvpro.classes(ind,jnd,5,rnd))) '-' num2str(ceil(summary.retvpro.classes(ind,jnd,6,rnd))) ') ' num2str(summary.retvpro.classes(ind,jnd,3,rnd)) ',']);
            end
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

%% Supplemental Table 1
summary.retvpro.data=zeros(n.class,2+length(ix.classuse),8,2);
% Index 2
% 1: Class value
% 2: n
% 3+: variables
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
% 7: p: vs ES/baseline
% 8: p: RvP
% Index 4
% 1: Retrospective
% 2: Prospective
ix.indicator=[];
ix.cont     =[];
for rnd=1:2
    for cnd=1:n.class
        summary.retvpro.data(cnd,1,:,:)=data.all.Dx(ix.all.classid{cnd}(1),1);
        summary.retvpro.data(cnd,2,:,rnd)=length(ix.retvpro.classid{cnd,rnd});
        cnt=2;
        for jnd=ix.classuse
            cnt=cnt+1;
            if ~isempty(ix.retvpro.classid{cnd,rnd})
                if rnd==1
                    tmp.source=data.retro(ix.retvpro.classid{cnd,rnd},jnd);
                    tmp.sourceE=data.retro(ix.retvpro.classid{1,rnd},jnd);
                else
                    tmp.source=data.prosp.testp(ix.retvpro.classid{cnd,rnd},jnd);
                    tmp.sourceR=data.retro(ix.retvpro.classid{cnd,rnd},jnd);
                    tmp.sourceE=data.prosp.testp(ix.retvpro.classid{1,rnd},jnd);
                end
                summary.retvpro.data(cnd,cnt,1,rnd)=nanmean(tmp.source);
                summary.retvpro.data(cnd,cnt,2,rnd)=min(tmp.source);
                summary.retvpro.data(cnd,cnt,3,rnd)=max(tmp.source);
                summary.retvpro.data(cnd,cnt,4,rnd)=nanstd(tmp.source);
                if length(unique(tmp.source))==2 % binary 
                    if rnd==1 && cnd==1
                        ix.indicator=[ix.indicator,jnd];
                    end
                    tmp.n=sum(~isnan(tmp.source));
                    tmp.p=nansum(tmp.source)/tmp.n;
                    summary.retvpro.data(cnd,cnt,5,rnd)=binoinv(0.025,tmp.n,tmp.p)/tmp.n;
                    summary.retvpro.data(cnd,cnt,6,rnd)=binoinv(0.975,tmp.n,tmp.p)/tmp.n;
                    fishmx=zeros(2,2);
                    fishmx(1,1)=sum(tmp.source(find(~isnan(tmp.source))) ==1);
                    fishmx(1,2)=sum(tmp.source(find(~isnan(tmp.source))) ==0);
                    fishmx(2,1)=sum(tmp.sourceE(find(~isnan(tmp.sourceE)))==1);
                    fishmx(2,2)=sum(tmp.sourceE(find(~isnan(tmp.sourceE)))==0);
                    [tmp.h,tmp.p]=fishertest(fishmx,'tail','both');
                    summary.retvpro.data(cnd,cnt,7,rnd)=tmp.p;
                    if rnd==2
                        fishmx=zeros(2,2);
                        fishmx(1,1)=sum(tmp.source(find(~isnan(tmp.source))) ==1);
                        fishmx(1,2)=sum(tmp.source(find(~isnan(tmp.source))) ==0);
                        fishmx(2,1)=sum(tmp.sourceR(find(~isnan(tmp.sourceR)))==1);
                        fishmx(2,2)=sum(tmp.sourceR(find(~isnan(tmp.sourceR)))==0);
                        [tmp.h,tmp.p]=fishertest(fishmx,'tail','both');
                        summary.retvpro.data(cnd,cnt,8,rnd)=tmp.p;
                    end
                else % continuous variables
                    if rnd==1 && cnd==1
                        ix.cont=[ix.cont,jnd];
                    end
                    summary.retvpro.data(cnd,cnt,5,rnd)=summary.retvpro.data(cnd,cnt,1,rnd)-1.96*summary.retvpro.data(cnd,cnt,4,rnd)/sqrt(summary.retvpro.data(cnd,2,1,rnd));
                    summary.retvpro.data(cnd,cnt,6,rnd)=summary.retvpro.data(cnd,cnt,1,rnd)+1.96*summary.retvpro.data(cnd,cnt,4,rnd)/sqrt(summary.retvpro.data(cnd,2,1,rnd));
                    [tmp.h,tmp.p]=ttest2(tmp.source(find(~isnan(tmp.source))),tmp.sourceE(find(~isnan(tmp.sourceE))),'tail','both','vartype','unequal');
                    summary.retvpro.data(cnd,cnt,7,rnd)=tmp.p;
                    if rnd==2
                        [tmp.h,tmp.p]=ttest2(tmp.source(find(~isnan(tmp.source))),tmp.sourceR(find(~isnan(tmp.sourceR))),'tail','both','vartype','unequal');
                        summary.retvpro.data(cnd,cnt,8,rnd)=tmp.p;
                    end
                end
            end
        end
    end
end

% Write it!
fid=fopen(dirs.StableRvP,'w');
fprintf(fid,'Ictal Behavior,Dataset,Statistic');
for ind=1:length(heads.class)
    fprintf(fid,[',' heads.class{ind}]);
end
fprintf(fid,'\n');
for jnd=1:length(ix.classuse)
    fprintf(fid,[heads.retro{ix.classuse(jnd)} ',']);
    for rnd=1:2
        if rnd==1
            kloop=[1 7];
        else
            kloop=[1 7 8];
        end
        for knd=kloop
            if knd==1
                if rnd==1
                    fprintf(fid,'Retro,');
                else
                    fprintf(fid,',Prosp,');
                end
                if intersect(ix.classuse(jnd),ix.cont)
                    fprintf(fid,'Mean (95 CI),');
                else
                    fprintf(fid,'Obs (95 CI),');
                end
            elseif knd==7
                fprintf(fid,',,p: vs ES,');
            elseif knd==8
                fprintf(fid,',,p: RvP,');
            else
                error 'which statistic?'
                % 1: Mean
                % 2: Min
                % 3: Max
                % 4: STD
                % 5: 95% CI LB
                % 6: 95% CI UB
                % 7: p: vs ES/baseline
                % 8: p: RvP
            end
            for ind=1:n.class
                if ~isempty(intersect(ix.classuse(jnd),ix.cont)) || knd>1
                    if knd>1
                        fprintf(fid,num2str(summary.retvpro.data(ind,jnd+2,knd,rnd)));
                        if knd==1
                            fprintf(fid,[' (' num2str(summary.retvpro.data(ind,jnd+2,5,rnd)) '-' num2str(summary.retvpro.data(ind,jnd+2,6,rnd)) ')']);
                        end
                    else
                        if intersect(ix.classuse(jnd),ix.dur)
                            fprintf(fid,sectotime(exp(summary.retvpro.data(ind,jnd+2,knd,rnd))));
                            if knd==1
                                fprintf(fid,[' (' sectotime(exp(summary.retvpro.data(ind,jnd+2,5,rnd))) '-' sectotime(exp(summary.retvpro.data(ind,jnd+2,6,rnd))) ')']);
                            end
                        elseif intersect(ix.classuse(jnd),ix.szf)
                            fprintf(fid,freqtostr(exp(summary.retvpro.data(ind,jnd+2,knd,rnd))));
                            if knd==1
                                fprintf(fid,[' (' freqtostr(exp(summary.retvpro.data(ind,jnd+2,5,rnd))) '-' freqtostr(exp(summary.retvpro.data(ind,jnd+2,6,rnd))) ')']);
                            end
                        else
                            fprintf(fid,num2str(round(summary.retvpro.data(ind,jnd+2,knd,rnd),2)));
                            if knd==1
                                fprintf(fid,[' (' num2str(round(summary.retvpro.data(ind,jnd+2,5,rnd),2)) '-' num2str(round(summary.retvpro.data(ind,jnd+2,6,rnd),2)) ')']);
                            end
                        end
                    end
                else
                    fprintf(fid,num2str(round(100*summary.retvpro.data(ind,jnd+2,knd,rnd))));
                    if knd==1
                        fprintf(fid,[' (' num2str(round(100*summary.retvpro.data(ind,jnd+2,5,rnd))) '-' num2str(round(100*summary.retvpro.data(ind,jnd+2,6,rnd))) ')']);
                    end
                end
                fprintf(fid,',');
            end
            fprintf(fid,'\n');
        end
    end
end
fclose(fid);

% Figure of RvP
% Reshape summary retvpro to be 2 dimensions
summary.retvpro.data2=zeros(size(summary.retvpro.data,1)*size(summary.retvpro.data,4),size(summary.retvpro.data,2),size(summary.retvpro.data,3));
for ind=1:size(summary.retvpro.data,1)
    summary.retvpro.data2(ind*2-1,:,:)=squeeze(summary.retvpro.data(ind,:,:,1));
    summary.retvpro.data2(ind*2  ,:,:)=squeeze(summary.retvpro.data(ind,:,:,2));
end

figure;
ix.bin=1+setdiff(ix.classuse,ix.cont);
n.bin =length(ix.bin);
bar5=barh(1:n.bin,squeeze(summary.retvpro.data2(:,ix.bin,1))','BarWidth',1);
set(gca,'fontsize',18);
set(bar5(1),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','ES-R');
set(bar5(2),'FaceColor',Colors5(ordcl(5),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','ES-P');
set(bar5(3),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','PSLE-R');
set(bar5(4),'FaceColor',Colors5(ordcl(4),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','PSLE-P');
set(bar5(5),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','Inc-R');
set(bar5(6),'FaceColor',Colors5(ordcl(3),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','Inc-P');
set(bar5(7),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','Mixed-R');
set(bar5(8),'FaceColor',Colors5(ordcl(2),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','Mixed-P');
set(bar5(9),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(5),:),...
    'DisplayName','PNES-R');
set(bar5(10),'FaceColor',Colors5(ordcl(1),:),'EdgeColor',Colors5(ordcl(1),:),...
    'DisplayName','PNES-P');
legend1 = legend(gca,'show');
set(gca,'ylim',[0.5 n.bin+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.bin-1}}); %,'XTickLabelRotation',90);
xlabel('Proportion Present');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
hold on
offset=[-0.36,-0.28,-0.20,-0.12,-0.04,0.04,0.12,0.20,0.28,0.36];
for fnd=1:n.bin
    for ind=1:10
        ebs=errbar(summary.retvpro.data2(ind,ix.bin(fnd),1),fnd+offset(ind),abs(summary.retvpro.data2(ind,ix.bin(fnd),5)-summary.retvpro.data2(ind,ix.bin(fnd),1)),abs(summary.retvpro.data2(ind,ix.bin(fnd),6)-summary.retvpro.data2(ind,ix.bin(fnd),1)),'LineWidth',3,'Color',[0 0 0],'horiz');
    end
end
hold off;


% the below is the transform of what we want (but I didn't finish it)
% fprintf(fid,',,');
% for jnd=ix.classuse
%     fprintf(fid,[heads.retro{jnd} ',']);
% end
% fprintf(fid,'\n');
% fprintf(fid,'Class,Dataset,');
% for jnd=1:ix.classuse
%     fprintf(fid,'Mean (95CI),');
% end
% fprintf(fid,'\n');
% for ind=1:n.class
%     fprintf(fid,[num2str(summary.retvpro.data(ind,1,1,rnd)) ',']);
%     for rnd=1:2
%         if rnd==1
%             fprintf(fid,'Retro,');
%         else
%             fprintf(fid,',Prosp,');
%         end
%         fprintf(fid,[num2str(summary.retvpro.data(ind,2,1,rnd)) ',']);
%         for jnd=1:length(ix.classuse)
%             fprintf(fid,[num2str(summary.retvpro.data
%             if jnd==4
%                 fprintf(fid,[num2str(round(100*summary.retvpro.classes(ind,jnd,1,rnd))) ',']);
%             else
%                 fprintf(fid,[num2str(summary.retvpro.classes(ind,jnd,2,rnd)) ' (' num2str(floor(summary.retvpro.classes(ind,jnd,5,rnd))) '-' num2str(ceil(summary.retvpro.classes(ind,jnd,6,rnd))) ') ' num2str(summary.retvpro.classes(ind,jnd,3,rnd)) ',']);
%             end
%         end
%         fprintf(fid,'\n');
%     end
% end
