% This runs just the permutations of the semiology trees
% Wesley Kerr, May 2017, wesleytk@g.ucla.edu

dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.analysis =[dirs.base 'Dropbox/ES_Semiology/'];
dirs.data     =[dirs.base 'Documents/EMU/CI/Semiology/'];
dirs.retroDx  =[dirs.data 'Retro5_ForDx.csv'];
dirs.retrodata=[dirs.data 'Retro6_Semiology.csv'];
dirs.retroarff=[dirs.data 'Retro6_Semiology'];
dirs.retrosum =[dirs.analysis 'Retro6_ModelSummary.csv'];
dirs.retrotreesum =[dirs.analysis 'Retro6_ModelSummaryTree.csv'];
dirs.sigmodel =[dirs.analysis 'Retro6_SigModel.csv'];
dirs.prospDx  =[dirs.data 'Prosp_Diagnosis161122b.csv'];
dirs.prospdata=[dirs.data 'Prosp_Semiology161121.csv'];
dirs.prosparff=[dirs.analysis 'Prosp5_Semiology'];
dirs.pro2ret  =[dirs.analysis 'Semiology_Pro2Ret.csv'];
dirs.descrip  =[dirs.analysis 'Semiology_Descrip_Class.csv'];
dirs.pairwise =[dirs.analysis 'Semiology_DescripPairwise.csv'];
dirs.table1   =[dirs.analysis 'Semiology_Table1.csv'];
dirs.Stable1  =[dirs.analysis 'Semiology_STable1.csv'];
dirs.process  =[dirs.data 'Semiology_Processed'];
dirs.treeout  =[dirs.analysis 'Semiology_TreeOutput.txt'];
dirs.perftable=[dirs.analysis 'Semiology_Perf.csv'];

%% Get List of Work Already Done
h=dir([dirs.process '*']);
if length(h)==1
    load([dirs.data h.name])
else
    load([dirs.data h(1).name]);
%     n.permsdone=0;
%     for dnd=2:lenth(h)
%         
    fprintf('Code up the efficient way\n')
end

C=clock;
rancode=round(sum(C(2:6))*10);
s = RandStream('mt19937ar','Seed',sum(C));
RandStream.setGlobalStream(s);

%% Set up Permutations
n.permutations=1000;
n.permstepsize=100;
fprintf(['Permuting with ' num2str(n.permutations) ' permutations\n']);
data.perm.Dx=zeros(size(data.Dx,1),size(data.Dx,2),n.permutations);
ix.perm.hazDx=zeros(length(ix.retro.hazDx),n.permutations);
for rnd=1:n.permutations
    data.perm.Dx(:,:,rnd)=data.Dx(randperm(size(data.Dx,1)),:);
    ix.perm.hazDx(:,rnd)=find(data.perm.Dx(:,2,rnd));
    ix.perm.classid{1,rnd}=find(data.perm.Dx(:,1,rnd)>1);
    ix.perm.classid{2,rnd}=find(data.perm.Dx(:,1,rnd)==-1);
    ix.perm.classid{3,rnd}=find(data.perm.Dx(:,1,rnd)==0);
    ix.perm.classid{4,rnd}=find(data.perm.Dx(:,1,rnd)==-5);
    ix.perm.classid{5,rnd}=find(data.perm.Dx(:,1,rnd)==-2);
end

%% Do the work
out.perm.mi.mo       =zeros(size(out.mi.mo,1),size(out.mi.mo,2),n.permutations);
out.perm.mi.se       =out.perm.mi.mo;
out.perm.mi.dev      =zeros(size(out.mi.dev,1),n.permutations);
out.perm.mi.pred     =zeros(size(out.mi.pred,1),size(out.mi.pred,2),n.permutations);
out.perm.mi.tree.pred=zeros(size(out.mi.pred,1),size(out.mi.pred,2),n.permutations);
out.perm.mi.tree.mo  =zeros(size(out.perm.mi.mo));
trees.perm.binary    =cell(n.imputations,n.permutations);
for rnd=1:n.permutations
    modeldata.Yperm=squeeze((data.perm.Dx(ix.perm.hazDx(:,rnd),2)==1)*1);
    for mnd=1:n.imputations
        modeldata.Xr=data.retrofilled(ix.retro.hazDx,ix.classuse,mnd);
        warning off
        [out.perm.mi.mo(:,mnd,rnd),out.perm.mi.dev(mnd,rnd),tmp.out.perm.mi.stats]=glmfit(modeldata.Xr,modeldata.Yperm,'binomial','link','logit');
        out.perm.mi.se(:,mnd,rnd)=tmp.out.perm.mi.stats.se;
        trees.perm.binary{mnd,rnd}=fitctree(modeldata.Xr,modeldata.Yperm,'OptimizeHyperparameters','none','MinLeafSize',trees.binary{mnd}.HyperparameterOptimizationResults.XAtMinObjective{1,'MinLeafSize'},'AlgorithmForCategorical','Exact','PredictorNames',{heads.retro{ix.classuse}});
        out.perm.mi.tree.mo(2:end,mnd,rnd)=predictorImportance(trees.perm.binary{mnd,rnd});
        warning on
        modeldata.Xp=data.prosp.testp(ix.prosp.hazDx,ix.classuse);
        for fnd=1:size(modeldata.Xp,2)
            tmp.mis=find(isnan(modeldata.Xp(:,fnd)));
            if ~isempty(tmp.mis)
                if mnd==1
%                     fprintf(['Fill in ' num2str(length(tmp.mis)) ' missing ' heads.retro{fnd+1} ' data for the prospective\n']);
                end
                if intersect(ix.retro.transform-1,fnd)
                    % fnd+1-2 to make a 5-1->3, and 6-1->4 (working with
                    % modeldata.Xp indices, not raw
                    modeldata.Xp(tmp.mis,fnd)=glmval(mi.mo(:,fnd+1-2,mnd),data.prosp.testp(tmp.mis,ix.retro.usetoimpute{fnd+1-2}),'identity');
                else
                    error 'missing prospective data that we do not have a model for or SzDur/SzF';
                end
            end
        end
        out.perm.mi.pred(:,mnd,rnd)=glmval(out.perm.mi.mo(:,mnd,rnd),modeldata.Xp,'logit');
        out.perm.mi.tree.pred(:,mnd,rnd)=predict(trees.perm.binary{mnd,rnd},modeldata.Xp);
    end
    
    % Save partial work because this will take a long long time
    if round(rnd/n.permstepsize)==rnd/n.permstepsize
        if exist([dirs.process '_' num2str(n.imputations) '_' num2str(rnd-n.permstepsize) '_' num2str(rancode) '.mat'],'file')
            warning off
            system(['rm ' dirs.process '_' num2str(n.imputations) '_' num2str(rnd-n.permstepsize) '_' num2str(rancode) '.mat']);
            warning on
        end
        save([dirs.process '_' num2str(n.imputations) '_' num2str(rnd) '_' num2str(rancode) '.mat'],'out','data','ix','-v7.3');
        fprintf(['Finished perm ' num2str(rnd) '\n']);
    end
end