% Notes: search for notes that aren't overlapping, but are nearby, then
% figure out which way to move things based on where that node came from
% (if it's a < node, everything needs to move R, otherwise L)
%
%

dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.analysis =[dirs.base 'Dropbox/ES_Semiology/'];
dirs.data     =[dirs.base 'Documents/EMU/CI/Semiology/'];
dirs.process  =[dirs.data 'Semiology_Processed'];
dirs.treeout  =[dirs.analysis 'Semiology_TreeOutput.txt'];
dirs.treepre  =[dirs.analysis 'TreeDisplay/Semiology_Tree'];
dirs.treesuf  ='.tex';

%% Set Some Basic Parameters
do.writeprosp=1;
do.labelend=1; % label the end node with the number of subjects in each type
do.labelmid=0; % label intermediary nodes with the number of things
tree.starttext='Decision tree for classification';
tree.endtext  ='Tree Imputation ';
tree.terminal ='  class = ';
tree.if       ='  if ';
tree.then     =' then node ';
tree.backstep =4;
tree.frontstep=4;
tree.vertstep =4;
tree.shift    =8;
tree.terminaltype='block';
tree.intermedtype='block';
tree.legendtype  ='rect';
tree.legstep  =1.3;
tree.arrowlen =8;
tree.writenode=0;

% Fixing some intricacies
tree.conv='# limbs convulsing';
tree.PI  ='postictal confusion/fatigue';
tree.dur ='Sz Duration (s)';
tree.szf ='Sz Freq (per mo)';
tree.sex ='Gender';
if do.labelmid
    tree.vertstep=tree.vertstep+1.5;
end

% Using a Colormap
cmap=colormap('jet');
close all;
tree.cols=zeros(size(cmap,1),4);
tree.cols(:,1)=(1:size(cmap,1))/size(cmap,1);
% tree.cols(:,2:4)=cmap*256;
tree.cols(:,2:4)=cmap;

%% Load the Trees
dirs.done    =dir([dirs.process '*_0.mat']);
load([dirs.data dirs.done.name],'heads','data','ix');

fid=fopen(dirs.treeout,'r');
d=textscan(fid,'%s ','Delimiter',',');
fclose(fid);

% Figure out the Biggest Tree (for initializing matrices)
tree.biggest=1;
cnt.trees=0;
for ind=1:length(d{1})-1
    if ind==length(d{1})-1
        tmp.size=str2num(d{1}{ind}(1:2));
        if tmp.size>tree.biggest
            tree.biggest=tmp.size;
        end
        cnt.trees=cnt.trees+1;
    else
        if length(d{1}{ind+1})>length(tree.endtext)
            if strcmp(d{1}{ind+1}(1:length(tree.endtext)),tree.endtext)
                % find the number of digits in the node name
                tmp.dig=1;
                while ~strcmp(d{1}{ind}(tmp.dig),' ')
                    tmp.dig=tmp.dig+1;
                end
                % read the node name
                tmp.size=str2num(d{1}{ind}(1:tmp.dig));
                if tmp.size>tree.biggest
                    tree.biggest=tmp.size;
                end
                cnt.trees=cnt.trees+1;
            end
        end
    end
end
n.trees=cnt.trees;
tree.dir =zeros(n.trees,tree.biggest,3); % Set up the binary decision mx: source, <, >
tree.comp=zeros(n.trees,tree.biggest,2,2); % Set up the composition mx
tree.nloc=zeros(n.trees,tree.biggest,2); % x,y dimensions of node
tree.ix  =cell(n.trees,tree.biggest,2); % the subjects at this node of the tree
tree.maxterm=ceil(log10(tree.biggest))+length(tree.terminal)+1;
tree.feat=cell(n.trees,tree.biggest);
tree.thresh=zeros(n.trees,tree.biggest);

%% Create the Trees
cnt.trees=0;
ix.line=1;
while ix.line<=length(d{1})
    if strcmp(d{1}{ix.line},tree.starttext)
        cnt.trees=cnt.trees+1;
        dirs.currenttree=[dirs.treepre num2str(cnt.trees) dirs.treesuf];
        DisplayTree_TexHeader(dirs.currenttree);
        tmp.nodes=0;
        node=1; % node count within the tree
        tree.ix{cnt.trees,node,1}=ix.retro.hazDx;
        tree.ix{cnt.trees,node,2}=ix.prosp.hazDx;
        tree.comp(cnt.trees,node,1,1)=sum(data.Dx(tree.ix{cnt.trees,node,1},1)> 1 );
        tree.comp(cnt.trees,node,2,1)=sum(data.Dx(tree.ix{cnt.trees,node,1},1)==-2);
        tree.comp(cnt.trees,node,1,2)=sum(data.prosp.Dx(tree.ix{cnt.trees,node,2},1)> 1 );
        tree.comp(cnt.trees,node,2,2)=sum(data.prosp.Dx(tree.ix{cnt.trees,node,2},1)==-2);
%   ix.retro.classid{1}=find(data.Dx(:,1)>1); % ES
%     ix.retro.classid{2}=find(data.Dx(:,1)==-1); % PSLE
%     ix.retro.classid{3}=find(data.Dx(:,1)==0); % Inconclusive
%     ix.retro.classid{4}=find(data.Dx(:,1)==-5); % Mixed
%     ix.retro.classid{5}=find(data.Dx(:,1)==-2); % PNES
        while node
            ix.line=ix.line+1;
            if strcmp(d{1}{ix.line}(end-length(tree.terminal):end-1),tree.terminal)
                % Found a terminal node
                if node>1
                    tree.comp(cnt.trees,node,1,1)=sum(data.Dx(tree.ix{cnt.trees,node,1},1)> 1 );
                    tree.comp(cnt.trees,node,2,1)=sum(data.Dx(tree.ix{cnt.trees,node,1},1)==-2);
                    tree.comp(cnt.trees,node,1,2)=sum(data.prosp.Dx(tree.ix{cnt.trees,node,2},1)> 1 );
                    tree.comp(cnt.trees,node,2,2)=sum(data.prosp.Dx(tree.ix{cnt.trees,node,2},1)==-2);
                end
                if ix.line==length(d{1})
                    % Found the end of the all the trees
                    tmp.nodes=node;
                    node=0;
                else
                    node=node+1;
                end
            elseif strcmp(d{1}{ix.line}(1:length(tree.endtext)),tree.endtext)
                tmp.nodes=node-1;
                % Found the end of the tree
                node=0;
            else
                % Found an intermediate node
                % This is where all the real work happens

                % Extract the feature name
                char=2;
                while ~strcmp(d{1}{ix.line}(char:char+length(tree.if)-1),tree.if)
                    char=char+1;
                end
                tmp.start=char+length(tree.if);
                while ~strcmp(d{1}{ix.line}(char),'<')
                    char=char+1;
                end
                tmp.end  =char-1;
                % Feature name extracted
                tree.feat{cnt.trees,node}=d{1}{ix.line}(tmp.start:tmp.end);
                % match the string with heads.retro
                tmp.ixfeat=find(strcmp(tree.feat{cnt.trees,node},heads.retro));
                % Extract Threshold
                while ~strcmp(d{1}{ix.line}(char),' ')
                    char=char+1;
                end
                tmp.endthresh=char;
                tree.thresh(cnt.trees,node)=str2num(d{1}{ix.line}(tmp.end+2:tmp.endthresh));
                % find the < leaf
                char=char+length(tree.then);
                while ~strcmp(d{1}{ix.line}(char),' ')
                    char=char+1;
                end
                tmp.endleaf=char;
                tmp.leaf1=str2num(d{1}{ix.line}(tmp.endthresh+length(tree.then)-1:tmp.endleaf));
                tree.dir(cnt.trees,node,2)=tmp.leaf1; % write where we are going
                tree.dir(cnt.trees,tmp.leaf1,1)=node; % write where we came from
                % give the leaf its subjects
                tmp.ix1=find(data.retrofilled(tree.ix{cnt.trees,node,1},tmp.ixfeat,cnt.trees)<tree.thresh(cnt.trees,node));
                tree.ix{cnt.trees,tmp.leaf1,1}=tree.ix{cnt.trees,node,1}(tmp.ix1);
                tmp.ix1=find(data.prosp.testp(tree.ix{cnt.trees,node,2},tmp.ixfeat)<tree.thresh(cnt.trees,node));
                tree.ix{cnt.trees,tmp.leaf1,2}=tree.ix{cnt.trees,node,2}(tmp.ix1);
                
                % find the > leaf
                while ~strcmp(d{1}{ix.line}(char:char+length(tree.then)-1),tree.then)
                    char=char+1;
                end
                tmp.stleaf2=char;
                char=char+length(tree.then);
                while ~strcmp(d{1}{ix.line}(char),' ')
                    char=char+1;
                end
                tmp.endleaf=char;
                tmp.leaf2=str2num(d{1}{ix.line}(tmp.stleaf2+length(tree.then):tmp.endleaf));
                tree.dir(cnt.trees,node,3)=tmp.leaf2; % write where we are going
                tree.dir(cnt.trees,tmp.leaf2,1)=node; % write where we came from
                % give the leaf its subjects
                tree.ix{cnt.trees,tmp.leaf2,1}=setdiff(tree.ix{cnt.trees,node,1},tree.ix{cnt.trees,tmp.leaf1,1});
                tree.ix{cnt.trees,tmp.leaf2,2}=setdiff(tree.ix{cnt.trees,node,2},tree.ix{cnt.trees,tmp.leaf1,2});
                
%                 if cnt.trees==8 && (tmp.leaf1==6 || tmp.leaf2==6)
%                     error 'hi'
% %                     [1:tmp.leaf2;squeeze(tree.nloc(cnt.trees,1:tmp.leaf2,:))']'
%                 end
                
                % check to see if you come from a branch where both leaves
                % have leaves
                % if you do, then you move
                % tree.dir(cnt.trees,node,1) : source leaf
                % tree.dir(cnt.trees,tree.nloc(cnt.trees,node,1),2) : < leaf of source
                % tree.dir(cnt.trees,tree.nloc(cnt.trees,node,1),3) : >= leaf of source
                if node>1
                    if tree.dir(cnt.trees,tree.dir(cnt.trees,tree.dir(cnt.trees,node,1),3),3)*tree.dir(cnt.trees,tree.dir(cnt.trees,tree.dir(cnt.trees,node,1),2),3) % >= leaf of source leaf has a leaves
                        tree.nloc(cnt.trees,node,1)=tree.nloc(cnt.trees,node,1)+tree.shift;
                    end
                end
%                 if tree.dir(cnt.trees,tree.nloc(cnt.trees,node,1),2)                

                % define where your leaves will be
                % check if there's a leaf where you want <leaf to be
                tmp.iy=find(tree.nloc(cnt.trees,:,2)==tree.nloc(cnt.trees,node,2)-tree.vertstep);
                tmp.ix=find(tree.nloc(cnt.trees,:,1)==tree.nloc(cnt.trees,node,1)-tree.backstep);
                tmp.ix4=find(tree.nloc(cnt.trees,:,1)>tree.nloc(cnt.trees,node,1)-tree.backstep *(1+length(intersect(tmp.iy,tmp.ix))));
                tmp.ix3=find(tree.nloc(cnt.trees,:,1)<tree.nloc(cnt.trees,node,1)+tree.frontstep*(1+length(intersect(tmp.iy,tmp.ix))));
                tmp.ix2=intersect(tmp.ix4,tmp.ix3);
                if intersect(tmp.iy,tmp.ix2) % there's a node where we want to shift our new node!
                    fprintf(['Shifting right ' num2str(cnt.trees) '\n']);
                    % so let's shift that node and every one above and to
                    % the right of it
                    tmp.ovlap=intersect(tmp.iy,tmp.ix2);
                    tmp.ylevel=tree.nloc(cnt.trees,tmp.ovlap(1),2);
                    tmp.xlevel=tree.nloc(cnt.trees,tmp.ovlap(1),1);
                    while tmp.ylevel<0
                        tmp.ymatch=find(tree.nloc(cnt.trees,:,2)==tmp.ylevel);
                        tmp.xright=find(tree.nloc(cnt.trees,:,1)>=tmp.xlevel);
                        tree.nloc(cnt.trees,intersect(tmp.ymatch,tmp.xright),1)=tree.nloc(cnt.trees,intersect(tmp.ymatch,tmp.xright),1)+tree.frontstep;
                        % step up and right diagonally
                        tmp.ylevel=tmp.ylevel+tree.vertstep;
                        tmp.xlevel=tmp.xlevel+tree.frontstep;
                    end
                end
                % put our leaf in the space we just made
                tree.nloc(cnt.trees,tmp.leaf1,1)=tree.nloc(cnt.trees,node,1)-tree.backstep;
                
                % check if there's an overlap with the >= leaf
                tmp.iy=find(tree.nloc(cnt.trees,:,2)==tree.nloc(cnt.trees,node,2)-tree.vertstep);
                tmp.ix=find(tree.nloc(cnt.trees,:,1)==tree.nloc(cnt.trees,node,1)+tree.frontstep);
                tmp.ix4=find(tree.nloc(cnt.trees,:,1)>tree.nloc(cnt.trees,node,1)-tree.backstep *(1+length(intersect(tmp.iy,tmp.ix))));
                tmp.ix3=find(tree.nloc(cnt.trees,:,1)<tree.nloc(cnt.trees,node,1)+tree.frontstep*(1+length(intersect(tmp.iy,tmp.ix))));
                tmp.ix2=intersect(tmp.ix4,tmp.ix3);
%                 tmp.ix2=find(tree.nloc(cnt.trees,:,1)==tree.nloc(cnt.trees,node,1)-tree.frontstep*(1-length(intersect(tmp.iy,tmp.ix))));
                if intersect(tmp.iy,tmp.ix2) % there's a node where we want to shift our new node!
                    fprintf(['Shifting left ' num2str(cnt.trees) '\n']);
                    % so let's shift that node and every one above and to
                    % the right of it
                    tmp.ovlap=intersect(tmp.iy,tmp.ix2);
                    tmp.ylevel=tree.nloc(cnt.trees,tmp.ovlap(1),2);
                    tmp.xlevel=tree.nloc(cnt.trees,tmp.ovlap(1),1);
                    while tmp.ylevel<0
                        tmp.ymatch=find(tree.nloc(cnt.trees,:,2)==tmp.ylevel);
                        tmp.xright=find(tree.nloc(cnt.trees,:,1)<=tmp.xlevel);
                        tree.nloc(cnt.trees,intersect(tmp.ymatch,tmp.xright),1)=tree.nloc(cnt.trees,intersect(tmp.ymatch,tmp.xright),1)-tree.backstep;
                        % step up and right diagonally
                        tmp.ylevel=tmp.ylevel+tree.vertstep;
                        tmp.xlevel=tmp.xlevel-tree.frontstep;
                    end
                end
                tree.nloc(cnt.trees,tmp.leaf2,1)=tree.nloc(cnt.trees,node,1)+tree.frontstep;
                tree.nloc(cnt.trees,[tmp.leaf1 tmp.leaf2],2)=tree.nloc(cnt.trees,node,2)-tree.vertstep;                
                
                % Create this node
                if node>1
                    tree.comp(cnt.trees,node,1,1)=sum(data.Dx(tree.ix{cnt.trees,node,1},1)> 1 );
                    tree.comp(cnt.trees,node,2,1)=sum(data.Dx(tree.ix{cnt.trees,node,1},1)==-2);
                    tree.comp(cnt.trees,node,1,2)=sum(data.prosp.Dx(tree.ix{cnt.trees,node,2},1)> 1 );
                    tree.comp(cnt.trees,node,2,2)=sum(data.prosp.Dx(tree.ix{cnt.trees,node,2},1)==-2);
                end
                node=node+1;
            end
            % wraps around to look for the next node
        end
        
        % Fix Overlaps
%         for ind=tmp.nodes:-1:2
%             tmp.iy=find(tree.nloc(cnt.trees,:,2)==tree.nloc(cnt.trees,ind,2));
%             tmp.ix=find(tree.nloc(cnt.trees,:,1)==tree.nloc(cnt.trees,ind,1));
%             if length(intersect(tmp.iy,tmp.ix))>1 % we have an overlap
%                 tmp.ovlap=intersect(tmp.iy,tmp.ix);
%                 tmp.ylevel=tree.nloc(cnt.trees,ind,2);
%                 tmp.xlevel=tree.nloc(cnt.trees,ind,1);
%                 % find the node that comes from a rightward source
%                 tmp.rightsource=find(tree.nloc(cnt.trees,tree.dir(cnt.trees,tmp.ovlap,1))>tmp.xlevel);
%                 if length(tmp.rightsource)==length(intersect(tmp.iy,tmp.ix))
%                     tmp.rightsource=tmp.rightsource(2:end);
%                     fprintf(['shifted everything ' num2str(cnt.trees) '\n']);
% %                     error 'we are just shifting everything'
%                 end
%                 for jnd=tmp.rightsource
%                     % step the overlapped node over
%                     tree.nloc(cnt.trees,tmp.ovlap(jnd),1)=tree.nloc(cnt.trees,tmp.ovlap(jnd),1)+tree.shift;
%                     while tmp.ylevel<0
%                         tmp.ymatch=find(tree.nloc(cnt.trees,:,2)==tmp.ylevel); % all nodes on this level
%                         tmp.xright=find(tree.nloc(cnt.trees,:,1)>=tmp.xlevel); % all nodes to the right
%                         tmp.ovlap2=setdiff(intersect(tmp.ymatch,tmp.xright),tmp.ovlap); % of course, not the nodes that we originally were dealing with
%                         if ~isempty(tmp.ovlap2)
%                             tree.nloc(cnt.trees,tmp.ovlap2,1)=tree.nloc(cnt.trees,tmp.ovlap2,1)+tree.shift;
%                         end
%                         % step up and right diagonally
%                         tmp.ylevel=tmp.ylevel+tree.vertstep;
%                         tmp.xlevel=tmp.xlevel+tree.frontstep;
%                     end
%                 end
%                 fprintf(['Fixing another overlap ' num2str(cnt.trees) '\n']);
%             end
%         end
        
        %% Write the Tree
        fid=fopen(dirs.currenttree,'a');
        for ind=1:tmp.nodes
            tmp.perc=tree.comp(cnt.trees,ind,1)/sum(tree.comp(cnt.trees,ind,:));
            tmp.ncol=min(find(tmp.perc<=tree.cols(:,1)));
            %             tmp.perc=zeros(2,1);
            %             for jnd=1:2
            %                 tmp.perc(jnd)=round(100*tree.comp(cnt.trees,ind,jnd)/sum(tree.comp(cnt.trees,ind,:)));
            %             end
            if tree.dir(cnt.trees,ind,2) % an intermediary node
                %                 fprintf(fid,['\\node[' tree.intermedtype ',fill={rgb:']);
                %                 fprintf(fid,[tree.cols{1} ',' num2str(tmp.perc(1)) ';']);
                %                 fprintf(fid,[tree.cols{2} ',' num2str(tmp.perc(2)) ]);
                %                 fill={rgb,255:red,21; green,66; blue,128}
                %                 fprintf(fid,['\\node[' tree.intermedtype ',fill={rgb,255:']);
                %                 fprintf(fid,['red,' num2str(tree.cols(tmp.ncol,2)) '; green,' num2str(tree.cols(tmp.ncol,3)) '; blue,' num2str(tree.cols(tmp.ncol,4))]);                
                fprintf(fid,['\\definecolor{fillcolor}{rgb}{' num2str(tree.cols(tmp.ncol,2)) ',' num2str(tree.cols(tmp.ncol,3)) ',' num2str(tree.cols(tmp.ncol,4)) '}']);
                fprintf(fid,['\\node[' tree.intermedtype ',fill=fillcolor']);
                fprintf(fid,['] (h' num2str(ind) ') at (']);
                fprintf(fid,[num2str(tree.nloc(cnt.trees,ind,1)) ',' num2str(tree.nloc(cnt.trees,ind,2))]);
                fprintf(fid,') {');
                if do.labelmid
                    % put the composition of the node in the label
                    if tree.writenode
                        fprintf(fid,[num2str(ind) 'R:' num2str(tree.comp(cnt.trees,ind,1,1)) 'ES,' num2str(tree.comp(cnt.trees,ind,2,1)) 'PNES\\' '\\ ']);
                    else
                        fprintf(fid,['R:' num2str(tree.comp(cnt.trees,ind,1,1)) 'ES,' num2str(tree.comp(cnt.trees,ind,2,1)) 'PNES\\' '\\ ']);
                    end
                    if do.writeprosp
                        fprintf(fid,['Pr:' num2str(tree.comp(cnt.trees,ind,1,2)) 'ES,' num2str(tree.comp(cnt.trees,ind,2,2)) 'PNES\\' '\\ ']);
                    end
                end
                if strcmp(tree.feat{cnt.trees,ind},tree.conv)
                    % Fixing an escape character: #
                    tree.feat{cnt.trees,ind}=['\\' tree.feat{cnt.trees,ind}];
                end
                if strcmp(tree.feat{cnt.trees,ind},tree.PI)
                    % Original string too long
                    tree.feat{cnt.trees,ind}='PI Conf';
                end
                if tree.thresh(cnt.trees,ind)==0.5
                    if strcmp(tree.feat{cnt.trees,ind},tree.sex)
                        fprintf(fid,['Sex' '\\' '\\ M $|$ F']);
                    else
                        fprintf(fid,[tree.feat{cnt.trees,ind} '\\' '\\ N $|$ Y']);
                    end
                elseif strcmp(tree.feat{cnt.trees,ind},tree.dur) || strcmp(tree.feat{cnt.trees,ind},tree.szf)
                    % Duration & Seizure Frequency Have Logged and Strange
                    % Units
                    if strcmp(tree.feat{cnt.trees,ind},tree.dur)
                        fprintf(fid,[tree.feat{cnt.trees,ind}(1:end-4) ' ' sectotime(exp(tree.thresh(cnt.trees,ind))) '\\' '\\ $< | \\geq$']);
                    else
                        fprintf(fid,[tree.feat{cnt.trees,ind}(1:end-9) ' ' freqtostr(exp(tree.thresh(cnt.trees,ind))) '\\' '\\ $< | \\geq$']);
                    end
                else
                    fprintf(fid,[tree.feat{cnt.trees,ind} ' ' num2str(tree.thresh(cnt.trees,ind)) '\\' '\\ $< | \\geq$']);
                end
                fprintf(fid,'};\n');
            else % terminal node
                %                 fprintf(fid,['\\node[' tree.terminaltype ',fill={rgb:']);
                %                 fprintf(fid,[tree.cols{1} ',' num2str(tmp.perc(1)) ';']);
                %                 fprintf(fid,[tree.cols{2} ',' num2str(tmp.perc(2)) ]);
                %                 fprintf(fid,['\\node[' tree.intermedtype ',fill={rgb,255:']);
                %                 fprintf(fid,['red,' num2str(tree.cols(tmp.ncol,2)) '; green,' num2str(tree.cols(tmp.ncol,3)) '; blue,' num2str(tree.cols(tmp.ncol,4))]);
                fprintf(fid,['\\definecolor{fillcolor}{rgb}{' num2str(tree.cols(tmp.ncol,2)) ',' num2str(tree.cols(tmp.ncol,3)) ',' num2str(tree.cols(tmp.ncol,4)) '}']);
                fprintf(fid,['\\node[' tree.intermedtype ',fill=fillcolor']);
                fprintf(fid,['] (h' num2str(ind) ') at (']);
                fprintf(fid,[num2str(tree.nloc(cnt.trees,ind,1)) ',' num2str(tree.nloc(cnt.trees,ind,2))]);
                if do.labelend
                    if tree.writenode
                    fprintf(fid,[') {' num2str(ind) 'R:' num2str(tree.comp(cnt.trees,ind,1)) 'ES,' num2str(tree.comp(cnt.trees,ind,2)) 'PNES']);
                    else
                        fprintf(fid,[') {R:' num2str(tree.comp(cnt.trees,ind,1)) 'ES,' num2str(tree.comp(cnt.trees,ind,2)) 'PNES']);
                    end
                    if do.writeprosp
                        fprintf(fid,['\\' '\\' 'Pr:' num2str(tree.comp(cnt.trees,ind,1,2)) 'ES,' num2str(tree.comp(cnt.trees,ind,2,2)) 'PNES']);                        
                    end
                    fprintf(fid,'};\n');
                else
                    fprintf(fid,') {};\n');
                end
            end
        end
        fclose(fid);
        
        % Draw the Connections
        fid=fopen(dirs.currenttree,'a');
        for ind=1:tmp.nodes
            for jnd=2:3
                if tree.dir(cnt.trees,ind,jnd)
                    fprintf(fid,['\\draw[-{Latex[length=' num2str(tree.arrowlen) 'mm]},thick,line width=3pt,draw=black] (']);
                    fprintf(fid,['h' num2str(ind) ') to (']);
%                     fprintf(fid,['h' num2str(ind) ') to [out=270,in=90] (']);
                    fprintf(fid,['h' num2str(tree.dir(cnt.trees,ind,jnd)) '.north);\n']);
                end
            end
        end
        
        % Draw the Legend
        ind=-0.05;
        fprintf(fid,['\\node[' tree.legendtype '] (cL) at (']);
        fprintf(fid,[num2str(min(tree.nloc(cnt.trees,:,1))-tree.backstep) ',' num2str(max(tree.nloc(cnt.trees,:,2))-tree.legstep*ind*10)]); 
        fprintf(fid,[') {\\' '%% ES};']);
        for ind=0:.05:1
            tmp.perc=ind;
            tmp.ncol=min(find(tmp.perc<=tree.cols(:,1)));
            fprintf(fid,['\\definecolor{fillcolor}{rgb}{' num2str(tree.cols(tmp.ncol,2)) ',' num2str(tree.cols(tmp.ncol,3)) ',' num2str(tree.cols(tmp.ncol,4)) '};']);
            fprintf(fid,['\\node[' tree.legendtype ',fill=fillcolor']);
            fprintf(fid,['] (c' num2str(ind*100) ') at (']);
            fprintf(fid,[num2str(min(tree.nloc(cnt.trees,:,1))-tree.backstep) ',' num2str(max(tree.nloc(cnt.trees,:,2))-tree.legstep*ind*10) ') {};\n']);
            fprintf(fid,['\\node[' tree.legendtype '] (c' num2str(ind*100) 'L) at (']);
            fprintf(fid,[num2str(min(tree.nloc(cnt.trees,:,1))-tree.backstep+1) ',' num2str(max(tree.nloc(cnt.trees,:,2))-tree.legstep*ind*10)]); 
                fprintf(fid,[') {' num2str(round(ind*100)) '\\' '%%']);
%             if ind<0.1
%                 fprintf(fid,[') {00' num2str(round(100*ind)) '\\' '%% ES']);
%             elseif ind<1
%                 fprintf(fid,[') {0' num2str(round(100*ind)) '\\' '%% ES']);
%             else
%                 fprintf(fid,[') {' num2str(round(ind*100)) '\\' '%% ES']);
%             end
            fprintf(fid,'};\n');
        end
        
        % Finish Up
        fprintf(fid,'\\end{tikzpicture}\n');
        fprintf(fid,'\\end{document}\n');
        fclose(fid);
    end
    ix.line=ix.line+1;
end